Class: Azure::Monitor::Mgmt::V2015_05_01::APIKeys
- Inherits:
-
Object
- Object
- Azure::Monitor::Mgmt::V2015_05_01::APIKeys
- Includes:
- MsRestAzure
- Defined in:
- lib/2015-05-01/generated/azure_mgmt_monitor/apikeys.rb
Overview
Composite Swagger for Application Insights Management Client
Instance Attribute Summary collapse
-
#client ⇒ ApplicationInsightsManagementClient
readonly
Reference to the ApplicationInsightsManagementClient.
Instance Method Summary collapse
-
#create(resource_group_name, resource_name, apikey_properties, custom_headers: nil) ⇒ ApplicationInsightsComponentAPIKey
Create an API Key of an Application Insights component.
-
#create_async(resource_group_name, resource_name, apikey_properties, custom_headers: nil) ⇒ Concurrent::Promise
Create an API Key of an Application Insights component.
-
#create_with_http_info(resource_group_name, resource_name, apikey_properties, custom_headers: nil) ⇒ MsRestAzure::AzureOperationResponse
Create an API Key of an Application Insights component.
-
#delete(resource_group_name, resource_name, key_id, custom_headers: nil) ⇒ ApplicationInsightsComponentAPIKey
Delete an API Key of an Application Insights component.
-
#delete_async(resource_group_name, resource_name, key_id, custom_headers: nil) ⇒ Concurrent::Promise
Delete an API Key of an Application Insights component.
-
#delete_with_http_info(resource_group_name, resource_name, key_id, custom_headers: nil) ⇒ MsRestAzure::AzureOperationResponse
Delete an API Key of an Application Insights component.
-
#get(resource_group_name, resource_name, key_id, custom_headers: nil) ⇒ ApplicationInsightsComponentAPIKey
Get the API Key for this key id.
-
#get_async(resource_group_name, resource_name, key_id, custom_headers: nil) ⇒ Concurrent::Promise
Get the API Key for this key id.
-
#get_with_http_info(resource_group_name, resource_name, key_id, custom_headers: nil) ⇒ MsRestAzure::AzureOperationResponse
Get the API Key for this key id.
-
#initialize(client) ⇒ APIKeys
constructor
Creates and initializes a new instance of the APIKeys class.
-
#list(resource_group_name, resource_name, custom_headers: nil) ⇒ ApplicationInsightsComponentAPIKeyListResult
Gets a list of API keys of an Application Insights component.
-
#list_async(resource_group_name, resource_name, custom_headers: nil) ⇒ Concurrent::Promise
Gets a list of API keys of an Application Insights component.
-
#list_with_http_info(resource_group_name, resource_name, custom_headers: nil) ⇒ MsRestAzure::AzureOperationResponse
Gets a list of API keys of an Application Insights component.
Constructor Details
#initialize(client) ⇒ APIKeys
Creates and initializes a new instance of the APIKeys class.
17 18 19 |
# File 'lib/2015-05-01/generated/azure_mgmt_monitor/apikeys.rb', line 17 def initialize(client) @client = client end |
Instance Attribute Details
#client ⇒ ApplicationInsightsManagementClient (readonly)
Returns reference to the ApplicationInsightsManagementClient.
22 23 24 |
# File 'lib/2015-05-01/generated/azure_mgmt_monitor/apikeys.rb', line 22 def client @client end |
Instance Method Details
#create(resource_group_name, resource_name, apikey_properties, custom_headers: nil) ⇒ ApplicationInsightsComponentAPIKey
Create an API Key of an Application Insights component.
is case insensitive. resource. to create an API key of a Application Insights component. will be added to the HTTP request.
143 144 145 146 |
# File 'lib/2015-05-01/generated/azure_mgmt_monitor/apikeys.rb', line 143 def create(resource_group_name, resource_name, apikey_properties, custom_headers:nil) response = create_async(resource_group_name, resource_name, apikey_properties, custom_headers:custom_headers).value! response.body unless response.nil? end |
#create_async(resource_group_name, resource_name, apikey_properties, custom_headers: nil) ⇒ Concurrent::Promise
Create an API Key of an Application Insights component.
is case insensitive. resource. to create an API key of a Application Insights component. to the HTTP request.
180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 |
# File 'lib/2015-05-01/generated/azure_mgmt_monitor/apikeys.rb', line 180 def create_async(resource_group_name, resource_name, apikey_properties, custom_headers:nil) fail ArgumentError, 'resource_group_name is nil' if resource_group_name.nil? fail ArgumentError, "'resource_group_name' should satisfy the constraint - 'MaxLength': '90'" if !resource_group_name.nil? && resource_group_name.length > 90 fail ArgumentError, "'resource_group_name' should satisfy the constraint - 'MinLength': '1'" if !resource_group_name.nil? && resource_group_name.length < 1 fail ArgumentError, "'resource_group_name' should satisfy the constraint - 'Pattern': '^[-\w\._\(\)]+$'" if !resource_group_name.nil? && resource_group_name.match(Regexp.new('^^[-\w\._\(\)]+$$')).nil? fail ArgumentError, '@client.api_version is nil' if @client.api_version.nil? fail ArgumentError, "'@client.api_version' should satisfy the constraint - 'MinLength': '1'" if !@client.api_version.nil? && @client.api_version.length < 1 fail ArgumentError, '@client.subscription_id is nil' if @client.subscription_id.nil? fail ArgumentError, "'@client.subscription_id' should satisfy the constraint - 'MinLength': '1'" if !@client.subscription_id.nil? && @client.subscription_id.length < 1 fail ArgumentError, 'resource_name is nil' if resource_name.nil? fail ArgumentError, 'apikey_properties is nil' if apikey_properties.nil? request_headers = {} request_headers['Content-Type'] = 'application/json; charset=utf-8' # Set Headers request_headers['x-ms-client-request-id'] = SecureRandom.uuid request_headers['accept-language'] = @client.accept_language unless @client.accept_language.nil? # Serialize Request request_mapper = Azure::Monitor::Mgmt::V2015_05_01::Models::APIKeyRequest.mapper() request_content = @client.serialize(request_mapper, apikey_properties) request_content = request_content != nil ? JSON.generate(request_content, quirks_mode: true) : nil path_template = 'subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.Insights/components/{resourceName}/ApiKeys' request_url = @base_url || @client.base_url = { middlewares: [[MsRest::RetryPolicyMiddleware, times: 3, retry: 0.02], [:cookie_jar]], path_params: {'resourceGroupName' => resource_group_name,'subscriptionId' => @client.subscription_id,'resourceName' => resource_name}, query_params: {'api-version' => @client.api_version}, body: request_content, headers: request_headers.merge(custom_headers || {}), base_url: request_url } promise = @client.make_request_async(:post, path_template, ) promise = promise.then do |result| http_response = result.response status_code = http_response.status response_content = http_response.body unless status_code == 200 error_model = JSON.load(response_content) fail MsRestAzure::AzureOperationError.new(result.request, http_response, error_model) end result.request_id = http_response['x-ms-request-id'] unless http_response['x-ms-request-id'].nil? result.correlation_request_id = http_response['x-ms-correlation-request-id'] unless http_response['x-ms-correlation-request-id'].nil? result.client_request_id = http_response['x-ms-client-request-id'] unless http_response['x-ms-client-request-id'].nil? # Deserialize Response if status_code == 200 begin parsed_response = response_content.to_s.empty? ? nil : JSON.load(response_content) result_mapper = Azure::Monitor::Mgmt::V2015_05_01::Models::ApplicationInsightsComponentAPIKey.mapper() result.body = @client.deserialize(result_mapper, parsed_response) rescue Exception => e fail MsRest::DeserializationError.new('Error occurred in deserializing the response', e., e.backtrace, result) end end result end promise.execute end |
#create_with_http_info(resource_group_name, resource_name, apikey_properties, custom_headers: nil) ⇒ MsRestAzure::AzureOperationResponse
Create an API Key of an Application Insights component.
is case insensitive. resource. to create an API key of a Application Insights component. will be added to the HTTP request.
162 163 164 |
# File 'lib/2015-05-01/generated/azure_mgmt_monitor/apikeys.rb', line 162 def create_with_http_info(resource_group_name, resource_name, apikey_properties, custom_headers:nil) create_async(resource_group_name, resource_name, apikey_properties, custom_headers:custom_headers).value! end |
#delete(resource_group_name, resource_name, key_id, custom_headers: nil) ⇒ ApplicationInsightsComponentAPIKey
Delete an API Key of an Application Insights component.
is case insensitive. resource. Insights component. will be added to the HTTP request.
262 263 264 265 |
# File 'lib/2015-05-01/generated/azure_mgmt_monitor/apikeys.rb', line 262 def delete(resource_group_name, resource_name, key_id, custom_headers:nil) response = delete_async(resource_group_name, resource_name, key_id, custom_headers:custom_headers).value! response.body unless response.nil? end |
#delete_async(resource_group_name, resource_name, key_id, custom_headers: nil) ⇒ Concurrent::Promise
Delete an API Key of an Application Insights component.
is case insensitive. resource. Insights component. to the HTTP request.
299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 |
# File 'lib/2015-05-01/generated/azure_mgmt_monitor/apikeys.rb', line 299 def delete_async(resource_group_name, resource_name, key_id, custom_headers:nil) fail ArgumentError, 'resource_group_name is nil' if resource_group_name.nil? fail ArgumentError, "'resource_group_name' should satisfy the constraint - 'MaxLength': '90'" if !resource_group_name.nil? && resource_group_name.length > 90 fail ArgumentError, "'resource_group_name' should satisfy the constraint - 'MinLength': '1'" if !resource_group_name.nil? && resource_group_name.length < 1 fail ArgumentError, "'resource_group_name' should satisfy the constraint - 'Pattern': '^[-\w\._\(\)]+$'" if !resource_group_name.nil? && resource_group_name.match(Regexp.new('^^[-\w\._\(\)]+$$')).nil? fail ArgumentError, '@client.api_version is nil' if @client.api_version.nil? fail ArgumentError, "'@client.api_version' should satisfy the constraint - 'MinLength': '1'" if !@client.api_version.nil? && @client.api_version.length < 1 fail ArgumentError, '@client.subscription_id is nil' if @client.subscription_id.nil? fail ArgumentError, "'@client.subscription_id' should satisfy the constraint - 'MinLength': '1'" if !@client.subscription_id.nil? && @client.subscription_id.length < 1 fail ArgumentError, 'resource_name is nil' if resource_name.nil? fail ArgumentError, 'key_id is nil' if key_id.nil? request_headers = {} request_headers['Content-Type'] = 'application/json; charset=utf-8' # Set Headers request_headers['x-ms-client-request-id'] = SecureRandom.uuid request_headers['accept-language'] = @client.accept_language unless @client.accept_language.nil? path_template = 'subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.Insights/components/{resourceName}/APIKeys/{keyId}' request_url = @base_url || @client.base_url = { middlewares: [[MsRest::RetryPolicyMiddleware, times: 3, retry: 0.02], [:cookie_jar]], path_params: {'resourceGroupName' => resource_group_name,'subscriptionId' => @client.subscription_id,'resourceName' => resource_name,'keyId' => key_id}, query_params: {'api-version' => @client.api_version}, headers: request_headers.merge(custom_headers || {}), base_url: request_url } promise = @client.make_request_async(:delete, path_template, ) promise = promise.then do |result| http_response = result.response status_code = http_response.status response_content = http_response.body unless status_code == 200 error_model = JSON.load(response_content) fail MsRestAzure::AzureOperationError.new(result.request, http_response, error_model) end result.request_id = http_response['x-ms-request-id'] unless http_response['x-ms-request-id'].nil? result.correlation_request_id = http_response['x-ms-correlation-request-id'] unless http_response['x-ms-correlation-request-id'].nil? result.client_request_id = http_response['x-ms-client-request-id'] unless http_response['x-ms-client-request-id'].nil? # Deserialize Response if status_code == 200 begin parsed_response = response_content.to_s.empty? ? nil : JSON.load(response_content) result_mapper = Azure::Monitor::Mgmt::V2015_05_01::Models::ApplicationInsightsComponentAPIKey.mapper() result.body = @client.deserialize(result_mapper, parsed_response) rescue Exception => e fail MsRest::DeserializationError.new('Error occurred in deserializing the response', e., e.backtrace, result) end end result end promise.execute end |
#delete_with_http_info(resource_group_name, resource_name, key_id, custom_headers: nil) ⇒ MsRestAzure::AzureOperationResponse
Delete an API Key of an Application Insights component.
is case insensitive. resource. Insights component. will be added to the HTTP request.
281 282 283 |
# File 'lib/2015-05-01/generated/azure_mgmt_monitor/apikeys.rb', line 281 def delete_with_http_info(resource_group_name, resource_name, key_id, custom_headers:nil) delete_async(resource_group_name, resource_name, key_id, custom_headers:custom_headers).value! end |
#get(resource_group_name, resource_name, key_id, custom_headers: nil) ⇒ ApplicationInsightsComponentAPIKey
Get the API Key for this key id.
is case insensitive. resource. Insights component. will be added to the HTTP request.
374 375 376 377 |
# File 'lib/2015-05-01/generated/azure_mgmt_monitor/apikeys.rb', line 374 def get(resource_group_name, resource_name, key_id, custom_headers:nil) response = get_async(resource_group_name, resource_name, key_id, custom_headers:custom_headers).value! response.body unless response.nil? end |
#get_async(resource_group_name, resource_name, key_id, custom_headers: nil) ⇒ Concurrent::Promise
Get the API Key for this key id.
is case insensitive. resource. Insights component. to the HTTP request.
411 412 413 414 415 416 417 418 419 420 421 422 423 424 425 426 427 428 429 430 431 432 433 434 435 436 437 438 439 440 441 442 443 444 445 446 447 448 449 450 451 452 453 454 455 456 457 458 459 460 461 462 463 464 465 466 467 468 469 470 |
# File 'lib/2015-05-01/generated/azure_mgmt_monitor/apikeys.rb', line 411 def get_async(resource_group_name, resource_name, key_id, custom_headers:nil) fail ArgumentError, 'resource_group_name is nil' if resource_group_name.nil? fail ArgumentError, "'resource_group_name' should satisfy the constraint - 'MaxLength': '90'" if !resource_group_name.nil? && resource_group_name.length > 90 fail ArgumentError, "'resource_group_name' should satisfy the constraint - 'MinLength': '1'" if !resource_group_name.nil? && resource_group_name.length < 1 fail ArgumentError, "'resource_group_name' should satisfy the constraint - 'Pattern': '^[-\w\._\(\)]+$'" if !resource_group_name.nil? && resource_group_name.match(Regexp.new('^^[-\w\._\(\)]+$$')).nil? fail ArgumentError, '@client.api_version is nil' if @client.api_version.nil? fail ArgumentError, "'@client.api_version' should satisfy the constraint - 'MinLength': '1'" if !@client.api_version.nil? && @client.api_version.length < 1 fail ArgumentError, '@client.subscription_id is nil' if @client.subscription_id.nil? fail ArgumentError, "'@client.subscription_id' should satisfy the constraint - 'MinLength': '1'" if !@client.subscription_id.nil? && @client.subscription_id.length < 1 fail ArgumentError, 'resource_name is nil' if resource_name.nil? fail ArgumentError, 'key_id is nil' if key_id.nil? request_headers = {} request_headers['Content-Type'] = 'application/json; charset=utf-8' # Set Headers request_headers['x-ms-client-request-id'] = SecureRandom.uuid request_headers['accept-language'] = @client.accept_language unless @client.accept_language.nil? path_template = 'subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.Insights/components/{resourceName}/APIKeys/{keyId}' request_url = @base_url || @client.base_url = { middlewares: [[MsRest::RetryPolicyMiddleware, times: 3, retry: 0.02], [:cookie_jar]], path_params: {'resourceGroupName' => resource_group_name,'subscriptionId' => @client.subscription_id,'resourceName' => resource_name,'keyId' => key_id}, query_params: {'api-version' => @client.api_version}, headers: request_headers.merge(custom_headers || {}), base_url: request_url } promise = @client.make_request_async(:get, path_template, ) promise = promise.then do |result| http_response = result.response status_code = http_response.status response_content = http_response.body unless status_code == 200 error_model = JSON.load(response_content) fail MsRestAzure::AzureOperationError.new(result.request, http_response, error_model) end result.request_id = http_response['x-ms-request-id'] unless http_response['x-ms-request-id'].nil? result.correlation_request_id = http_response['x-ms-correlation-request-id'] unless http_response['x-ms-correlation-request-id'].nil? result.client_request_id = http_response['x-ms-client-request-id'] unless http_response['x-ms-client-request-id'].nil? # Deserialize Response if status_code == 200 begin parsed_response = response_content.to_s.empty? ? nil : JSON.load(response_content) result_mapper = Azure::Monitor::Mgmt::V2015_05_01::Models::ApplicationInsightsComponentAPIKey.mapper() result.body = @client.deserialize(result_mapper, parsed_response) rescue Exception => e fail MsRest::DeserializationError.new('Error occurred in deserializing the response', e., e.backtrace, result) end end result end promise.execute end |
#get_with_http_info(resource_group_name, resource_name, key_id, custom_headers: nil) ⇒ MsRestAzure::AzureOperationResponse
Get the API Key for this key id.
is case insensitive. resource. Insights component. will be added to the HTTP request.
393 394 395 |
# File 'lib/2015-05-01/generated/azure_mgmt_monitor/apikeys.rb', line 393 def get_with_http_info(resource_group_name, resource_name, key_id, custom_headers:nil) get_async(resource_group_name, resource_name, key_id, custom_headers:custom_headers).value! end |
#list(resource_group_name, resource_name, custom_headers: nil) ⇒ ApplicationInsightsComponentAPIKeyListResult
Gets a list of API keys of an Application Insights component.
is case insensitive. resource. will be added to the HTTP request.
36 37 38 39 |
# File 'lib/2015-05-01/generated/azure_mgmt_monitor/apikeys.rb', line 36 def list(resource_group_name, resource_name, custom_headers:nil) response = list_async(resource_group_name, resource_name, custom_headers:custom_headers).value! response.body unless response.nil? end |
#list_async(resource_group_name, resource_name, custom_headers: nil) ⇒ Concurrent::Promise
Gets a list of API keys of an Application Insights component.
is case insensitive. resource. to the HTTP request.
69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 |
# File 'lib/2015-05-01/generated/azure_mgmt_monitor/apikeys.rb', line 69 def list_async(resource_group_name, resource_name, custom_headers:nil) fail ArgumentError, 'resource_group_name is nil' if resource_group_name.nil? fail ArgumentError, "'resource_group_name' should satisfy the constraint - 'MaxLength': '90'" if !resource_group_name.nil? && resource_group_name.length > 90 fail ArgumentError, "'resource_group_name' should satisfy the constraint - 'MinLength': '1'" if !resource_group_name.nil? && resource_group_name.length < 1 fail ArgumentError, "'resource_group_name' should satisfy the constraint - 'Pattern': '^[-\w\._\(\)]+$'" if !resource_group_name.nil? && resource_group_name.match(Regexp.new('^^[-\w\._\(\)]+$$')).nil? fail ArgumentError, '@client.api_version is nil' if @client.api_version.nil? fail ArgumentError, "'@client.api_version' should satisfy the constraint - 'MinLength': '1'" if !@client.api_version.nil? && @client.api_version.length < 1 fail ArgumentError, '@client.subscription_id is nil' if @client.subscription_id.nil? fail ArgumentError, "'@client.subscription_id' should satisfy the constraint - 'MinLength': '1'" if !@client.subscription_id.nil? && @client.subscription_id.length < 1 fail ArgumentError, 'resource_name is nil' if resource_name.nil? request_headers = {} request_headers['Content-Type'] = 'application/json; charset=utf-8' # Set Headers request_headers['x-ms-client-request-id'] = SecureRandom.uuid request_headers['accept-language'] = @client.accept_language unless @client.accept_language.nil? path_template = 'subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.Insights/components/{resourceName}/ApiKeys' request_url = @base_url || @client.base_url = { middlewares: [[MsRest::RetryPolicyMiddleware, times: 3, retry: 0.02], [:cookie_jar]], path_params: {'resourceGroupName' => resource_group_name,'subscriptionId' => @client.subscription_id,'resourceName' => resource_name}, query_params: {'api-version' => @client.api_version}, headers: request_headers.merge(custom_headers || {}), base_url: request_url } promise = @client.make_request_async(:get, path_template, ) promise = promise.then do |result| http_response = result.response status_code = http_response.status response_content = http_response.body unless status_code == 200 error_model = JSON.load(response_content) fail MsRestAzure::AzureOperationError.new(result.request, http_response, error_model) end result.request_id = http_response['x-ms-request-id'] unless http_response['x-ms-request-id'].nil? result.correlation_request_id = http_response['x-ms-correlation-request-id'] unless http_response['x-ms-correlation-request-id'].nil? result.client_request_id = http_response['x-ms-client-request-id'] unless http_response['x-ms-client-request-id'].nil? # Deserialize Response if status_code == 200 begin parsed_response = response_content.to_s.empty? ? nil : JSON.load(response_content) result_mapper = Azure::Monitor::Mgmt::V2015_05_01::Models::ApplicationInsightsComponentAPIKeyListResult.mapper() result.body = @client.deserialize(result_mapper, parsed_response) rescue Exception => e fail MsRest::DeserializationError.new('Error occurred in deserializing the response', e., e.backtrace, result) end end result end promise.execute end |
#list_with_http_info(resource_group_name, resource_name, custom_headers: nil) ⇒ MsRestAzure::AzureOperationResponse
Gets a list of API keys of an Application Insights component.
is case insensitive. resource. will be added to the HTTP request.
53 54 55 |
# File 'lib/2015-05-01/generated/azure_mgmt_monitor/apikeys.rb', line 53 def list_with_http_info(resource_group_name, resource_name, custom_headers:nil) list_async(resource_group_name, resource_name, custom_headers:custom_headers).value! end |