Class: Azure::Monitor::Mgmt::V2015_05_01::AnalyticsItems

Inherits:
Object
  • Object
show all
Includes:
MsRestAzure
Defined in:
lib/2015-05-01/generated/azure_mgmt_monitor/analytics_items.rb

Overview

Composite Swagger for Application Insights Management Client

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(client) ⇒ AnalyticsItems

Creates and initializes a new instance of the AnalyticsItems class.

Parameters:

  • client

    service class for accessing basic functionality.



17
18
19
# File 'lib/2015-05-01/generated/azure_mgmt_monitor/analytics_items.rb', line 17

def initialize(client)
  @client = client
end

Instance Attribute Details

#clientApplicationInsightsManagementClient (readonly)

Returns reference to the ApplicationInsightsManagementClient.

Returns:



22
23
24
# File 'lib/2015-05-01/generated/azure_mgmt_monitor/analytics_items.rb', line 22

def client
  @client
end

Instance Method Details

#delete(resource_group_name, resource_name, scope_path, id: nil, name: nil, custom_headers: nil) ⇒ Object

Deletes a specific Analytics Items defined within an Application Insights component.

is case insensitive. resource. owned by a specific user or is shared between all users with access to the Application Insights component. Possible values include: 'analyticsItems', 'myanalyticsItems' Insights component Insights component will be added to the HTTP request.

Parameters:

  • resource_group_name (String)

    The name of the resource group. The name

  • resource_name (String)

    The name of the Application Insights component

  • scope_path (ItemScopePath)

    Enum indicating if this item definition is

  • id (String) (defaults to: nil)

    The Id of a specific item defined in the Application

  • name (String) (defaults to: nil)

    The name of a specific item defined in the Application

  • custom_headers (Hash{String => String}) (defaults to: nil)

    A hash of custom headers that



482
483
484
485
# File 'lib/2015-05-01/generated/azure_mgmt_monitor/analytics_items.rb', line 482

def delete(resource_group_name, resource_name, scope_path, id:nil, name:nil, custom_headers:nil)
  response = delete_async(resource_group_name, resource_name, scope_path, id:id, name:name, custom_headers:custom_headers).value!
  nil
end

#delete_async(resource_group_name, resource_name, scope_path, id: nil, name: nil, custom_headers: nil) ⇒ Concurrent::Promise

Deletes a specific Analytics Items defined within an Application Insights component.

is case insensitive. resource. owned by a specific user or is shared between all users with access to the Application Insights component. Possible values include: 'analyticsItems', 'myanalyticsItems' Insights component Insights component to the HTTP request.

Parameters:

  • resource_group_name (String)

    The name of the resource group. The name

  • resource_name (String)

    The name of the Application Insights component

  • scope_path (ItemScopePath)

    Enum indicating if this item definition is

  • id (String) (defaults to: nil)

    The Id of a specific item defined in the Application

  • name (String) (defaults to: nil)

    The name of a specific item defined in the Application

  • A (Hash{String => String})

    hash of custom headers that will be added

Returns:

  • (Concurrent::Promise)

    Promise object which holds the HTTP response.



533
534
535
536
537
538
539
540
541
542
543
544
545
546
547
548
549
550
551
552
553
554
555
556
557
558
559
560
561
562
563
564
565
566
567
568
569
570
571
572
573
574
575
576
577
578
579
580
581
582
# File 'lib/2015-05-01/generated/azure_mgmt_monitor/analytics_items.rb', line 533

def delete_async(resource_group_name, resource_name, scope_path, id:nil, name:nil, custom_headers:nil)
  fail ArgumentError, '@client.subscription_id is nil' if @client.subscription_id.nil?
  fail ArgumentError, "'@client.subscription_id' should satisfy the constraint - 'MinLength': '1'" if !@client.subscription_id.nil? && @client.subscription_id.length < 1
  fail ArgumentError, 'resource_group_name is nil' if resource_group_name.nil?
  fail ArgumentError, "'resource_group_name' should satisfy the constraint - 'MaxLength': '90'" if !resource_group_name.nil? && resource_group_name.length > 90
  fail ArgumentError, "'resource_group_name' should satisfy the constraint - 'MinLength': '1'" if !resource_group_name.nil? && resource_group_name.length < 1
  fail ArgumentError, "'resource_group_name' should satisfy the constraint - 'Pattern': '^[-\w\._\(\)]+$'" if !resource_group_name.nil? && resource_group_name.match(Regexp.new('^^[-\w\._\(\)]+$$')).nil?
  fail ArgumentError, 'resource_name is nil' if resource_name.nil?
  fail ArgumentError, 'scope_path is nil' if scope_path.nil?
  fail ArgumentError, '@client.api_version is nil' if @client.api_version.nil?
  fail ArgumentError, "'@client.api_version' should satisfy the constraint - 'MinLength': '1'" if !@client.api_version.nil? && @client.api_version.length < 1


  request_headers = {}
  request_headers['Content-Type'] = 'application/json; charset=utf-8'

  # Set Headers
  request_headers['x-ms-client-request-id'] = SecureRandom.uuid
  request_headers['accept-language'] = @client.accept_language unless @client.accept_language.nil?
  path_template = 'subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/microsoft.insights/components/{resourceName}/{scopePath}/item'

  request_url = @base_url || @client.base_url

  options = {
      middlewares: [[MsRest::RetryPolicyMiddleware, times: 3, retry: 0.02], [:cookie_jar]],
      path_params: {'subscriptionId' => @client.subscription_id,'resourceGroupName' => resource_group_name,'resourceName' => resource_name,'scopePath' => scope_path},
      query_params: {'api-version' => @client.api_version,'id' => id,'name' => name},
      headers: request_headers.merge(custom_headers || {}),
      base_url: request_url
  }
  promise = @client.make_request_async(:delete, path_template, options)

  promise = promise.then do |result|
    http_response = result.response
    status_code = http_response.status
    response_content = http_response.body
    unless status_code == 200
      error_model = JSON.load(response_content)
      fail MsRestAzure::AzureOperationError.new(result.request, http_response, error_model)
    end

    result.request_id = http_response['x-ms-request-id'] unless http_response['x-ms-request-id'].nil?
    result.correlation_request_id = http_response['x-ms-correlation-request-id'] unless http_response['x-ms-correlation-request-id'].nil?
    result.client_request_id = http_response['x-ms-client-request-id'] unless http_response['x-ms-client-request-id'].nil?

    result
  end

  promise.execute
end

#delete_with_http_info(resource_group_name, resource_name, scope_path, id: nil, name: nil, custom_headers: nil) ⇒ MsRestAzure::AzureOperationResponse

Deletes a specific Analytics Items defined within an Application Insights component.

is case insensitive. resource. owned by a specific user or is shared between all users with access to the Application Insights component. Possible values include: 'analyticsItems', 'myanalyticsItems' Insights component Insights component will be added to the HTTP request.

Parameters:

  • resource_group_name (String)

    The name of the resource group. The name

  • resource_name (String)

    The name of the Application Insights component

  • scope_path (ItemScopePath)

    Enum indicating if this item definition is

  • id (String) (defaults to: nil)

    The Id of a specific item defined in the Application

  • name (String) (defaults to: nil)

    The name of a specific item defined in the Application

  • custom_headers (Hash{String => String}) (defaults to: nil)

    A hash of custom headers that

Returns:

  • (MsRestAzure::AzureOperationResponse)

    HTTP response information.



508
509
510
# File 'lib/2015-05-01/generated/azure_mgmt_monitor/analytics_items.rb', line 508

def delete_with_http_info(resource_group_name, resource_name, scope_path, id:nil, name:nil, custom_headers:nil)
  delete_async(resource_group_name, resource_name, scope_path, id:id, name:name, custom_headers:custom_headers).value!
end

#get(resource_group_name, resource_name, scope_path, id: nil, name: nil, custom_headers: nil) ⇒ ApplicationInsightsComponentAnalyticsItem

Gets a specific Analytics Items defined within an Application Insights component.

is case insensitive. resource. owned by a specific user or is shared between all users with access to the Application Insights component. Possible values include: 'analyticsItems', 'myanalyticsItems' Insights component Insights component will be added to the HTTP request.

Parameters:

  • resource_group_name (String)

    The name of the resource group. The name

  • resource_name (String)

    The name of the Application Insights component

  • scope_path (ItemScopePath)

    Enum indicating if this item definition is

  • id (String) (defaults to: nil)

    The Id of a specific item defined in the Application

  • name (String) (defaults to: nil)

    The name of a specific item defined in the Application

  • custom_headers (Hash{String => String}) (defaults to: nil)

    A hash of custom headers that

Returns:

  • (ApplicationInsightsComponentAnalyticsItem)

    operation results.



206
207
208
209
# File 'lib/2015-05-01/generated/azure_mgmt_monitor/analytics_items.rb', line 206

def get(resource_group_name, resource_name, scope_path, id:nil, name:nil, custom_headers:nil)
  response = get_async(resource_group_name, resource_name, scope_path, id:id, name:name, custom_headers:custom_headers).value!
  response.body unless response.nil?
end

#get_async(resource_group_name, resource_name, scope_path, id: nil, name: nil, custom_headers: nil) ⇒ Concurrent::Promise

Gets a specific Analytics Items defined within an Application Insights component.

is case insensitive. resource. owned by a specific user or is shared between all users with access to the Application Insights component. Possible values include: 'analyticsItems', 'myanalyticsItems' Insights component Insights component to the HTTP request.

Parameters:

  • resource_group_name (String)

    The name of the resource group. The name

  • resource_name (String)

    The name of the Application Insights component

  • scope_path (ItemScopePath)

    Enum indicating if this item definition is

  • id (String) (defaults to: nil)

    The Id of a specific item defined in the Application

  • name (String) (defaults to: nil)

    The name of a specific item defined in the Application

  • A (Hash{String => String})

    hash of custom headers that will be added

Returns:

  • (Concurrent::Promise)

    Promise object which holds the HTTP response.



257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
# File 'lib/2015-05-01/generated/azure_mgmt_monitor/analytics_items.rb', line 257

def get_async(resource_group_name, resource_name, scope_path, id:nil, name:nil, custom_headers:nil)
  fail ArgumentError, '@client.subscription_id is nil' if @client.subscription_id.nil?
  fail ArgumentError, "'@client.subscription_id' should satisfy the constraint - 'MinLength': '1'" if !@client.subscription_id.nil? && @client.subscription_id.length < 1
  fail ArgumentError, 'resource_group_name is nil' if resource_group_name.nil?
  fail ArgumentError, "'resource_group_name' should satisfy the constraint - 'MaxLength': '90'" if !resource_group_name.nil? && resource_group_name.length > 90
  fail ArgumentError, "'resource_group_name' should satisfy the constraint - 'MinLength': '1'" if !resource_group_name.nil? && resource_group_name.length < 1
  fail ArgumentError, "'resource_group_name' should satisfy the constraint - 'Pattern': '^[-\w\._\(\)]+$'" if !resource_group_name.nil? && resource_group_name.match(Regexp.new('^^[-\w\._\(\)]+$$')).nil?
  fail ArgumentError, 'resource_name is nil' if resource_name.nil?
  fail ArgumentError, 'scope_path is nil' if scope_path.nil?
  fail ArgumentError, '@client.api_version is nil' if @client.api_version.nil?
  fail ArgumentError, "'@client.api_version' should satisfy the constraint - 'MinLength': '1'" if !@client.api_version.nil? && @client.api_version.length < 1


  request_headers = {}
  request_headers['Content-Type'] = 'application/json; charset=utf-8'

  # Set Headers
  request_headers['x-ms-client-request-id'] = SecureRandom.uuid
  request_headers['accept-language'] = @client.accept_language unless @client.accept_language.nil?
  path_template = 'subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/microsoft.insights/components/{resourceName}/{scopePath}/item'

  request_url = @base_url || @client.base_url

  options = {
      middlewares: [[MsRest::RetryPolicyMiddleware, times: 3, retry: 0.02], [:cookie_jar]],
      path_params: {'subscriptionId' => @client.subscription_id,'resourceGroupName' => resource_group_name,'resourceName' => resource_name,'scopePath' => scope_path},
      query_params: {'api-version' => @client.api_version,'id' => id,'name' => name},
      headers: request_headers.merge(custom_headers || {}),
      base_url: request_url
  }
  promise = @client.make_request_async(:get, path_template, options)

  promise = promise.then do |result|
    http_response = result.response
    status_code = http_response.status
    response_content = http_response.body
    unless status_code == 200
      error_model = JSON.load(response_content)
      fail MsRestAzure::AzureOperationError.new(result.request, http_response, error_model)
    end

    result.request_id = http_response['x-ms-request-id'] unless http_response['x-ms-request-id'].nil?
    result.correlation_request_id = http_response['x-ms-correlation-request-id'] unless http_response['x-ms-correlation-request-id'].nil?
    result.client_request_id = http_response['x-ms-client-request-id'] unless http_response['x-ms-client-request-id'].nil?
    # Deserialize Response
    if status_code == 200
      begin
        parsed_response = response_content.to_s.empty? ? nil : JSON.load(response_content)
        result_mapper = Azure::Monitor::Mgmt::V2015_05_01::Models::ApplicationInsightsComponentAnalyticsItem.mapper()
        result.body = @client.deserialize(result_mapper, parsed_response)
      rescue Exception => e
        fail MsRest::DeserializationError.new('Error occurred in deserializing the response', e.message, e.backtrace, result)
      end
    end

    result
  end

  promise.execute
end

#get_with_http_info(resource_group_name, resource_name, scope_path, id: nil, name: nil, custom_headers: nil) ⇒ MsRestAzure::AzureOperationResponse

Gets a specific Analytics Items defined within an Application Insights component.

is case insensitive. resource. owned by a specific user or is shared between all users with access to the Application Insights component. Possible values include: 'analyticsItems', 'myanalyticsItems' Insights component Insights component will be added to the HTTP request.

Parameters:

  • resource_group_name (String)

    The name of the resource group. The name

  • resource_name (String)

    The name of the Application Insights component

  • scope_path (ItemScopePath)

    Enum indicating if this item definition is

  • id (String) (defaults to: nil)

    The Id of a specific item defined in the Application

  • name (String) (defaults to: nil)

    The name of a specific item defined in the Application

  • custom_headers (Hash{String => String}) (defaults to: nil)

    A hash of custom headers that

Returns:

  • (MsRestAzure::AzureOperationResponse)

    HTTP response information.



232
233
234
# File 'lib/2015-05-01/generated/azure_mgmt_monitor/analytics_items.rb', line 232

def get_with_http_info(resource_group_name, resource_name, scope_path, id:nil, name:nil, custom_headers:nil)
  get_async(resource_group_name, resource_name, scope_path, id:id, name:name, custom_headers:custom_headers).value!
end

#list(resource_group_name, resource_name, scope_path, scope: nil, type: nil, include_content: nil, custom_headers: nil) ⇒ Array

Gets a list of Analytics Items defined within an Application Insights component.

is case insensitive. resource. owned by a specific user or is shared between all users with access to the Application Insights component. Possible values include: 'analyticsItems', 'myanalyticsItems' a specific user or is shared between all users with access to the Application Insights component. Possible values include: 'shared', 'user' item. Possible values include: 'none', 'query', 'function', 'folder', 'recent' content of each applicable item. If false, only return the item information. will be added to the HTTP request.

Parameters:

  • resource_group_name (String)

    The name of the resource group. The name

  • resource_name (String)

    The name of the Application Insights component

  • scope_path (ItemScopePath)

    Enum indicating if this item definition is

  • scope (ItemScope) (defaults to: nil)

    Enum indicating if this item definition is owned by

  • type (ItemTypeParameter) (defaults to: nil)

    Enum indicating the type of the Analytics

  • include_content (Boolean) (defaults to: nil)

    Flag indicating whether or not to return the

  • custom_headers (Hash{String => String}) (defaults to: nil)

    A hash of custom headers that

Returns:

  • (Array)

    operation results.



49
50
51
52
# File 'lib/2015-05-01/generated/azure_mgmt_monitor/analytics_items.rb', line 49

def list(resource_group_name, resource_name, scope_path, scope:nil, type:nil, include_content:nil, custom_headers:nil)
  response = list_async(resource_group_name, resource_name, scope_path, scope:scope, type:type, include_content:include_content, custom_headers:custom_headers).value!
  response.body unless response.nil?
end

#list_async(resource_group_name, resource_name, scope_path, scope: nil, type: nil, include_content: nil, custom_headers: nil) ⇒ Concurrent::Promise

Gets a list of Analytics Items defined within an Application Insights component.

is case insensitive. resource. owned by a specific user or is shared between all users with access to the Application Insights component. Possible values include: 'analyticsItems', 'myanalyticsItems' a specific user or is shared between all users with access to the Application Insights component. Possible values include: 'shared', 'user' item. Possible values include: 'none', 'query', 'function', 'folder', 'recent' content of each applicable item. If false, only return the item information. to the HTTP request.

Parameters:

  • resource_group_name (String)

    The name of the resource group. The name

  • resource_name (String)

    The name of the Application Insights component

  • scope_path (ItemScopePath)

    Enum indicating if this item definition is

  • scope (ItemScope) (defaults to: nil)

    Enum indicating if this item definition is owned by

  • type (ItemTypeParameter) (defaults to: nil)

    Enum indicating the type of the Analytics

  • include_content (Boolean) (defaults to: nil)

    Flag indicating whether or not to return the

  • A (Hash{String => String})

    hash of custom headers that will be added

Returns:

  • (Concurrent::Promise)

    Promise object which holds the HTTP response.



108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
# File 'lib/2015-05-01/generated/azure_mgmt_monitor/analytics_items.rb', line 108

def list_async(resource_group_name, resource_name, scope_path, scope:nil, type:nil, include_content:nil, custom_headers:nil)
  fail ArgumentError, '@client.subscription_id is nil' if @client.subscription_id.nil?
  fail ArgumentError, "'@client.subscription_id' should satisfy the constraint - 'MinLength': '1'" if !@client.subscription_id.nil? && @client.subscription_id.length < 1
  fail ArgumentError, 'resource_group_name is nil' if resource_group_name.nil?
  fail ArgumentError, "'resource_group_name' should satisfy the constraint - 'MaxLength': '90'" if !resource_group_name.nil? && resource_group_name.length > 90
  fail ArgumentError, "'resource_group_name' should satisfy the constraint - 'MinLength': '1'" if !resource_group_name.nil? && resource_group_name.length < 1
  fail ArgumentError, "'resource_group_name' should satisfy the constraint - 'Pattern': '^[-\w\._\(\)]+$'" if !resource_group_name.nil? && resource_group_name.match(Regexp.new('^^[-\w\._\(\)]+$$')).nil?
  fail ArgumentError, 'resource_name is nil' if resource_name.nil?
  fail ArgumentError, 'scope_path is nil' if scope_path.nil?
  fail ArgumentError, '@client.api_version is nil' if @client.api_version.nil?
  fail ArgumentError, "'@client.api_version' should satisfy the constraint - 'MinLength': '1'" if !@client.api_version.nil? && @client.api_version.length < 1


  request_headers = {}
  request_headers['Content-Type'] = 'application/json; charset=utf-8'

  # Set Headers
  request_headers['x-ms-client-request-id'] = SecureRandom.uuid
  request_headers['accept-language'] = @client.accept_language unless @client.accept_language.nil?
  path_template = 'subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/microsoft.insights/components/{resourceName}/{scopePath}'

  request_url = @base_url || @client.base_url

  options = {
      middlewares: [[MsRest::RetryPolicyMiddleware, times: 3, retry: 0.02], [:cookie_jar]],
      path_params: {'subscriptionId' => @client.subscription_id,'resourceGroupName' => resource_group_name,'resourceName' => resource_name,'scopePath' => scope_path},
      query_params: {'api-version' => @client.api_version,'scope' => scope,'type' => type,'includeContent' => include_content},
      headers: request_headers.merge(custom_headers || {}),
      base_url: request_url
  }
  promise = @client.make_request_async(:get, path_template, options)

  promise = promise.then do |result|
    http_response = result.response
    status_code = http_response.status
    response_content = http_response.body
    unless status_code == 200
      error_model = JSON.load(response_content)
      fail MsRestAzure::AzureOperationError.new(result.request, http_response, error_model)
    end

    result.request_id = http_response['x-ms-request-id'] unless http_response['x-ms-request-id'].nil?
    result.correlation_request_id = http_response['x-ms-correlation-request-id'] unless http_response['x-ms-correlation-request-id'].nil?
    result.client_request_id = http_response['x-ms-client-request-id'] unless http_response['x-ms-client-request-id'].nil?
    # Deserialize Response
    if status_code == 200
      begin
        parsed_response = response_content.to_s.empty? ? nil : JSON.load(response_content)
        result_mapper = {
          client_side_validation: true,
          required: false,
          serialized_name: 'parsed_response',
          type: {
            name: 'Sequence',
            element: {
                client_side_validation: true,
                required: false,
                serialized_name: 'ApplicationInsightsComponentAnalyticsItemElementType',
                type: {
                  name: 'Composite',
                  class_name: 'ApplicationInsightsComponentAnalyticsItem'
                }
            }
          }
        }
        result.body = @client.deserialize(result_mapper, parsed_response)
      rescue Exception => e
        fail MsRest::DeserializationError.new('Error occurred in deserializing the response', e.message, e.backtrace, result)
      end
    end

    result
  end

  promise.execute
end

#list_with_http_info(resource_group_name, resource_name, scope_path, scope: nil, type: nil, include_content: nil, custom_headers: nil) ⇒ MsRestAzure::AzureOperationResponse

Gets a list of Analytics Items defined within an Application Insights component.

is case insensitive. resource. owned by a specific user or is shared between all users with access to the Application Insights component. Possible values include: 'analyticsItems', 'myanalyticsItems' a specific user or is shared between all users with access to the Application Insights component. Possible values include: 'shared', 'user' item. Possible values include: 'none', 'query', 'function', 'folder', 'recent' content of each applicable item. If false, only return the item information. will be added to the HTTP request.

Parameters:

  • resource_group_name (String)

    The name of the resource group. The name

  • resource_name (String)

    The name of the Application Insights component

  • scope_path (ItemScopePath)

    Enum indicating if this item definition is

  • scope (ItemScope) (defaults to: nil)

    Enum indicating if this item definition is owned by

  • type (ItemTypeParameter) (defaults to: nil)

    Enum indicating the type of the Analytics

  • include_content (Boolean) (defaults to: nil)

    Flag indicating whether or not to return the

  • custom_headers (Hash{String => String}) (defaults to: nil)

    A hash of custom headers that

Returns:

  • (MsRestAzure::AzureOperationResponse)

    HTTP response information.



79
80
81
# File 'lib/2015-05-01/generated/azure_mgmt_monitor/analytics_items.rb', line 79

def list_with_http_info(resource_group_name, resource_name, scope_path, scope:nil, type:nil, include_content:nil, custom_headers:nil)
  list_async(resource_group_name, resource_name, scope_path, scope:scope, type:type, include_content:include_content, custom_headers:custom_headers).value!
end

#put(resource_group_name, resource_name, scope_path, item_properties, override_item: nil, custom_headers: nil) ⇒ ApplicationInsightsComponentAnalyticsItem

Adds or Updates a specific Analytics Item within an Application Insights component.

is case insensitive. resource. owned by a specific user or is shared between all users with access to the Application Insights component. Possible values include: 'analyticsItems', 'myanalyticsItems' that need to be specified to create a new item and add it to an Application Insights component. an item. This allows overriding an item if it already exists. will be added to the HTTP request.

Parameters:

  • resource_group_name (String)

    The name of the resource group. The name

  • resource_name (String)

    The name of the Application Insights component

  • scope_path (ItemScopePath)

    Enum indicating if this item definition is

  • item_properties (ApplicationInsightsComponentAnalyticsItem)

    Properties

  • override_item (Boolean) (defaults to: nil)

    Flag indicating whether or not to force save

  • custom_headers (Hash{String => String}) (defaults to: nil)

    A hash of custom headers that

Returns:

  • (ApplicationInsightsComponentAnalyticsItem)

    operation results.



340
341
342
343
# File 'lib/2015-05-01/generated/azure_mgmt_monitor/analytics_items.rb', line 340

def put(resource_group_name, resource_name, scope_path, item_properties, override_item:nil, custom_headers:nil)
  response = put_async(resource_group_name, resource_name, scope_path, item_properties, override_item:override_item, custom_headers:custom_headers).value!
  response.body unless response.nil?
end

#put_async(resource_group_name, resource_name, scope_path, item_properties, override_item: nil, custom_headers: nil) ⇒ Concurrent::Promise

Adds or Updates a specific Analytics Item within an Application Insights component.

is case insensitive. resource. owned by a specific user or is shared between all users with access to the Application Insights component. Possible values include: 'analyticsItems', 'myanalyticsItems' that need to be specified to create a new item and add it to an Application Insights component. an item. This allows overriding an item if it already exists. to the HTTP request.

Parameters:

  • resource_group_name (String)

    The name of the resource group. The name

  • resource_name (String)

    The name of the Application Insights component

  • scope_path (ItemScopePath)

    Enum indicating if this item definition is

  • item_properties (ApplicationInsightsComponentAnalyticsItem)

    Properties

  • override_item (Boolean) (defaults to: nil)

    Flag indicating whether or not to force save

  • A (Hash{String => String})

    hash of custom headers that will be added

Returns:

  • (Concurrent::Promise)

    Promise object which holds the HTTP response.



393
394
395
396
397
398
399
400
401
402
403
404
405
406
407
408
409
410
411
412
413
414
415
416
417
418
419
420
421
422
423
424
425
426
427
428
429
430
431
432
433
434
435
436
437
438
439
440
441
442
443
444
445
446
447
448
449
450
451
452
453
454
455
456
457
458
459
460
# File 'lib/2015-05-01/generated/azure_mgmt_monitor/analytics_items.rb', line 393

def put_async(resource_group_name, resource_name, scope_path, item_properties, override_item:nil, custom_headers:nil)
  fail ArgumentError, '@client.subscription_id is nil' if @client.subscription_id.nil?
  fail ArgumentError, "'@client.subscription_id' should satisfy the constraint - 'MinLength': '1'" if !@client.subscription_id.nil? && @client.subscription_id.length < 1
  fail ArgumentError, 'resource_group_name is nil' if resource_group_name.nil?
  fail ArgumentError, "'resource_group_name' should satisfy the constraint - 'MaxLength': '90'" if !resource_group_name.nil? && resource_group_name.length > 90
  fail ArgumentError, "'resource_group_name' should satisfy the constraint - 'MinLength': '1'" if !resource_group_name.nil? && resource_group_name.length < 1
  fail ArgumentError, "'resource_group_name' should satisfy the constraint - 'Pattern': '^[-\w\._\(\)]+$'" if !resource_group_name.nil? && resource_group_name.match(Regexp.new('^^[-\w\._\(\)]+$$')).nil?
  fail ArgumentError, 'resource_name is nil' if resource_name.nil?
  fail ArgumentError, 'scope_path is nil' if scope_path.nil?
  fail ArgumentError, '@client.api_version is nil' if @client.api_version.nil?
  fail ArgumentError, "'@client.api_version' should satisfy the constraint - 'MinLength': '1'" if !@client.api_version.nil? && @client.api_version.length < 1
  fail ArgumentError, 'item_properties is nil' if item_properties.nil?


  request_headers = {}
  request_headers['Content-Type'] = 'application/json; charset=utf-8'

  # Set Headers
  request_headers['x-ms-client-request-id'] = SecureRandom.uuid
  request_headers['accept-language'] = @client.accept_language unless @client.accept_language.nil?

  # Serialize Request
  request_mapper = Azure::Monitor::Mgmt::V2015_05_01::Models::ApplicationInsightsComponentAnalyticsItem.mapper()
  request_content = @client.serialize(request_mapper,  item_properties)
  request_content = request_content != nil ? JSON.generate(request_content, quirks_mode: true) : nil

  path_template = 'subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/microsoft.insights/components/{resourceName}/{scopePath}/item'

  request_url = @base_url || @client.base_url

  options = {
      middlewares: [[MsRest::RetryPolicyMiddleware, times: 3, retry: 0.02], [:cookie_jar]],
      path_params: {'subscriptionId' => @client.subscription_id,'resourceGroupName' => resource_group_name,'resourceName' => resource_name,'scopePath' => scope_path},
      query_params: {'api-version' => @client.api_version,'overrideItem' => override_item},
      body: request_content,
      headers: request_headers.merge(custom_headers || {}),
      base_url: request_url
  }
  promise = @client.make_request_async(:put, path_template, options)

  promise = promise.then do |result|
    http_response = result.response
    status_code = http_response.status
    response_content = http_response.body
    unless status_code == 200
      error_model = JSON.load(response_content)
      fail MsRestAzure::AzureOperationError.new(result.request, http_response, error_model)
    end

    result.request_id = http_response['x-ms-request-id'] unless http_response['x-ms-request-id'].nil?
    result.correlation_request_id = http_response['x-ms-correlation-request-id'] unless http_response['x-ms-correlation-request-id'].nil?
    result.client_request_id = http_response['x-ms-client-request-id'] unless http_response['x-ms-client-request-id'].nil?
    # Deserialize Response
    if status_code == 200
      begin
        parsed_response = response_content.to_s.empty? ? nil : JSON.load(response_content)
        result_mapper = Azure::Monitor::Mgmt::V2015_05_01::Models::ApplicationInsightsComponentAnalyticsItem.mapper()
        result.body = @client.deserialize(result_mapper, parsed_response)
      rescue Exception => e
        fail MsRest::DeserializationError.new('Error occurred in deserializing the response', e.message, e.backtrace, result)
      end
    end

    result
  end

  promise.execute
end

#put_with_http_info(resource_group_name, resource_name, scope_path, item_properties, override_item: nil, custom_headers: nil) ⇒ MsRestAzure::AzureOperationResponse

Adds or Updates a specific Analytics Item within an Application Insights component.

is case insensitive. resource. owned by a specific user or is shared between all users with access to the Application Insights component. Possible values include: 'analyticsItems', 'myanalyticsItems' that need to be specified to create a new item and add it to an Application Insights component. an item. This allows overriding an item if it already exists. will be added to the HTTP request.

Parameters:

  • resource_group_name (String)

    The name of the resource group. The name

  • resource_name (String)

    The name of the Application Insights component

  • scope_path (ItemScopePath)

    Enum indicating if this item definition is

  • item_properties (ApplicationInsightsComponentAnalyticsItem)

    Properties

  • override_item (Boolean) (defaults to: nil)

    Flag indicating whether or not to force save

  • custom_headers (Hash{String => String}) (defaults to: nil)

    A hash of custom headers that

Returns:

  • (MsRestAzure::AzureOperationResponse)

    HTTP response information.



367
368
369
# File 'lib/2015-05-01/generated/azure_mgmt_monitor/analytics_items.rb', line 367

def put_with_http_info(resource_group_name, resource_name, scope_path, item_properties, override_item:nil, custom_headers:nil)
  put_async(resource_group_name, resource_name, scope_path, item_properties, override_item:override_item, custom_headers:custom_headers).value!
end