Class: Azure::Monitor::Mgmt::V2015_05_01::Annotations

Inherits:
Object
  • Object
show all
Includes:
MsRestAzure
Defined in:
lib/2015-05-01/generated/azure_mgmt_monitor/annotations.rb

Overview

Composite Swagger for Application Insights Management Client

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(client) ⇒ Annotations

Creates and initializes a new instance of the Annotations class.

Parameters:

  • client

    service class for accessing basic functionality.



17
18
19
# File 'lib/2015-05-01/generated/azure_mgmt_monitor/annotations.rb', line 17

def initialize(client)
  @client = client
end

Instance Attribute Details

#clientApplicationInsightsManagementClient (readonly)

Returns reference to the ApplicationInsightsManagementClient.

Returns:



22
23
24
# File 'lib/2015-05-01/generated/azure_mgmt_monitor/annotations.rb', line 22

def client
  @client
end

Instance Method Details

#create(resource_group_name, resource_name, annotation_properties, custom_headers: nil) ⇒ Array

Create an Annotation of an Application Insights component.

is case insensitive. resource. specified to create an annotation of a Application Insights component. will be added to the HTTP request.

Parameters:

  • resource_group_name (String)

    The name of the resource group. The name

  • resource_name (String)

    The name of the Application Insights component

  • annotation_properties (Annotation)

    Properties that need to be

  • custom_headers (Hash{String => String}) (defaults to: nil)

    A hash of custom headers that

Returns:

  • (Array)

    operation results.



154
155
156
157
# File 'lib/2015-05-01/generated/azure_mgmt_monitor/annotations.rb', line 154

def create(resource_group_name, resource_name, annotation_properties, custom_headers:nil)
  response = create_async(resource_group_name, resource_name, annotation_properties, custom_headers:custom_headers).value!
  response.body unless response.nil?
end

#create_async(resource_group_name, resource_name, annotation_properties, custom_headers: nil) ⇒ Concurrent::Promise

Create an Annotation of an Application Insights component.

is case insensitive. resource. specified to create an annotation of a Application Insights component. to the HTTP request.

Parameters:

  • resource_group_name (String)

    The name of the resource group. The name

  • resource_name (String)

    The name of the Application Insights component

  • annotation_properties (Annotation)

    Properties that need to be

  • A (Hash{String => String})

    hash of custom headers that will be added

Returns:

  • (Concurrent::Promise)

    Promise object which holds the HTTP response.



191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
# File 'lib/2015-05-01/generated/azure_mgmt_monitor/annotations.rb', line 191

def create_async(resource_group_name, resource_name, annotation_properties, custom_headers:nil)
  fail ArgumentError, 'resource_group_name is nil' if resource_group_name.nil?
  fail ArgumentError, "'resource_group_name' should satisfy the constraint - 'MaxLength': '90'" if !resource_group_name.nil? && resource_group_name.length > 90
  fail ArgumentError, "'resource_group_name' should satisfy the constraint - 'MinLength': '1'" if !resource_group_name.nil? && resource_group_name.length < 1
  fail ArgumentError, "'resource_group_name' should satisfy the constraint - 'Pattern': '^[-\w\._\(\)]+$'" if !resource_group_name.nil? && resource_group_name.match(Regexp.new('^^[-\w\._\(\)]+$$')).nil?
  fail ArgumentError, '@client.api_version is nil' if @client.api_version.nil?
  fail ArgumentError, "'@client.api_version' should satisfy the constraint - 'MinLength': '1'" if !@client.api_version.nil? && @client.api_version.length < 1
  fail ArgumentError, '@client.subscription_id is nil' if @client.subscription_id.nil?
  fail ArgumentError, "'@client.subscription_id' should satisfy the constraint - 'MinLength': '1'" if !@client.subscription_id.nil? && @client.subscription_id.length < 1
  fail ArgumentError, 'resource_name is nil' if resource_name.nil?
  fail ArgumentError, 'annotation_properties is nil' if annotation_properties.nil?


  request_headers = {}
  request_headers['Content-Type'] = 'application/json; charset=utf-8'

  # Set Headers
  request_headers['x-ms-client-request-id'] = SecureRandom.uuid
  request_headers['accept-language'] = @client.accept_language unless @client.accept_language.nil?

  # Serialize Request
  request_mapper = Azure::Monitor::Mgmt::V2015_05_01::Models::Annotation.mapper()
  request_content = @client.serialize(request_mapper,  annotation_properties)
  request_content = request_content != nil ? JSON.generate(request_content, quirks_mode: true) : nil

  path_template = 'subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.Insights/components/{resourceName}/Annotations'

  request_url = @base_url || @client.base_url

  options = {
      middlewares: [[MsRest::RetryPolicyMiddleware, times: 3, retry: 0.02], [:cookie_jar]],
      path_params: {'resourceGroupName' => resource_group_name,'subscriptionId' => @client.subscription_id,'resourceName' => resource_name},
      query_params: {'api-version' => @client.api_version},
      body: request_content,
      headers: request_headers.merge(custom_headers || {}),
      base_url: request_url
  }
  promise = @client.make_request_async(:put, path_template, options)

  promise = promise.then do |result|
    http_response = result.response
    status_code = http_response.status
    response_content = http_response.body
    unless status_code == 200
      error_model = JSON.load(response_content)
      fail MsRest::HttpOperationError.new(result.request, http_response, error_model)
    end

    result.request_id = http_response['x-ms-request-id'] unless http_response['x-ms-request-id'].nil?
    result.correlation_request_id = http_response['x-ms-correlation-request-id'] unless http_response['x-ms-correlation-request-id'].nil?
    result.client_request_id = http_response['x-ms-client-request-id'] unless http_response['x-ms-client-request-id'].nil?
    # Deserialize Response
    if status_code == 200
      begin
        parsed_response = response_content.to_s.empty? ? nil : JSON.load(response_content)
        result_mapper = {
          client_side_validation: true,
          required: false,
          serialized_name: 'parsed_response',
          type: {
            name: 'Sequence',
            element: {
                client_side_validation: true,
                required: false,
                serialized_name: 'AnnotationElementType',
                type: {
                  name: 'Composite',
                  class_name: 'Annotation'
                }
            }
          }
        }
        result.body = @client.deserialize(result_mapper, parsed_response)
      rescue Exception => e
        fail MsRest::DeserializationError.new('Error occurred in deserializing the response', e.message, e.backtrace, result)
      end
    end

    result
  end

  promise.execute
end

#create_with_http_info(resource_group_name, resource_name, annotation_properties, custom_headers: nil) ⇒ MsRestAzure::AzureOperationResponse

Create an Annotation of an Application Insights component.

is case insensitive. resource. specified to create an annotation of a Application Insights component. will be added to the HTTP request.

Parameters:

  • resource_group_name (String)

    The name of the resource group. The name

  • resource_name (String)

    The name of the Application Insights component

  • annotation_properties (Annotation)

    Properties that need to be

  • custom_headers (Hash{String => String}) (defaults to: nil)

    A hash of custom headers that

Returns:

  • (MsRestAzure::AzureOperationResponse)

    HTTP response information.



173
174
175
# File 'lib/2015-05-01/generated/azure_mgmt_monitor/annotations.rb', line 173

def create_with_http_info(resource_group_name, resource_name, annotation_properties, custom_headers:nil)
  create_async(resource_group_name, resource_name, annotation_properties, custom_headers:custom_headers).value!
end

#delete(resource_group_name, resource_name, annotation_id, custom_headers: nil) ⇒ Object

Delete an Annotation of an Application Insights component.

is case insensitive. resource. a Application Insights component. will be added to the HTTP request.

Parameters:

  • resource_group_name (String)

    The name of the resource group. The name

  • resource_name (String)

    The name of the Application Insights component

  • annotation_id (String)

    The unique annotation ID. This is unique within

  • custom_headers (Hash{String => String}) (defaults to: nil)

    A hash of custom headers that



288
289
290
291
# File 'lib/2015-05-01/generated/azure_mgmt_monitor/annotations.rb', line 288

def delete(resource_group_name, resource_name, annotation_id, custom_headers:nil)
  response = delete_async(resource_group_name, resource_name, annotation_id, custom_headers:custom_headers).value!
  nil
end

#delete_async(resource_group_name, resource_name, annotation_id, custom_headers: nil) ⇒ Concurrent::Promise

Delete an Annotation of an Application Insights component.

is case insensitive. resource. a Application Insights component. to the HTTP request.

Parameters:

  • resource_group_name (String)

    The name of the resource group. The name

  • resource_name (String)

    The name of the Application Insights component

  • annotation_id (String)

    The unique annotation ID. This is unique within

  • A (Hash{String => String})

    hash of custom headers that will be added

Returns:

  • (Concurrent::Promise)

    Promise object which holds the HTTP response.



325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
# File 'lib/2015-05-01/generated/azure_mgmt_monitor/annotations.rb', line 325

def delete_async(resource_group_name, resource_name, annotation_id, custom_headers:nil)
  fail ArgumentError, 'resource_group_name is nil' if resource_group_name.nil?
  fail ArgumentError, "'resource_group_name' should satisfy the constraint - 'MaxLength': '90'" if !resource_group_name.nil? && resource_group_name.length > 90
  fail ArgumentError, "'resource_group_name' should satisfy the constraint - 'MinLength': '1'" if !resource_group_name.nil? && resource_group_name.length < 1
  fail ArgumentError, "'resource_group_name' should satisfy the constraint - 'Pattern': '^[-\w\._\(\)]+$'" if !resource_group_name.nil? && resource_group_name.match(Regexp.new('^^[-\w\._\(\)]+$$')).nil?
  fail ArgumentError, '@client.api_version is nil' if @client.api_version.nil?
  fail ArgumentError, "'@client.api_version' should satisfy the constraint - 'MinLength': '1'" if !@client.api_version.nil? && @client.api_version.length < 1
  fail ArgumentError, '@client.subscription_id is nil' if @client.subscription_id.nil?
  fail ArgumentError, "'@client.subscription_id' should satisfy the constraint - 'MinLength': '1'" if !@client.subscription_id.nil? && @client.subscription_id.length < 1
  fail ArgumentError, 'resource_name is nil' if resource_name.nil?
  fail ArgumentError, 'annotation_id is nil' if annotation_id.nil?


  request_headers = {}
  request_headers['Content-Type'] = 'application/json; charset=utf-8'

  # Set Headers
  request_headers['x-ms-client-request-id'] = SecureRandom.uuid
  request_headers['accept-language'] = @client.accept_language unless @client.accept_language.nil?
  path_template = 'subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.Insights/components/{resourceName}/Annotations/{annotationId}'

  request_url = @base_url || @client.base_url

  options = {
      middlewares: [[MsRest::RetryPolicyMiddleware, times: 3, retry: 0.02], [:cookie_jar]],
      path_params: {'resourceGroupName' => resource_group_name,'subscriptionId' => @client.subscription_id,'resourceName' => resource_name,'annotationId' => annotation_id},
      query_params: {'api-version' => @client.api_version},
      headers: request_headers.merge(custom_headers || {}),
      base_url: request_url
  }
  promise = @client.make_request_async(:delete, path_template, options)

  promise = promise.then do |result|
    http_response = result.response
    status_code = http_response.status
    response_content = http_response.body
    unless status_code == 200
      error_model = JSON.load(response_content)
      fail MsRestAzure::AzureOperationError.new(result.request, http_response, error_model)
    end

    result.request_id = http_response['x-ms-request-id'] unless http_response['x-ms-request-id'].nil?
    result.correlation_request_id = http_response['x-ms-correlation-request-id'] unless http_response['x-ms-correlation-request-id'].nil?
    result.client_request_id = http_response['x-ms-client-request-id'] unless http_response['x-ms-client-request-id'].nil?

    result
  end

  promise.execute
end

#delete_with_http_info(resource_group_name, resource_name, annotation_id, custom_headers: nil) ⇒ MsRestAzure::AzureOperationResponse

Delete an Annotation of an Application Insights component.

is case insensitive. resource. a Application Insights component. will be added to the HTTP request.

Parameters:

  • resource_group_name (String)

    The name of the resource group. The name

  • resource_name (String)

    The name of the Application Insights component

  • annotation_id (String)

    The unique annotation ID. This is unique within

  • custom_headers (Hash{String => String}) (defaults to: nil)

    A hash of custom headers that

Returns:

  • (MsRestAzure::AzureOperationResponse)

    HTTP response information.



307
308
309
# File 'lib/2015-05-01/generated/azure_mgmt_monitor/annotations.rb', line 307

def delete_with_http_info(resource_group_name, resource_name, annotation_id, custom_headers:nil)
  delete_async(resource_group_name, resource_name, annotation_id, custom_headers:custom_headers).value!
end

#get(resource_group_name, resource_name, annotation_id, custom_headers: nil) ⇒ Array

Get the annotation for given id.

is case insensitive. resource. a Application Insights component. will be added to the HTTP request.

Parameters:

  • resource_group_name (String)

    The name of the resource group. The name

  • resource_name (String)

    The name of the Application Insights component

  • annotation_id (String)

    The unique annotation ID. This is unique within

  • custom_headers (Hash{String => String}) (defaults to: nil)

    A hash of custom headers that

Returns:

  • (Array)

    operation results.



390
391
392
393
# File 'lib/2015-05-01/generated/azure_mgmt_monitor/annotations.rb', line 390

def get(resource_group_name, resource_name, annotation_id, custom_headers:nil)
  response = get_async(resource_group_name, resource_name, annotation_id, custom_headers:custom_headers).value!
  response.body unless response.nil?
end

#get_async(resource_group_name, resource_name, annotation_id, custom_headers: nil) ⇒ Concurrent::Promise

Get the annotation for given id.

is case insensitive. resource. a Application Insights component. to the HTTP request.

Parameters:

  • resource_group_name (String)

    The name of the resource group. The name

  • resource_name (String)

    The name of the Application Insights component

  • annotation_id (String)

    The unique annotation ID. This is unique within

  • A (Hash{String => String})

    hash of custom headers that will be added

Returns:

  • (Concurrent::Promise)

    Promise object which holds the HTTP response.



427
428
429
430
431
432
433
434
435
436
437
438
439
440
441
442
443
444
445
446
447
448
449
450
451
452
453
454
455
456
457
458
459
460
461
462
463
464
465
466
467
468
469
470
471
472
473
474
475
476
477
478
479
480
481
482
483
484
485
486
487
488
489
490
491
492
493
494
495
496
497
498
499
500
501
502
# File 'lib/2015-05-01/generated/azure_mgmt_monitor/annotations.rb', line 427

def get_async(resource_group_name, resource_name, annotation_id, custom_headers:nil)
  fail ArgumentError, 'resource_group_name is nil' if resource_group_name.nil?
  fail ArgumentError, "'resource_group_name' should satisfy the constraint - 'MaxLength': '90'" if !resource_group_name.nil? && resource_group_name.length > 90
  fail ArgumentError, "'resource_group_name' should satisfy the constraint - 'MinLength': '1'" if !resource_group_name.nil? && resource_group_name.length < 1
  fail ArgumentError, "'resource_group_name' should satisfy the constraint - 'Pattern': '^[-\w\._\(\)]+$'" if !resource_group_name.nil? && resource_group_name.match(Regexp.new('^^[-\w\._\(\)]+$$')).nil?
  fail ArgumentError, '@client.api_version is nil' if @client.api_version.nil?
  fail ArgumentError, "'@client.api_version' should satisfy the constraint - 'MinLength': '1'" if !@client.api_version.nil? && @client.api_version.length < 1
  fail ArgumentError, '@client.subscription_id is nil' if @client.subscription_id.nil?
  fail ArgumentError, "'@client.subscription_id' should satisfy the constraint - 'MinLength': '1'" if !@client.subscription_id.nil? && @client.subscription_id.length < 1
  fail ArgumentError, 'resource_name is nil' if resource_name.nil?
  fail ArgumentError, 'annotation_id is nil' if annotation_id.nil?


  request_headers = {}
  request_headers['Content-Type'] = 'application/json; charset=utf-8'

  # Set Headers
  request_headers['x-ms-client-request-id'] = SecureRandom.uuid
  request_headers['accept-language'] = @client.accept_language unless @client.accept_language.nil?
  path_template = 'subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.Insights/components/{resourceName}/Annotations/{annotationId}'

  request_url = @base_url || @client.base_url

  options = {
      middlewares: [[MsRest::RetryPolicyMiddleware, times: 3, retry: 0.02], [:cookie_jar]],
      path_params: {'resourceGroupName' => resource_group_name,'subscriptionId' => @client.subscription_id,'resourceName' => resource_name,'annotationId' => annotation_id},
      query_params: {'api-version' => @client.api_version},
      headers: request_headers.merge(custom_headers || {}),
      base_url: request_url
  }
  promise = @client.make_request_async(:get, path_template, options)

  promise = promise.then do |result|
    http_response = result.response
    status_code = http_response.status
    response_content = http_response.body
    unless status_code == 200
      error_model = JSON.load(response_content)
      fail MsRest::HttpOperationError.new(result.request, http_response, error_model)
    end

    result.request_id = http_response['x-ms-request-id'] unless http_response['x-ms-request-id'].nil?
    result.correlation_request_id = http_response['x-ms-correlation-request-id'] unless http_response['x-ms-correlation-request-id'].nil?
    result.client_request_id = http_response['x-ms-client-request-id'] unless http_response['x-ms-client-request-id'].nil?
    # Deserialize Response
    if status_code == 200
      begin
        parsed_response = response_content.to_s.empty? ? nil : JSON.load(response_content)
        result_mapper = {
          client_side_validation: true,
          required: false,
          serialized_name: 'parsed_response',
          type: {
            name: 'Sequence',
            element: {
                client_side_validation: true,
                required: false,
                serialized_name: 'AnnotationElementType',
                type: {
                  name: 'Composite',
                  class_name: 'Annotation'
                }
            }
          }
        }
        result.body = @client.deserialize(result_mapper, parsed_response)
      rescue Exception => e
        fail MsRest::DeserializationError.new('Error occurred in deserializing the response', e.message, e.backtrace, result)
      end
    end

    result
  end

  promise.execute
end

#get_with_http_info(resource_group_name, resource_name, annotation_id, custom_headers: nil) ⇒ MsRestAzure::AzureOperationResponse

Get the annotation for given id.

is case insensitive. resource. a Application Insights component. will be added to the HTTP request.

Parameters:

  • resource_group_name (String)

    The name of the resource group. The name

  • resource_name (String)

    The name of the Application Insights component

  • annotation_id (String)

    The unique annotation ID. This is unique within

  • custom_headers (Hash{String => String}) (defaults to: nil)

    A hash of custom headers that

Returns:

  • (MsRestAzure::AzureOperationResponse)

    HTTP response information.



409
410
411
# File 'lib/2015-05-01/generated/azure_mgmt_monitor/annotations.rb', line 409

def get_with_http_info(resource_group_name, resource_name, annotation_id, custom_headers:nil)
  get_async(resource_group_name, resource_name, annotation_id, custom_headers:custom_headers).value!
end

#list(resource_group_name, resource_name, start, end_parameter, custom_headers: nil) ⇒ AnnotationsListResult

Gets the list of annotations for a component for given time range

is case insensitive. resource. older than 90 days from current date. will be added to the HTTP request.

Parameters:

  • resource_group_name (String)

    The name of the resource group. The name

  • resource_name (String)

    The name of the Application Insights component

  • start (String)

    The start time to query from for annotations, cannot be

  • end_parameter (String)

    The end time to query for annotations.

  • custom_headers (Hash{String => String}) (defaults to: nil)

    A hash of custom headers that

Returns:

  • (AnnotationsListResult)

    operation results.



39
40
41
42
# File 'lib/2015-05-01/generated/azure_mgmt_monitor/annotations.rb', line 39

def list(resource_group_name, resource_name, start, end_parameter, custom_headers:nil)
  response = list_async(resource_group_name, resource_name, start, end_parameter, custom_headers:custom_headers).value!
  response.body unless response.nil?
end

#list_async(resource_group_name, resource_name, start, end_parameter, custom_headers: nil) ⇒ Concurrent::Promise

Gets the list of annotations for a component for given time range

is case insensitive. resource. older than 90 days from current date. to the HTTP request.

Parameters:

  • resource_group_name (String)

    The name of the resource group. The name

  • resource_name (String)

    The name of the Application Insights component

  • start (String)

    The start time to query from for annotations, cannot be

  • end_parameter (String)

    The end time to query for annotations.

  • A (Hash{String => String})

    hash of custom headers that will be added

Returns:

  • (Concurrent::Promise)

    Promise object which holds the HTTP response.



78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
# File 'lib/2015-05-01/generated/azure_mgmt_monitor/annotations.rb', line 78

def list_async(resource_group_name, resource_name, start, end_parameter, custom_headers:nil)
  fail ArgumentError, 'resource_group_name is nil' if resource_group_name.nil?
  fail ArgumentError, "'resource_group_name' should satisfy the constraint - 'MaxLength': '90'" if !resource_group_name.nil? && resource_group_name.length > 90
  fail ArgumentError, "'resource_group_name' should satisfy the constraint - 'MinLength': '1'" if !resource_group_name.nil? && resource_group_name.length < 1
  fail ArgumentError, "'resource_group_name' should satisfy the constraint - 'Pattern': '^[-\w\._\(\)]+$'" if !resource_group_name.nil? && resource_group_name.match(Regexp.new('^^[-\w\._\(\)]+$$')).nil?
  fail ArgumentError, '@client.api_version is nil' if @client.api_version.nil?
  fail ArgumentError, "'@client.api_version' should satisfy the constraint - 'MinLength': '1'" if !@client.api_version.nil? && @client.api_version.length < 1
  fail ArgumentError, '@client.subscription_id is nil' if @client.subscription_id.nil?
  fail ArgumentError, "'@client.subscription_id' should satisfy the constraint - 'MinLength': '1'" if !@client.subscription_id.nil? && @client.subscription_id.length < 1
  fail ArgumentError, 'resource_name is nil' if resource_name.nil?
  fail ArgumentError, 'start is nil' if start.nil?
  fail ArgumentError, 'end_parameter is nil' if end_parameter.nil?


  request_headers = {}
  request_headers['Content-Type'] = 'application/json; charset=utf-8'

  # Set Headers
  request_headers['x-ms-client-request-id'] = SecureRandom.uuid
  request_headers['accept-language'] = @client.accept_language unless @client.accept_language.nil?
  path_template = 'subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.Insights/components/{resourceName}/Annotations'

  request_url = @base_url || @client.base_url

  options = {
      middlewares: [[MsRest::RetryPolicyMiddleware, times: 3, retry: 0.02], [:cookie_jar]],
      path_params: {'resourceGroupName' => resource_group_name,'subscriptionId' => @client.subscription_id,'resourceName' => resource_name},
      query_params: {'api-version' => @client.api_version,'start' => start,'end' => end_parameter},
      headers: request_headers.merge(custom_headers || {}),
      base_url: request_url
  }
  promise = @client.make_request_async(:get, path_template, options)

  promise = promise.then do |result|
    http_response = result.response
    status_code = http_response.status
    response_content = http_response.body
    unless status_code == 200
      error_model = JSON.load(response_content)
      fail MsRest::HttpOperationError.new(result.request, http_response, error_model)
    end

    result.request_id = http_response['x-ms-request-id'] unless http_response['x-ms-request-id'].nil?
    result.correlation_request_id = http_response['x-ms-correlation-request-id'] unless http_response['x-ms-correlation-request-id'].nil?
    result.client_request_id = http_response['x-ms-client-request-id'] unless http_response['x-ms-client-request-id'].nil?
    # Deserialize Response
    if status_code == 200
      begin
        parsed_response = response_content.to_s.empty? ? nil : JSON.load(response_content)
        result_mapper = Azure::Monitor::Mgmt::V2015_05_01::Models::AnnotationsListResult.mapper()
        result.body = @client.deserialize(result_mapper, parsed_response)
      rescue Exception => e
        fail MsRest::DeserializationError.new('Error occurred in deserializing the response', e.message, e.backtrace, result)
      end
    end

    result
  end

  promise.execute
end

#list_with_http_info(resource_group_name, resource_name, start, end_parameter, custom_headers: nil) ⇒ MsRestAzure::AzureOperationResponse

Gets the list of annotations for a component for given time range

is case insensitive. resource. older than 90 days from current date. will be added to the HTTP request.

Parameters:

  • resource_group_name (String)

    The name of the resource group. The name

  • resource_name (String)

    The name of the Application Insights component

  • start (String)

    The start time to query from for annotations, cannot be

  • end_parameter (String)

    The end time to query for annotations.

  • custom_headers (Hash{String => String}) (defaults to: nil)

    A hash of custom headers that

Returns:

  • (MsRestAzure::AzureOperationResponse)

    HTTP response information.



59
60
61
# File 'lib/2015-05-01/generated/azure_mgmt_monitor/annotations.rb', line 59

def list_with_http_info(resource_group_name, resource_name, start, end_parameter, custom_headers:nil)
  list_async(resource_group_name, resource_name, start, end_parameter, custom_headers:custom_headers).value!
end