Class: Azure::Monitor::Mgmt::V2015_05_01::Components
- Inherits:
-
Object
- Object
- Azure::Monitor::Mgmt::V2015_05_01::Components
- Includes:
- MsRestAzure
- Defined in:
- lib/2015-05-01/generated/azure_mgmt_monitor/components.rb
Overview
Composite Swagger for Application Insights Management Client
Instance Attribute Summary collapse
-
#client ⇒ ApplicationInsightsManagementClient
readonly
Reference to the ApplicationInsightsManagementClient.
Instance Method Summary collapse
-
#create_or_update(resource_group_name, resource_name, insight_properties, custom_headers: nil) ⇒ ApplicationInsightsComponent
Creates (or updates) an Application Insights component.
-
#create_or_update_async(resource_group_name, resource_name, insight_properties, custom_headers: nil) ⇒ Concurrent::Promise
Creates (or updates) an Application Insights component.
-
#create_or_update_with_http_info(resource_group_name, resource_name, insight_properties, custom_headers: nil) ⇒ MsRestAzure::AzureOperationResponse
Creates (or updates) an Application Insights component.
-
#delete(resource_group_name, resource_name, custom_headers: nil) ⇒ Object
Deletes an Application Insights component.
-
#delete_async(resource_group_name, resource_name, custom_headers: nil) ⇒ Concurrent::Promise
Deletes an Application Insights component.
-
#delete_with_http_info(resource_group_name, resource_name, custom_headers: nil) ⇒ MsRestAzure::AzureOperationResponse
Deletes an Application Insights component.
-
#get(resource_group_name, resource_name, custom_headers: nil) ⇒ ApplicationInsightsComponent
Returns an Application Insights component.
-
#get_async(resource_group_name, resource_name, custom_headers: nil) ⇒ Concurrent::Promise
Returns an Application Insights component.
-
#get_purge_status(resource_group_name, resource_name, purge_id, custom_headers: nil) ⇒ ComponentPurgeStatusResponse
Get status for an ongoing purge operation.
-
#get_purge_status_async(resource_group_name, resource_name, purge_id, custom_headers: nil) ⇒ Concurrent::Promise
Get status for an ongoing purge operation.
-
#get_purge_status_with_http_info(resource_group_name, resource_name, purge_id, custom_headers: nil) ⇒ MsRestAzure::AzureOperationResponse
Get status for an ongoing purge operation.
-
#get_with_http_info(resource_group_name, resource_name, custom_headers: nil) ⇒ MsRestAzure::AzureOperationResponse
Returns an Application Insights component.
-
#initialize(client) ⇒ Components
constructor
Creates and initializes a new instance of the Components class.
-
#list(custom_headers: nil) ⇒ Array<ApplicationInsightsComponent>
Gets a list of all Application Insights components within a subscription.
-
#list_as_lazy(custom_headers: nil) ⇒ ApplicationInsightsComponentListResult
Gets a list of all Application Insights components within a subscription.
-
#list_async(custom_headers: nil) ⇒ Concurrent::Promise
Gets a list of all Application Insights components within a subscription.
-
#list_by_resource_group(resource_group_name, custom_headers: nil) ⇒ Array<ApplicationInsightsComponent>
Gets a list of Application Insights components within a resource group.
-
#list_by_resource_group_as_lazy(resource_group_name, custom_headers: nil) ⇒ ApplicationInsightsComponentListResult
Gets a list of Application Insights components within a resource group.
-
#list_by_resource_group_async(resource_group_name, custom_headers: nil) ⇒ Concurrent::Promise
Gets a list of Application Insights components within a resource group.
-
#list_by_resource_group_next(next_page_link, custom_headers: nil) ⇒ ApplicationInsightsComponentListResult
Gets a list of Application Insights components within a resource group.
-
#list_by_resource_group_next_async(next_page_link, custom_headers: nil) ⇒ Concurrent::Promise
Gets a list of Application Insights components within a resource group.
-
#list_by_resource_group_next_with_http_info(next_page_link, custom_headers: nil) ⇒ MsRestAzure::AzureOperationResponse
Gets a list of Application Insights components within a resource group.
-
#list_by_resource_group_with_http_info(resource_group_name, custom_headers: nil) ⇒ MsRestAzure::AzureOperationResponse
Gets a list of Application Insights components within a resource group.
-
#list_next(next_page_link, custom_headers: nil) ⇒ ApplicationInsightsComponentListResult
Gets a list of all Application Insights components within a subscription.
-
#list_next_async(next_page_link, custom_headers: nil) ⇒ Concurrent::Promise
Gets a list of all Application Insights components within a subscription.
-
#list_next_with_http_info(next_page_link, custom_headers: nil) ⇒ MsRestAzure::AzureOperationResponse
Gets a list of all Application Insights components within a subscription.
-
#list_with_http_info(custom_headers: nil) ⇒ MsRestAzure::AzureOperationResponse
Gets a list of all Application Insights components within a subscription.
-
#purge(resource_group_name, resource_name, body, custom_headers: nil) ⇒ ComponentPurgeResponse
Purges data in an Application Insights component by a set of user-defined filters.
-
#purge_async(resource_group_name, resource_name, body, custom_headers: nil) ⇒ Concurrent::Promise
Purges data in an Application Insights component by a set of user-defined filters.
-
#purge_with_http_info(resource_group_name, resource_name, body, custom_headers: nil) ⇒ MsRestAzure::AzureOperationResponse
Purges data in an Application Insights component by a set of user-defined filters.
-
#update_tags(resource_group_name, resource_name, component_tags, custom_headers: nil) ⇒ ApplicationInsightsComponent
Updates an existing component's tags.
-
#update_tags_async(resource_group_name, resource_name, component_tags, custom_headers: nil) ⇒ Concurrent::Promise
Updates an existing component's tags.
-
#update_tags_with_http_info(resource_group_name, resource_name, component_tags, custom_headers: nil) ⇒ MsRestAzure::AzureOperationResponse
Updates an existing component's tags.
Constructor Details
#initialize(client) ⇒ Components
Creates and initializes a new instance of the Components class.
17 18 19 |
# File 'lib/2015-05-01/generated/azure_mgmt_monitor/components.rb', line 17 def initialize(client) @client = client end |
Instance Attribute Details
#client ⇒ ApplicationInsightsManagementClient (readonly)
Returns reference to the ApplicationInsightsManagementClient.
22 23 24 |
# File 'lib/2015-05-01/generated/azure_mgmt_monitor/components.rb', line 22 def client @client end |
Instance Method Details
#create_or_update(resource_group_name, resource_name, insight_properties, custom_headers: nil) ⇒ ApplicationInsightsComponent
Creates (or updates) an Application Insights component. Note: You cannot specify a different value for InstrumentationKey nor AppId in the Put operation.
is case insensitive. resource. to be specified to create an Application Insights component. will be added to the HTTP request.
425 426 427 428 |
# File 'lib/2015-05-01/generated/azure_mgmt_monitor/components.rb', line 425 def create_or_update(resource_group_name, resource_name, insight_properties, custom_headers:nil) response = create_or_update_async(resource_group_name, resource_name, insight_properties, custom_headers:custom_headers).value! response.body unless response.nil? end |
#create_or_update_async(resource_group_name, resource_name, insight_properties, custom_headers: nil) ⇒ Concurrent::Promise
Creates (or updates) an Application Insights component. Note: You cannot specify a different value for InstrumentationKey nor AppId in the Put operation.
is case insensitive. resource. to be specified to create an Application Insights component. to the HTTP request.
466 467 468 469 470 471 472 473 474 475 476 477 478 479 480 481 482 483 484 485 486 487 488 489 490 491 492 493 494 495 496 497 498 499 500 501 502 503 504 505 506 507 508 509 510 511 512 513 514 515 516 517 518 519 520 521 522 523 524 525 526 527 528 529 530 531 532 |
# File 'lib/2015-05-01/generated/azure_mgmt_monitor/components.rb', line 466 def create_or_update_async(resource_group_name, resource_name, insight_properties, custom_headers:nil) fail ArgumentError, 'resource_group_name is nil' if resource_group_name.nil? fail ArgumentError, "'resource_group_name' should satisfy the constraint - 'MaxLength': '90'" if !resource_group_name.nil? && resource_group_name.length > 90 fail ArgumentError, "'resource_group_name' should satisfy the constraint - 'MinLength': '1'" if !resource_group_name.nil? && resource_group_name.length < 1 fail ArgumentError, "'resource_group_name' should satisfy the constraint - 'Pattern': '^[-\w\._\(\)]+$'" if !resource_group_name.nil? && resource_group_name.match(Regexp.new('^^[-\w\._\(\)]+$$')).nil? fail ArgumentError, '@client.api_version is nil' if @client.api_version.nil? fail ArgumentError, "'@client.api_version' should satisfy the constraint - 'MinLength': '1'" if !@client.api_version.nil? && @client.api_version.length < 1 fail ArgumentError, '@client.subscription_id is nil' if @client.subscription_id.nil? fail ArgumentError, "'@client.subscription_id' should satisfy the constraint - 'MinLength': '1'" if !@client.subscription_id.nil? && @client.subscription_id.length < 1 fail ArgumentError, 'resource_name is nil' if resource_name.nil? fail ArgumentError, 'insight_properties is nil' if insight_properties.nil? request_headers = {} request_headers['Content-Type'] = 'application/json; charset=utf-8' # Set Headers request_headers['x-ms-client-request-id'] = SecureRandom.uuid request_headers['accept-language'] = @client.accept_language unless @client.accept_language.nil? # Serialize Request request_mapper = Azure::Monitor::Mgmt::V2015_05_01::Models::ApplicationInsightsComponent.mapper() request_content = @client.serialize(request_mapper, insight_properties) request_content = request_content != nil ? JSON.generate(request_content, quirks_mode: true) : nil path_template = 'subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.Insights/components/{resourceName}' request_url = @base_url || @client.base_url = { middlewares: [[MsRest::RetryPolicyMiddleware, times: 3, retry: 0.02], [:cookie_jar]], path_params: {'resourceGroupName' => resource_group_name,'subscriptionId' => @client.subscription_id,'resourceName' => resource_name}, query_params: {'api-version' => @client.api_version}, body: request_content, headers: request_headers.merge(custom_headers || {}), base_url: request_url } promise = @client.make_request_async(:put, path_template, ) promise = promise.then do |result| http_response = result.response status_code = http_response.status response_content = http_response.body unless status_code == 200 error_model = JSON.load(response_content) fail MsRestAzure::AzureOperationError.new(result.request, http_response, error_model) end result.request_id = http_response['x-ms-request-id'] unless http_response['x-ms-request-id'].nil? result.correlation_request_id = http_response['x-ms-correlation-request-id'] unless http_response['x-ms-correlation-request-id'].nil? result.client_request_id = http_response['x-ms-client-request-id'] unless http_response['x-ms-client-request-id'].nil? # Deserialize Response if status_code == 200 begin parsed_response = response_content.to_s.empty? ? nil : JSON.load(response_content) result_mapper = Azure::Monitor::Mgmt::V2015_05_01::Models::ApplicationInsightsComponent.mapper() result.body = @client.deserialize(result_mapper, parsed_response) rescue Exception => e fail MsRest::DeserializationError.new('Error occurred in deserializing the response', e., e.backtrace, result) end end result end promise.execute end |
#create_or_update_with_http_info(resource_group_name, resource_name, insight_properties, custom_headers: nil) ⇒ MsRestAzure::AzureOperationResponse
Creates (or updates) an Application Insights component. Note: You cannot specify a different value for InstrumentationKey nor AppId in the Put operation.
is case insensitive. resource. to be specified to create an Application Insights component. will be added to the HTTP request.
446 447 448 |
# File 'lib/2015-05-01/generated/azure_mgmt_monitor/components.rb', line 446 def create_or_update_with_http_info(resource_group_name, resource_name, insight_properties, custom_headers:nil) create_or_update_async(resource_group_name, resource_name, insight_properties, custom_headers:custom_headers).value! end |
#delete(resource_group_name, resource_name, custom_headers: nil) ⇒ Object
Deletes an Application Insights component.
is case insensitive. resource. will be added to the HTTP request.
221 222 223 224 |
# File 'lib/2015-05-01/generated/azure_mgmt_monitor/components.rb', line 221 def delete(resource_group_name, resource_name, custom_headers:nil) response = delete_async(resource_group_name, resource_name, custom_headers:custom_headers).value! nil end |
#delete_async(resource_group_name, resource_name, custom_headers: nil) ⇒ Concurrent::Promise
Deletes an Application Insights component.
is case insensitive. resource. to the HTTP request.
254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 |
# File 'lib/2015-05-01/generated/azure_mgmt_monitor/components.rb', line 254 def delete_async(resource_group_name, resource_name, custom_headers:nil) fail ArgumentError, 'resource_group_name is nil' if resource_group_name.nil? fail ArgumentError, "'resource_group_name' should satisfy the constraint - 'MaxLength': '90'" if !resource_group_name.nil? && resource_group_name.length > 90 fail ArgumentError, "'resource_group_name' should satisfy the constraint - 'MinLength': '1'" if !resource_group_name.nil? && resource_group_name.length < 1 fail ArgumentError, "'resource_group_name' should satisfy the constraint - 'Pattern': '^[-\w\._\(\)]+$'" if !resource_group_name.nil? && resource_group_name.match(Regexp.new('^^[-\w\._\(\)]+$$')).nil? fail ArgumentError, '@client.api_version is nil' if @client.api_version.nil? fail ArgumentError, "'@client.api_version' should satisfy the constraint - 'MinLength': '1'" if !@client.api_version.nil? && @client.api_version.length < 1 fail ArgumentError, '@client.subscription_id is nil' if @client.subscription_id.nil? fail ArgumentError, "'@client.subscription_id' should satisfy the constraint - 'MinLength': '1'" if !@client.subscription_id.nil? && @client.subscription_id.length < 1 fail ArgumentError, 'resource_name is nil' if resource_name.nil? request_headers = {} request_headers['Content-Type'] = 'application/json; charset=utf-8' # Set Headers request_headers['x-ms-client-request-id'] = SecureRandom.uuid request_headers['accept-language'] = @client.accept_language unless @client.accept_language.nil? path_template = 'subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.Insights/components/{resourceName}' request_url = @base_url || @client.base_url = { middlewares: [[MsRest::RetryPolicyMiddleware, times: 3, retry: 0.02], [:cookie_jar]], path_params: {'resourceGroupName' => resource_group_name,'subscriptionId' => @client.subscription_id,'resourceName' => resource_name}, query_params: {'api-version' => @client.api_version}, headers: request_headers.merge(custom_headers || {}), base_url: request_url } promise = @client.make_request_async(:delete, path_template, ) promise = promise.then do |result| http_response = result.response status_code = http_response.status response_content = http_response.body unless status_code == 200 || status_code == 204 error_model = JSON.load(response_content) fail MsRestAzure::AzureOperationError.new(result.request, http_response, error_model) end result.request_id = http_response['x-ms-request-id'] unless http_response['x-ms-request-id'].nil? result.correlation_request_id = http_response['x-ms-correlation-request-id'] unless http_response['x-ms-correlation-request-id'].nil? result.client_request_id = http_response['x-ms-client-request-id'] unless http_response['x-ms-client-request-id'].nil? result end promise.execute end |
#delete_with_http_info(resource_group_name, resource_name, custom_headers: nil) ⇒ MsRestAzure::AzureOperationResponse
Deletes an Application Insights component.
is case insensitive. resource. will be added to the HTTP request.
238 239 240 |
# File 'lib/2015-05-01/generated/azure_mgmt_monitor/components.rb', line 238 def delete_with_http_info(resource_group_name, resource_name, custom_headers:nil) delete_async(resource_group_name, resource_name, custom_headers:custom_headers).value! end |
#get(resource_group_name, resource_name, custom_headers: nil) ⇒ ApplicationInsightsComponent
Returns an Application Insights component.
is case insensitive. resource. will be added to the HTTP request.
316 317 318 319 |
# File 'lib/2015-05-01/generated/azure_mgmt_monitor/components.rb', line 316 def get(resource_group_name, resource_name, custom_headers:nil) response = get_async(resource_group_name, resource_name, custom_headers:custom_headers).value! response.body unless response.nil? end |
#get_async(resource_group_name, resource_name, custom_headers: nil) ⇒ Concurrent::Promise
Returns an Application Insights component.
is case insensitive. resource. to the HTTP request.
349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 397 398 399 400 401 402 403 404 405 406 407 |
# File 'lib/2015-05-01/generated/azure_mgmt_monitor/components.rb', line 349 def get_async(resource_group_name, resource_name, custom_headers:nil) fail ArgumentError, 'resource_group_name is nil' if resource_group_name.nil? fail ArgumentError, "'resource_group_name' should satisfy the constraint - 'MaxLength': '90'" if !resource_group_name.nil? && resource_group_name.length > 90 fail ArgumentError, "'resource_group_name' should satisfy the constraint - 'MinLength': '1'" if !resource_group_name.nil? && resource_group_name.length < 1 fail ArgumentError, "'resource_group_name' should satisfy the constraint - 'Pattern': '^[-\w\._\(\)]+$'" if !resource_group_name.nil? && resource_group_name.match(Regexp.new('^^[-\w\._\(\)]+$$')).nil? fail ArgumentError, '@client.api_version is nil' if @client.api_version.nil? fail ArgumentError, "'@client.api_version' should satisfy the constraint - 'MinLength': '1'" if !@client.api_version.nil? && @client.api_version.length < 1 fail ArgumentError, '@client.subscription_id is nil' if @client.subscription_id.nil? fail ArgumentError, "'@client.subscription_id' should satisfy the constraint - 'MinLength': '1'" if !@client.subscription_id.nil? && @client.subscription_id.length < 1 fail ArgumentError, 'resource_name is nil' if resource_name.nil? request_headers = {} request_headers['Content-Type'] = 'application/json; charset=utf-8' # Set Headers request_headers['x-ms-client-request-id'] = SecureRandom.uuid request_headers['accept-language'] = @client.accept_language unless @client.accept_language.nil? path_template = 'subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.Insights/components/{resourceName}' request_url = @base_url || @client.base_url = { middlewares: [[MsRest::RetryPolicyMiddleware, times: 3, retry: 0.02], [:cookie_jar]], path_params: {'resourceGroupName' => resource_group_name,'subscriptionId' => @client.subscription_id,'resourceName' => resource_name}, query_params: {'api-version' => @client.api_version}, headers: request_headers.merge(custom_headers || {}), base_url: request_url } promise = @client.make_request_async(:get, path_template, ) promise = promise.then do |result| http_response = result.response status_code = http_response.status response_content = http_response.body unless status_code == 200 error_model = JSON.load(response_content) fail MsRestAzure::AzureOperationError.new(result.request, http_response, error_model) end result.request_id = http_response['x-ms-request-id'] unless http_response['x-ms-request-id'].nil? result.correlation_request_id = http_response['x-ms-correlation-request-id'] unless http_response['x-ms-correlation-request-id'].nil? result.client_request_id = http_response['x-ms-client-request-id'] unless http_response['x-ms-client-request-id'].nil? # Deserialize Response if status_code == 200 begin parsed_response = response_content.to_s.empty? ? nil : JSON.load(response_content) result_mapper = Azure::Monitor::Mgmt::V2015_05_01::Models::ApplicationInsightsComponent.mapper() result.body = @client.deserialize(result_mapper, parsed_response) rescue Exception => e fail MsRest::DeserializationError.new('Error occurred in deserializing the response', e., e.backtrace, result) end end result end promise.execute end |
#get_purge_status(resource_group_name, resource_name, purge_id, custom_headers: nil) ⇒ ComponentPurgeStatusResponse
Get status for an ongoing purge operation.
is case insensitive. resource. operation the status of which is returned. will be added to the HTTP request.
813 814 815 816 |
# File 'lib/2015-05-01/generated/azure_mgmt_monitor/components.rb', line 813 def get_purge_status(resource_group_name, resource_name, purge_id, custom_headers:nil) response = get_purge_status_async(resource_group_name, resource_name, purge_id, custom_headers:custom_headers).value! response.body unless response.nil? end |
#get_purge_status_async(resource_group_name, resource_name, purge_id, custom_headers: nil) ⇒ Concurrent::Promise
Get status for an ongoing purge operation.
is case insensitive. resource. operation the status of which is returned. to the HTTP request.
850 851 852 853 854 855 856 857 858 859 860 861 862 863 864 865 866 867 868 869 870 871 872 873 874 875 876 877 878 879 880 881 882 883 884 885 886 887 888 889 890 891 892 893 894 895 896 897 898 899 900 901 902 903 904 905 906 907 908 909 |
# File 'lib/2015-05-01/generated/azure_mgmt_monitor/components.rb', line 850 def get_purge_status_async(resource_group_name, resource_name, purge_id, custom_headers:nil) fail ArgumentError, 'resource_group_name is nil' if resource_group_name.nil? fail ArgumentError, "'resource_group_name' should satisfy the constraint - 'MaxLength': '90'" if !resource_group_name.nil? && resource_group_name.length > 90 fail ArgumentError, "'resource_group_name' should satisfy the constraint - 'MinLength': '1'" if !resource_group_name.nil? && resource_group_name.length < 1 fail ArgumentError, "'resource_group_name' should satisfy the constraint - 'Pattern': '^[-\w\._\(\)]+$'" if !resource_group_name.nil? && resource_group_name.match(Regexp.new('^^[-\w\._\(\)]+$$')).nil? fail ArgumentError, '@client.api_version is nil' if @client.api_version.nil? fail ArgumentError, "'@client.api_version' should satisfy the constraint - 'MinLength': '1'" if !@client.api_version.nil? && @client.api_version.length < 1 fail ArgumentError, '@client.subscription_id is nil' if @client.subscription_id.nil? fail ArgumentError, "'@client.subscription_id' should satisfy the constraint - 'MinLength': '1'" if !@client.subscription_id.nil? && @client.subscription_id.length < 1 fail ArgumentError, 'resource_name is nil' if resource_name.nil? fail ArgumentError, 'purge_id is nil' if purge_id.nil? request_headers = {} request_headers['Content-Type'] = 'application/json; charset=utf-8' # Set Headers request_headers['x-ms-client-request-id'] = SecureRandom.uuid request_headers['accept-language'] = @client.accept_language unless @client.accept_language.nil? path_template = 'subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.Insights/components/{resourceName}/operations/{purgeId}' request_url = @base_url || @client.base_url = { middlewares: [[MsRest::RetryPolicyMiddleware, times: 3, retry: 0.02], [:cookie_jar]], path_params: {'resourceGroupName' => resource_group_name,'subscriptionId' => @client.subscription_id,'resourceName' => resource_name,'purgeId' => purge_id}, query_params: {'api-version' => @client.api_version}, headers: request_headers.merge(custom_headers || {}), base_url: request_url } promise = @client.make_request_async(:get, path_template, ) promise = promise.then do |result| http_response = result.response status_code = http_response.status response_content = http_response.body unless status_code == 200 error_model = JSON.load(response_content) fail MsRestAzure::AzureOperationError.new(result.request, http_response, error_model) end result.request_id = http_response['x-ms-request-id'] unless http_response['x-ms-request-id'].nil? result.correlation_request_id = http_response['x-ms-correlation-request-id'] unless http_response['x-ms-correlation-request-id'].nil? result.client_request_id = http_response['x-ms-client-request-id'] unless http_response['x-ms-client-request-id'].nil? # Deserialize Response if status_code == 200 begin parsed_response = response_content.to_s.empty? ? nil : JSON.load(response_content) result_mapper = Azure::Monitor::Mgmt::V2015_05_01::Models::ComponentPurgeStatusResponse.mapper() result.body = @client.deserialize(result_mapper, parsed_response) rescue Exception => e fail MsRest::DeserializationError.new('Error occurred in deserializing the response', e., e.backtrace, result) end end result end promise.execute end |
#get_purge_status_with_http_info(resource_group_name, resource_name, purge_id, custom_headers: nil) ⇒ MsRestAzure::AzureOperationResponse
Get status for an ongoing purge operation.
is case insensitive. resource. operation the status of which is returned. will be added to the HTTP request.
832 833 834 |
# File 'lib/2015-05-01/generated/azure_mgmt_monitor/components.rb', line 832 def get_purge_status_with_http_info(resource_group_name, resource_name, purge_id, custom_headers:nil) get_purge_status_async(resource_group_name, resource_name, purge_id, custom_headers:custom_headers).value! end |
#get_with_http_info(resource_group_name, resource_name, custom_headers: nil) ⇒ MsRestAzure::AzureOperationResponse
Returns an Application Insights component.
is case insensitive. resource. will be added to the HTTP request.
333 334 335 |
# File 'lib/2015-05-01/generated/azure_mgmt_monitor/components.rb', line 333 def get_with_http_info(resource_group_name, resource_name, custom_headers:nil) get_async(resource_group_name, resource_name, custom_headers:custom_headers).value! end |
#list(custom_headers: nil) ⇒ Array<ApplicationInsightsComponent>
Gets a list of all Application Insights components within a subscription.
will be added to the HTTP request.
32 33 34 35 |
# File 'lib/2015-05-01/generated/azure_mgmt_monitor/components.rb', line 32 def list(custom_headers:nil) first_page = list_as_lazy(custom_headers:custom_headers) first_page.get_all_items end |
#list_as_lazy(custom_headers: nil) ⇒ ApplicationInsightsComponentListResult
Gets a list of all Application Insights components within a subscription.
will be added to the HTTP request.
pages of the response.
1100 1101 1102 1103 1104 1105 1106 1107 1108 1109 |
# File 'lib/2015-05-01/generated/azure_mgmt_monitor/components.rb', line 1100 def list_as_lazy(custom_headers:nil) response = list_async(custom_headers:custom_headers).value! unless response.nil? page = response.body page.next_method = Proc.new do |next_page_link| list_next_async(next_page_link, custom_headers:custom_headers) end page end end |
#list_async(custom_headers: nil) ⇒ Concurrent::Promise
Gets a list of all Application Insights components within a subscription.
to the HTTP request.
57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 |
# File 'lib/2015-05-01/generated/azure_mgmt_monitor/components.rb', line 57 def list_async(custom_headers:nil) fail ArgumentError, '@client.api_version is nil' if @client.api_version.nil? fail ArgumentError, "'@client.api_version' should satisfy the constraint - 'MinLength': '1'" if !@client.api_version.nil? && @client.api_version.length < 1 fail ArgumentError, '@client.subscription_id is nil' if @client.subscription_id.nil? fail ArgumentError, "'@client.subscription_id' should satisfy the constraint - 'MinLength': '1'" if !@client.subscription_id.nil? && @client.subscription_id.length < 1 request_headers = {} request_headers['Content-Type'] = 'application/json; charset=utf-8' # Set Headers request_headers['x-ms-client-request-id'] = SecureRandom.uuid request_headers['accept-language'] = @client.accept_language unless @client.accept_language.nil? path_template = 'subscriptions/{subscriptionId}/providers/Microsoft.Insights/components' request_url = @base_url || @client.base_url = { middlewares: [[MsRest::RetryPolicyMiddleware, times: 3, retry: 0.02], [:cookie_jar]], path_params: {'subscriptionId' => @client.subscription_id}, query_params: {'api-version' => @client.api_version}, headers: request_headers.merge(custom_headers || {}), base_url: request_url } promise = @client.make_request_async(:get, path_template, ) promise = promise.then do |result| http_response = result.response status_code = http_response.status response_content = http_response.body unless status_code == 200 error_model = JSON.load(response_content) fail MsRestAzure::AzureOperationError.new(result.request, http_response, error_model) end result.request_id = http_response['x-ms-request-id'] unless http_response['x-ms-request-id'].nil? result.correlation_request_id = http_response['x-ms-correlation-request-id'] unless http_response['x-ms-correlation-request-id'].nil? result.client_request_id = http_response['x-ms-client-request-id'] unless http_response['x-ms-client-request-id'].nil? # Deserialize Response if status_code == 200 begin parsed_response = response_content.to_s.empty? ? nil : JSON.load(response_content) result_mapper = Azure::Monitor::Mgmt::V2015_05_01::Models::ApplicationInsightsComponentListResult.mapper() result.body = @client.deserialize(result_mapper, parsed_response) rescue Exception => e fail MsRest::DeserializationError.new('Error occurred in deserializing the response', e., e.backtrace, result) end end result end promise.execute end |
#list_by_resource_group(resource_group_name, custom_headers: nil) ⇒ Array<ApplicationInsightsComponent>
Gets a list of Application Insights components within a resource group.
is case insensitive. will be added to the HTTP request.
122 123 124 125 |
# File 'lib/2015-05-01/generated/azure_mgmt_monitor/components.rb', line 122 def list_by_resource_group(resource_group_name, custom_headers:nil) first_page = list_by_resource_group_as_lazy(resource_group_name, custom_headers:custom_headers) first_page.get_all_items end |
#list_by_resource_group_as_lazy(resource_group_name, custom_headers: nil) ⇒ ApplicationInsightsComponentListResult
Gets a list of Application Insights components within a resource group.
is case insensitive. will be added to the HTTP request.
pages of the response.
1122 1123 1124 1125 1126 1127 1128 1129 1130 1131 |
# File 'lib/2015-05-01/generated/azure_mgmt_monitor/components.rb', line 1122 def list_by_resource_group_as_lazy(resource_group_name, custom_headers:nil) response = list_by_resource_group_async(resource_group_name, custom_headers:custom_headers).value! unless response.nil? page = response.body page.next_method = Proc.new do |next_page_link| list_by_resource_group_next_async(next_page_link, custom_headers:custom_headers) end page end end |
#list_by_resource_group_async(resource_group_name, custom_headers: nil) ⇒ Concurrent::Promise
Gets a list of Application Insights components within a resource group.
is case insensitive. to the HTTP request.
151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 |
# File 'lib/2015-05-01/generated/azure_mgmt_monitor/components.rb', line 151 def list_by_resource_group_async(resource_group_name, custom_headers:nil) fail ArgumentError, 'resource_group_name is nil' if resource_group_name.nil? fail ArgumentError, "'resource_group_name' should satisfy the constraint - 'MaxLength': '90'" if !resource_group_name.nil? && resource_group_name.length > 90 fail ArgumentError, "'resource_group_name' should satisfy the constraint - 'MinLength': '1'" if !resource_group_name.nil? && resource_group_name.length < 1 fail ArgumentError, "'resource_group_name' should satisfy the constraint - 'Pattern': '^[-\w\._\(\)]+$'" if !resource_group_name.nil? && resource_group_name.match(Regexp.new('^^[-\w\._\(\)]+$$')).nil? fail ArgumentError, '@client.api_version is nil' if @client.api_version.nil? fail ArgumentError, "'@client.api_version' should satisfy the constraint - 'MinLength': '1'" if !@client.api_version.nil? && @client.api_version.length < 1 fail ArgumentError, '@client.subscription_id is nil' if @client.subscription_id.nil? fail ArgumentError, "'@client.subscription_id' should satisfy the constraint - 'MinLength': '1'" if !@client.subscription_id.nil? && @client.subscription_id.length < 1 request_headers = {} request_headers['Content-Type'] = 'application/json; charset=utf-8' # Set Headers request_headers['x-ms-client-request-id'] = SecureRandom.uuid request_headers['accept-language'] = @client.accept_language unless @client.accept_language.nil? path_template = 'subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.Insights/components' request_url = @base_url || @client.base_url = { middlewares: [[MsRest::RetryPolicyMiddleware, times: 3, retry: 0.02], [:cookie_jar]], path_params: {'resourceGroupName' => resource_group_name,'subscriptionId' => @client.subscription_id}, query_params: {'api-version' => @client.api_version}, headers: request_headers.merge(custom_headers || {}), base_url: request_url } promise = @client.make_request_async(:get, path_template, ) promise = promise.then do |result| http_response = result.response status_code = http_response.status response_content = http_response.body unless status_code == 200 error_model = JSON.load(response_content) fail MsRestAzure::AzureOperationError.new(result.request, http_response, error_model) end result.request_id = http_response['x-ms-request-id'] unless http_response['x-ms-request-id'].nil? result.correlation_request_id = http_response['x-ms-correlation-request-id'] unless http_response['x-ms-correlation-request-id'].nil? result.client_request_id = http_response['x-ms-client-request-id'] unless http_response['x-ms-client-request-id'].nil? # Deserialize Response if status_code == 200 begin parsed_response = response_content.to_s.empty? ? nil : JSON.load(response_content) result_mapper = Azure::Monitor::Mgmt::V2015_05_01::Models::ApplicationInsightsComponentListResult.mapper() result.body = @client.deserialize(result_mapper, parsed_response) rescue Exception => e fail MsRest::DeserializationError.new('Error occurred in deserializing the response', e., e.backtrace, result) end end result end promise.execute end |
#list_by_resource_group_next(next_page_link, custom_headers: nil) ⇒ ApplicationInsightsComponentListResult
Gets a list of Application Insights components within a resource group.
to List operation. will be added to the HTTP request.
1011 1012 1013 1014 |
# File 'lib/2015-05-01/generated/azure_mgmt_monitor/components.rb', line 1011 def list_by_resource_group_next(next_page_link, custom_headers:nil) response = list_by_resource_group_next_async(next_page_link, custom_headers:custom_headers).value! response.body unless response.nil? end |
#list_by_resource_group_next_async(next_page_link, custom_headers: nil) ⇒ Concurrent::Promise
Gets a list of Application Insights components within a resource group.
to List operation. to the HTTP request.
1040 1041 1042 1043 1044 1045 1046 1047 1048 1049 1050 1051 1052 1053 1054 1055 1056 1057 1058 1059 1060 1061 1062 1063 1064 1065 1066 1067 1068 1069 1070 1071 1072 1073 1074 1075 1076 1077 1078 1079 1080 1081 1082 1083 1084 1085 1086 1087 1088 1089 |
# File 'lib/2015-05-01/generated/azure_mgmt_monitor/components.rb', line 1040 def list_by_resource_group_next_async(next_page_link, custom_headers:nil) fail ArgumentError, 'next_page_link is nil' if next_page_link.nil? request_headers = {} request_headers['Content-Type'] = 'application/json; charset=utf-8' # Set Headers request_headers['x-ms-client-request-id'] = SecureRandom.uuid request_headers['accept-language'] = @client.accept_language unless @client.accept_language.nil? path_template = '{nextLink}' request_url = @base_url || @client.base_url = { middlewares: [[MsRest::RetryPolicyMiddleware, times: 3, retry: 0.02], [:cookie_jar]], skip_encoding_path_params: {'nextLink' => next_page_link}, headers: request_headers.merge(custom_headers || {}), base_url: request_url } promise = @client.make_request_async(:get, path_template, ) promise = promise.then do |result| http_response = result.response status_code = http_response.status response_content = http_response.body unless status_code == 200 error_model = JSON.load(response_content) fail MsRestAzure::AzureOperationError.new(result.request, http_response, error_model) end result.request_id = http_response['x-ms-request-id'] unless http_response['x-ms-request-id'].nil? result.correlation_request_id = http_response['x-ms-correlation-request-id'] unless http_response['x-ms-correlation-request-id'].nil? result.client_request_id = http_response['x-ms-client-request-id'] unless http_response['x-ms-client-request-id'].nil? # Deserialize Response if status_code == 200 begin parsed_response = response_content.to_s.empty? ? nil : JSON.load(response_content) result_mapper = Azure::Monitor::Mgmt::V2015_05_01::Models::ApplicationInsightsComponentListResult.mapper() result.body = @client.deserialize(result_mapper, parsed_response) rescue Exception => e fail MsRest::DeserializationError.new('Error occurred in deserializing the response', e., e.backtrace, result) end end result end promise.execute end |
#list_by_resource_group_next_with_http_info(next_page_link, custom_headers: nil) ⇒ MsRestAzure::AzureOperationResponse
Gets a list of Application Insights components within a resource group.
to List operation. will be added to the HTTP request.
1026 1027 1028 |
# File 'lib/2015-05-01/generated/azure_mgmt_monitor/components.rb', line 1026 def list_by_resource_group_next_with_http_info(next_page_link, custom_headers:nil) list_by_resource_group_next_async(next_page_link, custom_headers:custom_headers).value! end |
#list_by_resource_group_with_http_info(resource_group_name, custom_headers: nil) ⇒ MsRestAzure::AzureOperationResponse
Gets a list of Application Insights components within a resource group.
is case insensitive. will be added to the HTTP request.
137 138 139 |
# File 'lib/2015-05-01/generated/azure_mgmt_monitor/components.rb', line 137 def list_by_resource_group_with_http_info(resource_group_name, custom_headers:nil) list_by_resource_group_async(resource_group_name, custom_headers:custom_headers).value! end |
#list_next(next_page_link, custom_headers: nil) ⇒ ApplicationInsightsComponentListResult
Gets a list of all Application Insights components within a subscription.
to List operation. will be added to the HTTP request.
921 922 923 924 |
# File 'lib/2015-05-01/generated/azure_mgmt_monitor/components.rb', line 921 def list_next(next_page_link, custom_headers:nil) response = list_next_async(next_page_link, custom_headers:custom_headers).value! response.body unless response.nil? end |
#list_next_async(next_page_link, custom_headers: nil) ⇒ Concurrent::Promise
Gets a list of all Application Insights components within a subscription.
to List operation. to the HTTP request.
950 951 952 953 954 955 956 957 958 959 960 961 962 963 964 965 966 967 968 969 970 971 972 973 974 975 976 977 978 979 980 981 982 983 984 985 986 987 988 989 990 991 992 993 994 995 996 997 998 999 |
# File 'lib/2015-05-01/generated/azure_mgmt_monitor/components.rb', line 950 def list_next_async(next_page_link, custom_headers:nil) fail ArgumentError, 'next_page_link is nil' if next_page_link.nil? request_headers = {} request_headers['Content-Type'] = 'application/json; charset=utf-8' # Set Headers request_headers['x-ms-client-request-id'] = SecureRandom.uuid request_headers['accept-language'] = @client.accept_language unless @client.accept_language.nil? path_template = '{nextLink}' request_url = @base_url || @client.base_url = { middlewares: [[MsRest::RetryPolicyMiddleware, times: 3, retry: 0.02], [:cookie_jar]], skip_encoding_path_params: {'nextLink' => next_page_link}, headers: request_headers.merge(custom_headers || {}), base_url: request_url } promise = @client.make_request_async(:get, path_template, ) promise = promise.then do |result| http_response = result.response status_code = http_response.status response_content = http_response.body unless status_code == 200 error_model = JSON.load(response_content) fail MsRestAzure::AzureOperationError.new(result.request, http_response, error_model) end result.request_id = http_response['x-ms-request-id'] unless http_response['x-ms-request-id'].nil? result.correlation_request_id = http_response['x-ms-correlation-request-id'] unless http_response['x-ms-correlation-request-id'].nil? result.client_request_id = http_response['x-ms-client-request-id'] unless http_response['x-ms-client-request-id'].nil? # Deserialize Response if status_code == 200 begin parsed_response = response_content.to_s.empty? ? nil : JSON.load(response_content) result_mapper = Azure::Monitor::Mgmt::V2015_05_01::Models::ApplicationInsightsComponentListResult.mapper() result.body = @client.deserialize(result_mapper, parsed_response) rescue Exception => e fail MsRest::DeserializationError.new('Error occurred in deserializing the response', e., e.backtrace, result) end end result end promise.execute end |
#list_next_with_http_info(next_page_link, custom_headers: nil) ⇒ MsRestAzure::AzureOperationResponse
Gets a list of all Application Insights components within a subscription.
to List operation. will be added to the HTTP request.
936 937 938 |
# File 'lib/2015-05-01/generated/azure_mgmt_monitor/components.rb', line 936 def list_next_with_http_info(next_page_link, custom_headers:nil) list_next_async(next_page_link, custom_headers:custom_headers).value! end |
#list_with_http_info(custom_headers: nil) ⇒ MsRestAzure::AzureOperationResponse
Gets a list of all Application Insights components within a subscription.
will be added to the HTTP request.
45 46 47 |
# File 'lib/2015-05-01/generated/azure_mgmt_monitor/components.rb', line 45 def list_with_http_info(custom_headers:nil) list_async(custom_headers:custom_headers).value! end |
#purge(resource_group_name, resource_name, body, custom_headers: nil) ⇒ ComponentPurgeResponse
Purges data in an Application Insights component by a set of user-defined filters.
In order to manage system resources, purge requests are throttled at 50 requests per hour. You should batch the execution of purge requests by sending a single command whose predicate includes all user identities that require purging. Use the in operator to specify multiple identities. You should run the query prior to using for a purge request to verify that the results are expected.
is case insensitive. resource. data in a single table of an Application Insights component will be added to the HTTP request.
678 679 680 681 |
# File 'lib/2015-05-01/generated/azure_mgmt_monitor/components.rb', line 678 def purge(resource_group_name, resource_name, body, custom_headers:nil) response = purge_async(resource_group_name, resource_name, body, custom_headers:custom_headers).value! response.body unless response.nil? end |
#purge_async(resource_group_name, resource_name, body, custom_headers: nil) ⇒ Concurrent::Promise
Purges data in an Application Insights component by a set of user-defined filters.
In order to manage system resources, purge requests are throttled at 50 requests per hour. You should batch the execution of purge requests by sending a single command whose predicate includes all user identities that require purging. Use the in operator to specify multiple identities. You should run the query prior to using for a purge request to verify that the results are expected.
is case insensitive. resource. data in a single table of an Application Insights component to the HTTP request.
731 732 733 734 735 736 737 738 739 740 741 742 743 744 745 746 747 748 749 750 751 752 753 754 755 756 757 758 759 760 761 762 763 764 765 766 767 768 769 770 771 772 773 774 775 776 777 778 779 780 781 782 783 784 785 786 787 788 789 790 791 792 793 794 795 796 797 |
# File 'lib/2015-05-01/generated/azure_mgmt_monitor/components.rb', line 731 def purge_async(resource_group_name, resource_name, body, custom_headers:nil) fail ArgumentError, 'resource_group_name is nil' if resource_group_name.nil? fail ArgumentError, "'resource_group_name' should satisfy the constraint - 'MaxLength': '90'" if !resource_group_name.nil? && resource_group_name.length > 90 fail ArgumentError, "'resource_group_name' should satisfy the constraint - 'MinLength': '1'" if !resource_group_name.nil? && resource_group_name.length < 1 fail ArgumentError, "'resource_group_name' should satisfy the constraint - 'Pattern': '^[-\w\._\(\)]+$'" if !resource_group_name.nil? && resource_group_name.match(Regexp.new('^^[-\w\._\(\)]+$$')).nil? fail ArgumentError, '@client.api_version is nil' if @client.api_version.nil? fail ArgumentError, "'@client.api_version' should satisfy the constraint - 'MinLength': '1'" if !@client.api_version.nil? && @client.api_version.length < 1 fail ArgumentError, '@client.subscription_id is nil' if @client.subscription_id.nil? fail ArgumentError, "'@client.subscription_id' should satisfy the constraint - 'MinLength': '1'" if !@client.subscription_id.nil? && @client.subscription_id.length < 1 fail ArgumentError, 'resource_name is nil' if resource_name.nil? fail ArgumentError, 'body is nil' if body.nil? request_headers = {} request_headers['Content-Type'] = 'application/json; charset=utf-8' # Set Headers request_headers['x-ms-client-request-id'] = SecureRandom.uuid request_headers['accept-language'] = @client.accept_language unless @client.accept_language.nil? # Serialize Request request_mapper = Azure::Monitor::Mgmt::V2015_05_01::Models::ComponentPurgeBody.mapper() request_content = @client.serialize(request_mapper, body) request_content = request_content != nil ? JSON.generate(request_content, quirks_mode: true) : nil path_template = 'subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.Insights/components/{resourceName}/purge' request_url = @base_url || @client.base_url = { middlewares: [[MsRest::RetryPolicyMiddleware, times: 3, retry: 0.02], [:cookie_jar]], path_params: {'resourceGroupName' => resource_group_name,'subscriptionId' => @client.subscription_id,'resourceName' => resource_name}, query_params: {'api-version' => @client.api_version}, body: request_content, headers: request_headers.merge(custom_headers || {}), base_url: request_url } promise = @client.make_request_async(:post, path_template, ) promise = promise.then do |result| http_response = result.response status_code = http_response.status response_content = http_response.body unless status_code == 202 error_model = JSON.load(response_content) fail MsRestAzure::AzureOperationError.new(result.request, http_response, error_model) end result.request_id = http_response['x-ms-request-id'] unless http_response['x-ms-request-id'].nil? result.correlation_request_id = http_response['x-ms-correlation-request-id'] unless http_response['x-ms-correlation-request-id'].nil? result.client_request_id = http_response['x-ms-client-request-id'] unless http_response['x-ms-client-request-id'].nil? # Deserialize Response if status_code == 202 begin parsed_response = response_content.to_s.empty? ? nil : JSON.load(response_content) result_mapper = Azure::Monitor::Mgmt::V2015_05_01::Models::ComponentPurgeResponse.mapper() result.body = @client.deserialize(result_mapper, parsed_response) rescue Exception => e fail MsRest::DeserializationError.new('Error occurred in deserializing the response', e., e.backtrace, result) end end result end promise.execute end |
#purge_with_http_info(resource_group_name, resource_name, body, custom_headers: nil) ⇒ MsRestAzure::AzureOperationResponse
Purges data in an Application Insights component by a set of user-defined filters.
In order to manage system resources, purge requests are throttled at 50 requests per hour. You should batch the execution of purge requests by sending a single command whose predicate includes all user identities that require purging. Use the in operator to specify multiple identities. You should run the query prior to using for a purge request to verify that the results are expected.
is case insensitive. resource. data in a single table of an Application Insights component will be added to the HTTP request.
705 706 707 |
# File 'lib/2015-05-01/generated/azure_mgmt_monitor/components.rb', line 705 def purge_with_http_info(resource_group_name, resource_name, body, custom_headers:nil) purge_async(resource_group_name, resource_name, body, custom_headers:custom_headers).value! end |
#update_tags(resource_group_name, resource_name, component_tags, custom_headers: nil) ⇒ ApplicationInsightsComponent
Updates an existing component's tags. To update other fields use the CreateOrUpdate method.
is case insensitive. resource. component instance. will be added to the HTTP request.
549 550 551 552 |
# File 'lib/2015-05-01/generated/azure_mgmt_monitor/components.rb', line 549 def (resource_group_name, resource_name, , custom_headers:nil) response = (resource_group_name, resource_name, , custom_headers:custom_headers).value! response.body unless response.nil? end |
#update_tags_async(resource_group_name, resource_name, component_tags, custom_headers: nil) ⇒ Concurrent::Promise
Updates an existing component's tags. To update other fields use the CreateOrUpdate method.
is case insensitive. resource. component instance. to the HTTP request.
588 589 590 591 592 593 594 595 596 597 598 599 600 601 602 603 604 605 606 607 608 609 610 611 612 613 614 615 616 617 618 619 620 621 622 623 624 625 626 627 628 629 630 631 632 633 634 635 636 637 638 639 640 641 642 643 644 645 646 647 648 649 650 651 652 653 654 |
# File 'lib/2015-05-01/generated/azure_mgmt_monitor/components.rb', line 588 def (resource_group_name, resource_name, , custom_headers:nil) fail ArgumentError, 'resource_group_name is nil' if resource_group_name.nil? fail ArgumentError, "'resource_group_name' should satisfy the constraint - 'MaxLength': '90'" if !resource_group_name.nil? && resource_group_name.length > 90 fail ArgumentError, "'resource_group_name' should satisfy the constraint - 'MinLength': '1'" if !resource_group_name.nil? && resource_group_name.length < 1 fail ArgumentError, "'resource_group_name' should satisfy the constraint - 'Pattern': '^[-\w\._\(\)]+$'" if !resource_group_name.nil? && resource_group_name.match(Regexp.new('^^[-\w\._\(\)]+$$')).nil? fail ArgumentError, '@client.api_version is nil' if @client.api_version.nil? fail ArgumentError, "'@client.api_version' should satisfy the constraint - 'MinLength': '1'" if !@client.api_version.nil? && @client.api_version.length < 1 fail ArgumentError, '@client.subscription_id is nil' if @client.subscription_id.nil? fail ArgumentError, "'@client.subscription_id' should satisfy the constraint - 'MinLength': '1'" if !@client.subscription_id.nil? && @client.subscription_id.length < 1 fail ArgumentError, 'resource_name is nil' if resource_name.nil? fail ArgumentError, 'component_tags is nil' if .nil? request_headers = {} request_headers['Content-Type'] = 'application/json; charset=utf-8' # Set Headers request_headers['x-ms-client-request-id'] = SecureRandom.uuid request_headers['accept-language'] = @client.accept_language unless @client.accept_language.nil? # Serialize Request request_mapper = Azure::Monitor::Mgmt::V2015_05_01::Models::TagsResource.mapper() request_content = @client.serialize(request_mapper, ) request_content = request_content != nil ? JSON.generate(request_content, quirks_mode: true) : nil path_template = 'subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.Insights/components/{resourceName}' request_url = @base_url || @client.base_url = { middlewares: [[MsRest::RetryPolicyMiddleware, times: 3, retry: 0.02], [:cookie_jar]], path_params: {'resourceGroupName' => resource_group_name,'subscriptionId' => @client.subscription_id,'resourceName' => resource_name}, query_params: {'api-version' => @client.api_version}, body: request_content, headers: request_headers.merge(custom_headers || {}), base_url: request_url } promise = @client.make_request_async(:patch, path_template, ) promise = promise.then do |result| http_response = result.response status_code = http_response.status response_content = http_response.body unless status_code == 200 error_model = JSON.load(response_content) fail MsRestAzure::AzureOperationError.new(result.request, http_response, error_model) end result.request_id = http_response['x-ms-request-id'] unless http_response['x-ms-request-id'].nil? result.correlation_request_id = http_response['x-ms-correlation-request-id'] unless http_response['x-ms-correlation-request-id'].nil? result.client_request_id = http_response['x-ms-client-request-id'] unless http_response['x-ms-client-request-id'].nil? # Deserialize Response if status_code == 200 begin parsed_response = response_content.to_s.empty? ? nil : JSON.load(response_content) result_mapper = Azure::Monitor::Mgmt::V2015_05_01::Models::ApplicationInsightsComponent.mapper() result.body = @client.deserialize(result_mapper, parsed_response) rescue Exception => e fail MsRest::DeserializationError.new('Error occurred in deserializing the response', e., e.backtrace, result) end end result end promise.execute end |
#update_tags_with_http_info(resource_group_name, resource_name, component_tags, custom_headers: nil) ⇒ MsRestAzure::AzureOperationResponse
Updates an existing component's tags. To update other fields use the CreateOrUpdate method.
is case insensitive. resource. component instance. will be added to the HTTP request.
569 570 571 |
# File 'lib/2015-05-01/generated/azure_mgmt_monitor/components.rb', line 569 def (resource_group_name, resource_name, , custom_headers:nil) (resource_group_name, resource_name, , custom_headers:custom_headers).value! end |