Class: Azure::Monitor::Mgmt::V2015_05_01::ProactiveDetectionConfigurations
- Inherits:
-
Object
- Object
- Azure::Monitor::Mgmt::V2015_05_01::ProactiveDetectionConfigurations
- Includes:
- MsRestAzure
- Defined in:
- lib/2015-05-01/generated/azure_mgmt_monitor/proactive_detection_configurations.rb
Overview
Composite Swagger for Application Insights Management Client
Instance Attribute Summary collapse
-
#client ⇒ ApplicationInsightsManagementClient
readonly
Reference to the ApplicationInsightsManagementClient.
Instance Method Summary collapse
-
#get(resource_group_name, resource_name, configuration_id, custom_headers: nil) ⇒ ApplicationInsightsComponentProactiveDetectionConfiguration
Get the ProactiveDetection configuration for this configuration id.
-
#get_async(resource_group_name, resource_name, configuration_id, custom_headers: nil) ⇒ Concurrent::Promise
Get the ProactiveDetection configuration for this configuration id.
-
#get_with_http_info(resource_group_name, resource_name, configuration_id, custom_headers: nil) ⇒ MsRestAzure::AzureOperationResponse
Get the ProactiveDetection configuration for this configuration id.
-
#initialize(client) ⇒ ProactiveDetectionConfigurations
constructor
Creates and initializes a new instance of the ProactiveDetectionConfigurations class.
-
#list(resource_group_name, resource_name, custom_headers: nil) ⇒ Array
Gets a list of ProactiveDetection configurations of an Application Insights component.
-
#list_async(resource_group_name, resource_name, custom_headers: nil) ⇒ Concurrent::Promise
Gets a list of ProactiveDetection configurations of an Application Insights component.
-
#list_with_http_info(resource_group_name, resource_name, custom_headers: nil) ⇒ MsRestAzure::AzureOperationResponse
Gets a list of ProactiveDetection configurations of an Application Insights component.
-
#update(resource_group_name, resource_name, configuration_id, proactive_detection_properties, custom_headers: nil) ⇒ ApplicationInsightsComponentProactiveDetectionConfiguration
Update the ProactiveDetection configuration for this configuration id.
-
#update_async(resource_group_name, resource_name, configuration_id, proactive_detection_properties, custom_headers: nil) ⇒ Concurrent::Promise
Update the ProactiveDetection configuration for this configuration id.
-
#update_with_http_info(resource_group_name, resource_name, configuration_id, proactive_detection_properties, custom_headers: nil) ⇒ MsRestAzure::AzureOperationResponse
Update the ProactiveDetection configuration for this configuration id.
Constructor Details
#initialize(client) ⇒ ProactiveDetectionConfigurations
Creates and initializes a new instance of the ProactiveDetectionConfigurations class.
17 18 19 |
# File 'lib/2015-05-01/generated/azure_mgmt_monitor/proactive_detection_configurations.rb', line 17 def initialize(client) @client = client end |
Instance Attribute Details
#client ⇒ ApplicationInsightsManagementClient (readonly)
Returns reference to the ApplicationInsightsManagementClient.
22 23 24 |
# File 'lib/2015-05-01/generated/azure_mgmt_monitor/proactive_detection_configurations.rb', line 22 def client @client end |
Instance Method Details
#get(resource_group_name, resource_name, configuration_id, custom_headers: nil) ⇒ ApplicationInsightsComponentProactiveDetectionConfiguration
Get the ProactiveDetection configuration for this configuration id.
is case insensitive. resource. This is unique within a Application Insights component. will be added to the HTTP request.
operation results.
163 164 165 166 |
# File 'lib/2015-05-01/generated/azure_mgmt_monitor/proactive_detection_configurations.rb', line 163 def get(resource_group_name, resource_name, configuration_id, custom_headers:nil) response = get_async(resource_group_name, resource_name, configuration_id, custom_headers:custom_headers).value! response.body unless response.nil? end |
#get_async(resource_group_name, resource_name, configuration_id, custom_headers: nil) ⇒ Concurrent::Promise
Get the ProactiveDetection configuration for this configuration id.
is case insensitive. resource. This is unique within a Application Insights component. to the HTTP request.
200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 |
# File 'lib/2015-05-01/generated/azure_mgmt_monitor/proactive_detection_configurations.rb', line 200 def get_async(resource_group_name, resource_name, configuration_id, custom_headers:nil) fail ArgumentError, 'resource_group_name is nil' if resource_group_name.nil? fail ArgumentError, "'resource_group_name' should satisfy the constraint - 'MaxLength': '90'" if !resource_group_name.nil? && resource_group_name.length > 90 fail ArgumentError, "'resource_group_name' should satisfy the constraint - 'MinLength': '1'" if !resource_group_name.nil? && resource_group_name.length < 1 fail ArgumentError, "'resource_group_name' should satisfy the constraint - 'Pattern': '^[-\w\._\(\)]+$'" if !resource_group_name.nil? && resource_group_name.match(Regexp.new('^^[-\w\._\(\)]+$$')).nil? fail ArgumentError, '@client.api_version is nil' if @client.api_version.nil? fail ArgumentError, "'@client.api_version' should satisfy the constraint - 'MinLength': '1'" if !@client.api_version.nil? && @client.api_version.length < 1 fail ArgumentError, '@client.subscription_id is nil' if @client.subscription_id.nil? fail ArgumentError, "'@client.subscription_id' should satisfy the constraint - 'MinLength': '1'" if !@client.subscription_id.nil? && @client.subscription_id.length < 1 fail ArgumentError, 'resource_name is nil' if resource_name.nil? fail ArgumentError, 'configuration_id is nil' if configuration_id.nil? request_headers = {} request_headers['Content-Type'] = 'application/json; charset=utf-8' # Set Headers request_headers['x-ms-client-request-id'] = SecureRandom.uuid request_headers['accept-language'] = @client.accept_language unless @client.accept_language.nil? path_template = 'subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.Insights/components/{resourceName}/ProactiveDetectionConfigs/{ConfigurationId}' request_url = @base_url || @client.base_url = { middlewares: [[MsRest::RetryPolicyMiddleware, times: 3, retry: 0.02], [:cookie_jar]], path_params: {'resourceGroupName' => resource_group_name,'subscriptionId' => @client.subscription_id,'resourceName' => resource_name,'ConfigurationId' => configuration_id}, query_params: {'api-version' => @client.api_version}, headers: request_headers.merge(custom_headers || {}), base_url: request_url } promise = @client.make_request_async(:get, path_template, ) promise = promise.then do |result| http_response = result.response status_code = http_response.status response_content = http_response.body unless status_code == 200 error_model = JSON.load(response_content) fail MsRestAzure::AzureOperationError.new(result.request, http_response, error_model) end result.request_id = http_response['x-ms-request-id'] unless http_response['x-ms-request-id'].nil? result.correlation_request_id = http_response['x-ms-correlation-request-id'] unless http_response['x-ms-correlation-request-id'].nil? result.client_request_id = http_response['x-ms-client-request-id'] unless http_response['x-ms-client-request-id'].nil? # Deserialize Response if status_code == 200 begin parsed_response = response_content.to_s.empty? ? nil : JSON.load(response_content) result_mapper = Azure::Monitor::Mgmt::V2015_05_01::Models::ApplicationInsightsComponentProactiveDetectionConfiguration.mapper() result.body = @client.deserialize(result_mapper, parsed_response) rescue Exception => e fail MsRest::DeserializationError.new('Error occurred in deserializing the response', e., e.backtrace, result) end end result end promise.execute end |
#get_with_http_info(resource_group_name, resource_name, configuration_id, custom_headers: nil) ⇒ MsRestAzure::AzureOperationResponse
Get the ProactiveDetection configuration for this configuration id.
is case insensitive. resource. This is unique within a Application Insights component. will be added to the HTTP request.
182 183 184 |
# File 'lib/2015-05-01/generated/azure_mgmt_monitor/proactive_detection_configurations.rb', line 182 def get_with_http_info(resource_group_name, resource_name, configuration_id, custom_headers:nil) get_async(resource_group_name, resource_name, configuration_id, custom_headers:custom_headers).value! end |
#list(resource_group_name, resource_name, custom_headers: nil) ⇒ Array
Gets a list of ProactiveDetection configurations of an Application Insights component.
is case insensitive. resource. will be added to the HTTP request.
37 38 39 40 |
# File 'lib/2015-05-01/generated/azure_mgmt_monitor/proactive_detection_configurations.rb', line 37 def list(resource_group_name, resource_name, custom_headers:nil) response = list_async(resource_group_name, resource_name, custom_headers:custom_headers).value! response.body unless response.nil? end |
#list_async(resource_group_name, resource_name, custom_headers: nil) ⇒ Concurrent::Promise
Gets a list of ProactiveDetection configurations of an Application Insights component.
is case insensitive. resource. to the HTTP request.
72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 |
# File 'lib/2015-05-01/generated/azure_mgmt_monitor/proactive_detection_configurations.rb', line 72 def list_async(resource_group_name, resource_name, custom_headers:nil) fail ArgumentError, 'resource_group_name is nil' if resource_group_name.nil? fail ArgumentError, "'resource_group_name' should satisfy the constraint - 'MaxLength': '90'" if !resource_group_name.nil? && resource_group_name.length > 90 fail ArgumentError, "'resource_group_name' should satisfy the constraint - 'MinLength': '1'" if !resource_group_name.nil? && resource_group_name.length < 1 fail ArgumentError, "'resource_group_name' should satisfy the constraint - 'Pattern': '^[-\w\._\(\)]+$'" if !resource_group_name.nil? && resource_group_name.match(Regexp.new('^^[-\w\._\(\)]+$$')).nil? fail ArgumentError, '@client.api_version is nil' if @client.api_version.nil? fail ArgumentError, "'@client.api_version' should satisfy the constraint - 'MinLength': '1'" if !@client.api_version.nil? && @client.api_version.length < 1 fail ArgumentError, '@client.subscription_id is nil' if @client.subscription_id.nil? fail ArgumentError, "'@client.subscription_id' should satisfy the constraint - 'MinLength': '1'" if !@client.subscription_id.nil? && @client.subscription_id.length < 1 fail ArgumentError, 'resource_name is nil' if resource_name.nil? request_headers = {} request_headers['Content-Type'] = 'application/json; charset=utf-8' # Set Headers request_headers['x-ms-client-request-id'] = SecureRandom.uuid request_headers['accept-language'] = @client.accept_language unless @client.accept_language.nil? path_template = 'subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.Insights/components/{resourceName}/ProactiveDetectionConfigs' request_url = @base_url || @client.base_url = { middlewares: [[MsRest::RetryPolicyMiddleware, times: 3, retry: 0.02], [:cookie_jar]], path_params: {'resourceGroupName' => resource_group_name,'subscriptionId' => @client.subscription_id,'resourceName' => resource_name}, query_params: {'api-version' => @client.api_version}, headers: request_headers.merge(custom_headers || {}), base_url: request_url } promise = @client.make_request_async(:get, path_template, ) promise = promise.then do |result| http_response = result.response status_code = http_response.status response_content = http_response.body unless status_code == 200 error_model = JSON.load(response_content) fail MsRestAzure::AzureOperationError.new(result.request, http_response, error_model) end result.request_id = http_response['x-ms-request-id'] unless http_response['x-ms-request-id'].nil? result.correlation_request_id = http_response['x-ms-correlation-request-id'] unless http_response['x-ms-correlation-request-id'].nil? result.client_request_id = http_response['x-ms-client-request-id'] unless http_response['x-ms-client-request-id'].nil? # Deserialize Response if status_code == 200 begin parsed_response = response_content.to_s.empty? ? nil : JSON.load(response_content) result_mapper = { client_side_validation: true, required: false, serialized_name: 'parsed_response', type: { name: 'Sequence', element: { client_side_validation: true, required: false, serialized_name: 'ApplicationInsightsComponentProactiveDetectionConfigurationElementType', type: { name: 'Composite', class_name: 'ApplicationInsightsComponentProactiveDetectionConfiguration' } } } } result.body = @client.deserialize(result_mapper, parsed_response) rescue Exception => e fail MsRest::DeserializationError.new('Error occurred in deserializing the response', e., e.backtrace, result) end end result end promise.execute end |
#list_with_http_info(resource_group_name, resource_name, custom_headers: nil) ⇒ MsRestAzure::AzureOperationResponse
Gets a list of ProactiveDetection configurations of an Application Insights component.
is case insensitive. resource. will be added to the HTTP request.
55 56 57 |
# File 'lib/2015-05-01/generated/azure_mgmt_monitor/proactive_detection_configurations.rb', line 55 def list_with_http_info(resource_group_name, resource_name, custom_headers:nil) list_async(resource_group_name, resource_name, custom_headers:custom_headers).value! end |
#update(resource_group_name, resource_name, configuration_id, proactive_detection_properties, custom_headers: nil) ⇒ ApplicationInsightsComponentProactiveDetectionConfiguration
Update the ProactiveDetection configuration for this configuration id.
is case insensitive. resource. This is unique within a Application Insights component.
- ApplicationInsightsComponentProactiveDetectionConfiguration
-
Properties that
need to be specified to update the ProactiveDetection configuration. will be added to the HTTP request.
operation results.
279 280 281 282 |
# File 'lib/2015-05-01/generated/azure_mgmt_monitor/proactive_detection_configurations.rb', line 279 def update(resource_group_name, resource_name, configuration_id, proactive_detection_properties, custom_headers:nil) response = update_async(resource_group_name, resource_name, configuration_id, proactive_detection_properties, custom_headers:custom_headers).value! response.body unless response.nil? end |
#update_async(resource_group_name, resource_name, configuration_id, proactive_detection_properties, custom_headers: nil) ⇒ Concurrent::Promise
Update the ProactiveDetection configuration for this configuration id.
is case insensitive. resource. This is unique within a Application Insights component.
- ApplicationInsightsComponentProactiveDetectionConfiguration
-
Properties that
need to be specified to update the ProactiveDetection configuration. to the HTTP request.
322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 389 |
# File 'lib/2015-05-01/generated/azure_mgmt_monitor/proactive_detection_configurations.rb', line 322 def update_async(resource_group_name, resource_name, configuration_id, proactive_detection_properties, custom_headers:nil) fail ArgumentError, 'resource_group_name is nil' if resource_group_name.nil? fail ArgumentError, "'resource_group_name' should satisfy the constraint - 'MaxLength': '90'" if !resource_group_name.nil? && resource_group_name.length > 90 fail ArgumentError, "'resource_group_name' should satisfy the constraint - 'MinLength': '1'" if !resource_group_name.nil? && resource_group_name.length < 1 fail ArgumentError, "'resource_group_name' should satisfy the constraint - 'Pattern': '^[-\w\._\(\)]+$'" if !resource_group_name.nil? && resource_group_name.match(Regexp.new('^^[-\w\._\(\)]+$$')).nil? fail ArgumentError, '@client.api_version is nil' if @client.api_version.nil? fail ArgumentError, "'@client.api_version' should satisfy the constraint - 'MinLength': '1'" if !@client.api_version.nil? && @client.api_version.length < 1 fail ArgumentError, '@client.subscription_id is nil' if @client.subscription_id.nil? fail ArgumentError, "'@client.subscription_id' should satisfy the constraint - 'MinLength': '1'" if !@client.subscription_id.nil? && @client.subscription_id.length < 1 fail ArgumentError, 'resource_name is nil' if resource_name.nil? fail ArgumentError, 'configuration_id is nil' if configuration_id.nil? fail ArgumentError, 'proactive_detection_properties is nil' if proactive_detection_properties.nil? request_headers = {} request_headers['Content-Type'] = 'application/json; charset=utf-8' # Set Headers request_headers['x-ms-client-request-id'] = SecureRandom.uuid request_headers['accept-language'] = @client.accept_language unless @client.accept_language.nil? # Serialize Request request_mapper = Azure::Monitor::Mgmt::V2015_05_01::Models::ApplicationInsightsComponentProactiveDetectionConfiguration.mapper() request_content = @client.serialize(request_mapper, proactive_detection_properties) request_content = request_content != nil ? JSON.generate(request_content, quirks_mode: true) : nil path_template = 'subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.Insights/components/{resourceName}/ProactiveDetectionConfigs/{ConfigurationId}' request_url = @base_url || @client.base_url = { middlewares: [[MsRest::RetryPolicyMiddleware, times: 3, retry: 0.02], [:cookie_jar]], path_params: {'resourceGroupName' => resource_group_name,'subscriptionId' => @client.subscription_id,'resourceName' => resource_name,'ConfigurationId' => configuration_id}, query_params: {'api-version' => @client.api_version}, body: request_content, headers: request_headers.merge(custom_headers || {}), base_url: request_url } promise = @client.make_request_async(:put, path_template, ) promise = promise.then do |result| http_response = result.response status_code = http_response.status response_content = http_response.body unless status_code == 200 error_model = JSON.load(response_content) fail MsRestAzure::AzureOperationError.new(result.request, http_response, error_model) end result.request_id = http_response['x-ms-request-id'] unless http_response['x-ms-request-id'].nil? result.correlation_request_id = http_response['x-ms-correlation-request-id'] unless http_response['x-ms-correlation-request-id'].nil? result.client_request_id = http_response['x-ms-client-request-id'] unless http_response['x-ms-client-request-id'].nil? # Deserialize Response if status_code == 200 begin parsed_response = response_content.to_s.empty? ? nil : JSON.load(response_content) result_mapper = Azure::Monitor::Mgmt::V2015_05_01::Models::ApplicationInsightsComponentProactiveDetectionConfiguration.mapper() result.body = @client.deserialize(result_mapper, parsed_response) rescue Exception => e fail MsRest::DeserializationError.new('Error occurred in deserializing the response', e., e.backtrace, result) end end result end promise.execute end |
#update_with_http_info(resource_group_name, resource_name, configuration_id, proactive_detection_properties, custom_headers: nil) ⇒ MsRestAzure::AzureOperationResponse
Update the ProactiveDetection configuration for this configuration id.
is case insensitive. resource. This is unique within a Application Insights component.
- ApplicationInsightsComponentProactiveDetectionConfiguration
-
Properties that
need to be specified to update the ProactiveDetection configuration. will be added to the HTTP request.
301 302 303 |
# File 'lib/2015-05-01/generated/azure_mgmt_monitor/proactive_detection_configurations.rb', line 301 def update_with_http_info(resource_group_name, resource_name, configuration_id, proactive_detection_properties, custom_headers:nil) update_async(resource_group_name, resource_name, configuration_id, proactive_detection_properties, custom_headers:custom_headers).value! end |