Class: Azure::Monitor::Mgmt::V2016_03_01::AlertRuleIncidents
- Inherits:
-
Object
- Object
- Azure::Monitor::Mgmt::V2016_03_01::AlertRuleIncidents
- Includes:
- MsRestAzure
- Defined in:
- lib/2016-03-01/generated/azure_mgmt_monitor/alert_rule_incidents.rb
Overview
Monitor Management Client
Instance Attribute Summary collapse
-
#client ⇒ MonitorManagementClient
readonly
Reference to the MonitorManagementClient.
Instance Method Summary collapse
-
#get(resource_group_name, rule_name, incident_name, custom_headers: nil) ⇒ Incident
Gets an incident associated to an alert rule.
-
#get_async(resource_group_name, rule_name, incident_name, custom_headers: nil) ⇒ Concurrent::Promise
Gets an incident associated to an alert rule.
-
#get_with_http_info(resource_group_name, rule_name, incident_name, custom_headers: nil) ⇒ MsRestAzure::AzureOperationResponse
Gets an incident associated to an alert rule.
-
#initialize(client) ⇒ AlertRuleIncidents
constructor
Creates and initializes a new instance of the AlertRuleIncidents class.
-
#list_by_alert_rule(resource_group_name, rule_name, custom_headers: nil) ⇒ IncidentListResult
Gets a list of incidents associated to an alert rule.
-
#list_by_alert_rule_async(resource_group_name, rule_name, custom_headers: nil) ⇒ Concurrent::Promise
Gets a list of incidents associated to an alert rule.
-
#list_by_alert_rule_with_http_info(resource_group_name, rule_name, custom_headers: nil) ⇒ MsRestAzure::AzureOperationResponse
Gets a list of incidents associated to an alert rule.
Constructor Details
#initialize(client) ⇒ AlertRuleIncidents
Creates and initializes a new instance of the AlertRuleIncidents class.
17 18 19 |
# File 'lib/2016-03-01/generated/azure_mgmt_monitor/alert_rule_incidents.rb', line 17 def initialize(client) @client = client end |
Instance Attribute Details
#client ⇒ MonitorManagementClient (readonly)
Returns reference to the MonitorManagementClient.
22 23 24 |
# File 'lib/2016-03-01/generated/azure_mgmt_monitor/alert_rule_incidents.rb', line 22 def client @client end |
Instance Method Details
#get(resource_group_name, rule_name, incident_name, custom_headers: nil) ⇒ Incident
Gets an incident associated to an alert rule
will be added to the HTTP request.
35 36 37 38 |
# File 'lib/2016-03-01/generated/azure_mgmt_monitor/alert_rule_incidents.rb', line 35 def get(resource_group_name, rule_name, incident_name, custom_headers:nil) response = get_async(resource_group_name, rule_name, incident_name, custom_headers:custom_headers).value! response.body unless response.nil? end |
#get_async(resource_group_name, rule_name, incident_name, custom_headers: nil) ⇒ Concurrent::Promise
Gets an incident associated to an alert rule
to the HTTP request.
66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 |
# File 'lib/2016-03-01/generated/azure_mgmt_monitor/alert_rule_incidents.rb', line 66 def get_async(resource_group_name, rule_name, incident_name, custom_headers:nil) fail ArgumentError, 'resource_group_name is nil' if resource_group_name.nil? fail ArgumentError, 'rule_name is nil' if rule_name.nil? fail ArgumentError, 'incident_name is nil' if incident_name.nil? fail ArgumentError, '@client.api_version is nil' if @client.api_version.nil? fail ArgumentError, '@client.subscription_id is nil' if @client.subscription_id.nil? request_headers = {} request_headers['Content-Type'] = 'application/json; charset=utf-8' # Set Headers request_headers['x-ms-client-request-id'] = SecureRandom.uuid request_headers['accept-language'] = @client.accept_language unless @client.accept_language.nil? path_template = 'subscriptions/{subscriptionId}/resourcegroups/{resourceGroupName}/providers/microsoft.insights/alertrules/{ruleName}/incidents/{incidentName}' request_url = @base_url || @client.base_url = { middlewares: [[MsRest::RetryPolicyMiddleware, times: 3, retry: 0.02], [:cookie_jar]], path_params: {'resourceGroupName' => resource_group_name,'ruleName' => rule_name,'incidentName' => incident_name,'subscriptionId' => @client.subscription_id}, query_params: {'api-version' => @client.api_version}, headers: request_headers.merge(custom_headers || {}), base_url: request_url } promise = @client.make_request_async(:get, path_template, ) promise = promise.then do |result| http_response = result.response status_code = http_response.status response_content = http_response.body unless status_code == 200 error_model = JSON.load(response_content) fail MsRest::HttpOperationError.new(result.request, http_response, error_model) end result.request_id = http_response['x-ms-request-id'] unless http_response['x-ms-request-id'].nil? result.correlation_request_id = http_response['x-ms-correlation-request-id'] unless http_response['x-ms-correlation-request-id'].nil? result.client_request_id = http_response['x-ms-client-request-id'] unless http_response['x-ms-client-request-id'].nil? # Deserialize Response if status_code == 200 begin parsed_response = response_content.to_s.empty? ? nil : JSON.load(response_content) result_mapper = Azure::Monitor::Mgmt::V2016_03_01::Models::Incident.mapper() result.body = @client.deserialize(result_mapper, parsed_response) rescue Exception => e fail MsRest::DeserializationError.new('Error occurred in deserializing the response', e., e.backtrace, result) end end result end promise.execute end |
#get_with_http_info(resource_group_name, rule_name, incident_name, custom_headers: nil) ⇒ MsRestAzure::AzureOperationResponse
Gets an incident associated to an alert rule
will be added to the HTTP request.
51 52 53 |
# File 'lib/2016-03-01/generated/azure_mgmt_monitor/alert_rule_incidents.rb', line 51 def get_with_http_info(resource_group_name, rule_name, incident_name, custom_headers:nil) get_async(resource_group_name, rule_name, incident_name, custom_headers:custom_headers).value! end |
#list_by_alert_rule(resource_group_name, rule_name, custom_headers: nil) ⇒ IncidentListResult
Gets a list of incidents associated to an alert rule
will be added to the HTTP request.
132 133 134 135 |
# File 'lib/2016-03-01/generated/azure_mgmt_monitor/alert_rule_incidents.rb', line 132 def list_by_alert_rule(resource_group_name, rule_name, custom_headers:nil) response = list_by_alert_rule_async(resource_group_name, rule_name, custom_headers:custom_headers).value! response.body unless response.nil? end |
#list_by_alert_rule_async(resource_group_name, rule_name, custom_headers: nil) ⇒ Concurrent::Promise
Gets a list of incidents associated to an alert rule
to the HTTP request.
161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 |
# File 'lib/2016-03-01/generated/azure_mgmt_monitor/alert_rule_incidents.rb', line 161 def list_by_alert_rule_async(resource_group_name, rule_name, custom_headers:nil) fail ArgumentError, 'resource_group_name is nil' if resource_group_name.nil? fail ArgumentError, 'rule_name is nil' if rule_name.nil? fail ArgumentError, '@client.api_version is nil' if @client.api_version.nil? fail ArgumentError, '@client.subscription_id is nil' if @client.subscription_id.nil? request_headers = {} request_headers['Content-Type'] = 'application/json; charset=utf-8' # Set Headers request_headers['x-ms-client-request-id'] = SecureRandom.uuid request_headers['accept-language'] = @client.accept_language unless @client.accept_language.nil? path_template = 'subscriptions/{subscriptionId}/resourcegroups/{resourceGroupName}/providers/microsoft.insights/alertrules/{ruleName}/incidents' request_url = @base_url || @client.base_url = { middlewares: [[MsRest::RetryPolicyMiddleware, times: 3, retry: 0.02], [:cookie_jar]], path_params: {'resourceGroupName' => resource_group_name,'ruleName' => rule_name,'subscriptionId' => @client.subscription_id}, query_params: {'api-version' => @client.api_version}, headers: request_headers.merge(custom_headers || {}), base_url: request_url } promise = @client.make_request_async(:get, path_template, ) promise = promise.then do |result| http_response = result.response status_code = http_response.status response_content = http_response.body unless status_code == 200 error_model = JSON.load(response_content) fail MsRestAzure::AzureOperationError.new(result.request, http_response, error_model) end result.request_id = http_response['x-ms-request-id'] unless http_response['x-ms-request-id'].nil? result.correlation_request_id = http_response['x-ms-correlation-request-id'] unless http_response['x-ms-correlation-request-id'].nil? result.client_request_id = http_response['x-ms-client-request-id'] unless http_response['x-ms-client-request-id'].nil? # Deserialize Response if status_code == 200 begin parsed_response = response_content.to_s.empty? ? nil : JSON.load(response_content) result_mapper = Azure::Monitor::Mgmt::V2016_03_01::Models::IncidentListResult.mapper() result.body = @client.deserialize(result_mapper, parsed_response) rescue Exception => e fail MsRest::DeserializationError.new('Error occurred in deserializing the response', e., e.backtrace, result) end end result end promise.execute end |
#list_by_alert_rule_with_http_info(resource_group_name, rule_name, custom_headers: nil) ⇒ MsRestAzure::AzureOperationResponse
Gets a list of incidents associated to an alert rule
will be added to the HTTP request.
147 148 149 |
# File 'lib/2016-03-01/generated/azure_mgmt_monitor/alert_rule_incidents.rb', line 147 def list_by_alert_rule_with_http_info(resource_group_name, rule_name, custom_headers:nil) list_by_alert_rule_async(resource_group_name, rule_name, custom_headers:custom_headers).value! end |