Class: Azure::Monitor::Mgmt::V2016_03_01::MetricDefinitions
- Inherits:
-
Object
- Object
- Azure::Monitor::Mgmt::V2016_03_01::MetricDefinitions
- Includes:
- MsRestAzure
- Defined in:
- lib/2016-03-01/generated/azure_mgmt_monitor/metric_definitions.rb
Overview
Monitor Management Client
Instance Attribute Summary collapse
-
#client ⇒ MonitorManagementClient
readonly
Reference to the MonitorManagementClient.
Instance Method Summary collapse
-
#initialize(client) ⇒ MetricDefinitions
constructor
Creates and initializes a new instance of the MetricDefinitions class.
-
#list(resource_uri, filter: nil, custom_headers: nil) ⇒ MetricDefinitionCollection
Lists the metric definitions for the resource.
-
#list_async(resource_uri, filter: nil, custom_headers: nil) ⇒ Concurrent::Promise
Lists the metric definitions for the resource.
-
#list_with_http_info(resource_uri, filter: nil, custom_headers: nil) ⇒ MsRestAzure::AzureOperationResponse
Lists the metric definitions for the resource.
Constructor Details
#initialize(client) ⇒ MetricDefinitions
Creates and initializes a new instance of the MetricDefinitions class.
17 18 19 |
# File 'lib/2016-03-01/generated/azure_mgmt_monitor/metric_definitions.rb', line 17 def initialize(client) @client = client end |
Instance Attribute Details
#client ⇒ MonitorManagementClient (readonly)
Returns reference to the MonitorManagementClient.
22 23 24 |
# File 'lib/2016-03-01/generated/azure_mgmt_monitor/metric_definitions.rb', line 22 def client @client end |
Instance Method Details
#list(resource_uri, filter: nil, custom_headers: nil) ⇒ MetricDefinitionCollection
Lists the metric definitions for the resource.
particular metric definitions from all the definitions available for the resource.
For example, to get just the definition for the 'CPU percentage' counter: $filter=name.value eq 'Processor(_Total)% Processor Time'.
Multiple metrics can be retrieved by joining together *'name eq <value>'* clauses separated by or logical operators.
*NOTE*: No other syntax is allowed. will be added to the HTTP request.
40 41 42 43 |
# File 'lib/2016-03-01/generated/azure_mgmt_monitor/metric_definitions.rb', line 40 def list(resource_uri, filter:nil, custom_headers:nil) response = list_async(resource_uri, filter:filter, custom_headers:custom_headers).value! response.body unless response.nil? end |
#list_async(resource_uri, filter: nil, custom_headers: nil) ⇒ Concurrent::Promise
Lists the metric definitions for the resource.
particular metric definitions from all the definitions available for the resource.
For example, to get just the definition for the 'CPU percentage' counter: $filter=name.value eq 'Processor(_Total)% Processor Time'.
Multiple metrics can be retrieved by joining together *'name eq <value>'* clauses separated by or logical operators.
*NOTE*: No other syntax is allowed. to the HTTP request.
81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 |
# File 'lib/2016-03-01/generated/azure_mgmt_monitor/metric_definitions.rb', line 81 def list_async(resource_uri, filter:nil, custom_headers:nil) fail ArgumentError, 'resource_uri is nil' if resource_uri.nil? fail ArgumentError, '@client.api_version is nil' if @client.api_version.nil? request_headers = {} request_headers['Content-Type'] = 'application/json; charset=utf-8' # Set Headers request_headers['x-ms-client-request-id'] = SecureRandom.uuid request_headers['accept-language'] = @client.accept_language unless @client.accept_language.nil? path_template = '{resourceUri}/providers/microsoft.insights/metricDefinitions' request_url = @base_url || @client.base_url = { middlewares: [[MsRest::RetryPolicyMiddleware, times: 3, retry: 0.02], [:cookie_jar]], skip_encoding_path_params: {'resourceUri' => resource_uri}, query_params: {'api-version' => @client.api_version,'$filter' => filter}, headers: request_headers.merge(custom_headers || {}), base_url: request_url } promise = @client.make_request_async(:get, path_template, ) promise = promise.then do |result| http_response = result.response status_code = http_response.status response_content = http_response.body unless status_code == 200 error_model = JSON.load(response_content) fail MsRest::HttpOperationError.new(result.request, http_response, error_model) end result.request_id = http_response['x-ms-request-id'] unless http_response['x-ms-request-id'].nil? result.correlation_request_id = http_response['x-ms-correlation-request-id'] unless http_response['x-ms-correlation-request-id'].nil? result.client_request_id = http_response['x-ms-client-request-id'] unless http_response['x-ms-client-request-id'].nil? # Deserialize Response if status_code == 200 begin parsed_response = response_content.to_s.empty? ? nil : JSON.load(response_content) result_mapper = Azure::Monitor::Mgmt::V2016_03_01::Models::MetricDefinitionCollection.mapper() result.body = @client.deserialize(result_mapper, parsed_response) rescue Exception => e fail MsRest::DeserializationError.new('Error occurred in deserializing the response', e., e.backtrace, result) end end result end promise.execute end |
#list_with_http_info(resource_uri, filter: nil, custom_headers: nil) ⇒ MsRestAzure::AzureOperationResponse
Lists the metric definitions for the resource.
particular metric definitions from all the definitions available for the resource.
For example, to get just the definition for the 'CPU percentage' counter: $filter=name.value eq 'Processor(_Total)% Processor Time'.
Multiple metrics can be retrieved by joining together *'name eq <value>'* clauses separated by or logical operators.
*NOTE*: No other syntax is allowed. will be added to the HTTP request.
61 62 63 |
# File 'lib/2016-03-01/generated/azure_mgmt_monitor/metric_definitions.rb', line 61 def list_with_http_info(resource_uri, filter:nil, custom_headers:nil) list_async(resource_uri, filter:filter, custom_headers:custom_headers).value! end |