Class: Azure::Monitor::Mgmt::V2018_03_01::ActionGroups

Inherits:
Object
  • Object
show all
Includes:
MsRestAzure
Defined in:
lib/2018-03-01/generated/azure_mgmt_monitor/action_groups.rb

Overview

Monitor Management Client

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(client) ⇒ ActionGroups

Creates and initializes a new instance of the ActionGroups class.

Parameters:

  • client

    service class for accessing basic functionality.



17
18
19
# File 'lib/2018-03-01/generated/azure_mgmt_monitor/action_groups.rb', line 17

def initialize(client)
  @client = client
end

Instance Attribute Details

#clientMonitorManagementClient (readonly)

Returns reference to the MonitorManagementClient.

Returns:



22
23
24
# File 'lib/2018-03-01/generated/azure_mgmt_monitor/action_groups.rb', line 22

def client
  @client
end

Instance Method Details

#create_or_update(resource_group_name, action_group_name, action_group, custom_headers: nil) ⇒ ActionGroupResource

Create a new action group or update an existing one.

for the update. will be added to the HTTP request.

Parameters:

  • resource_group_name (String)

    The name of the resource group.

  • action_group_name (String)

    The name of the action group.

  • action_group (ActionGroupResource)

    The action group to create or use

  • custom_headers (Hash{String => String}) (defaults to: nil)

    A hash of custom headers that

Returns:

  • (ActionGroupResource)

    operation results.



36
37
38
39
# File 'lib/2018-03-01/generated/azure_mgmt_monitor/action_groups.rb', line 36

def create_or_update(resource_group_name, action_group_name, action_group, custom_headers:nil)
  response = create_or_update_async(resource_group_name, action_group_name, action_group, custom_headers:custom_headers).value!
  response.body unless response.nil?
end

#create_or_update_async(resource_group_name, action_group_name, action_group, custom_headers: nil) ⇒ Concurrent::Promise

Create a new action group or update an existing one.

for the update. to the HTTP request.

Parameters:

  • resource_group_name (String)

    The name of the resource group.

  • action_group_name (String)

    The name of the action group.

  • action_group (ActionGroupResource)

    The action group to create or use

  • A (Hash{String => String})

    hash of custom headers that will be added

Returns:

  • (Concurrent::Promise)

    Promise object which holds the HTTP response.



69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
# File 'lib/2018-03-01/generated/azure_mgmt_monitor/action_groups.rb', line 69

def create_or_update_async(resource_group_name, action_group_name, action_group, custom_headers:nil)
  fail ArgumentError, 'resource_group_name is nil' if resource_group_name.nil?
  fail ArgumentError, 'action_group_name is nil' if action_group_name.nil?
  fail ArgumentError, 'action_group is nil' if action_group.nil?
  fail ArgumentError, '@client.subscription_id is nil' if @client.subscription_id.nil?
  fail ArgumentError, '@client.api_version is nil' if @client.api_version.nil?


  request_headers = {}
  request_headers['Content-Type'] = 'application/json; charset=utf-8'

  # Set Headers
  request_headers['x-ms-client-request-id'] = SecureRandom.uuid
  request_headers['accept-language'] = @client.accept_language unless @client.accept_language.nil?

  # Serialize Request
  request_mapper = Azure::Monitor::Mgmt::V2018_03_01::Models::ActionGroupResource.mapper()
  request_content = @client.serialize(request_mapper,  action_group)
  request_content = request_content != nil ? JSON.generate(request_content, quirks_mode: true) : nil

  path_template = 'subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/microsoft.insights/actionGroups/{actionGroupName}'

  request_url = @base_url || @client.base_url

  options = {
      middlewares: [[MsRest::RetryPolicyMiddleware, times: 3, retry: 0.02], [:cookie_jar]],
      path_params: {'resourceGroupName' => resource_group_name,'actionGroupName' => action_group_name,'subscriptionId' => @client.subscription_id},
      query_params: {'api-version' => @client.api_version},
      body: request_content,
      headers: request_headers.merge(custom_headers || {}),
      base_url: request_url
  }
  promise = @client.make_request_async(:put, path_template, options)

  promise = promise.then do |result|
    http_response = result.response
    status_code = http_response.status
    response_content = http_response.body
    unless status_code == 200 || status_code == 201
      error_model = JSON.load(response_content)
      fail MsRest::HttpOperationError.new(result.request, http_response, error_model)
    end

    result.request_id = http_response['x-ms-request-id'] unless http_response['x-ms-request-id'].nil?
    result.correlation_request_id = http_response['x-ms-correlation-request-id'] unless http_response['x-ms-correlation-request-id'].nil?
    result.client_request_id = http_response['x-ms-client-request-id'] unless http_response['x-ms-client-request-id'].nil?
    # Deserialize Response
    if status_code == 200
      begin
        parsed_response = response_content.to_s.empty? ? nil : JSON.load(response_content)
        result_mapper = Azure::Monitor::Mgmt::V2018_03_01::Models::ActionGroupResource.mapper()
        result.body = @client.deserialize(result_mapper, parsed_response)
      rescue Exception => e
        fail MsRest::DeserializationError.new('Error occurred in deserializing the response', e.message, e.backtrace, result)
      end
    end
    # Deserialize Response
    if status_code == 201
      begin
        parsed_response = response_content.to_s.empty? ? nil : JSON.load(response_content)
        result_mapper = Azure::Monitor::Mgmt::V2018_03_01::Models::ActionGroupResource.mapper()
        result.body = @client.deserialize(result_mapper, parsed_response)
      rescue Exception => e
        fail MsRest::DeserializationError.new('Error occurred in deserializing the response', e.message, e.backtrace, result)
      end
    end

    result
  end

  promise.execute
end

#create_or_update_with_http_info(resource_group_name, action_group_name, action_group, custom_headers: nil) ⇒ MsRestAzure::AzureOperationResponse

Create a new action group or update an existing one.

for the update. will be added to the HTTP request.

Parameters:

  • resource_group_name (String)

    The name of the resource group.

  • action_group_name (String)

    The name of the action group.

  • action_group (ActionGroupResource)

    The action group to create or use

  • custom_headers (Hash{String => String}) (defaults to: nil)

    A hash of custom headers that

Returns:

  • (MsRestAzure::AzureOperationResponse)

    HTTP response information.



53
54
55
# File 'lib/2018-03-01/generated/azure_mgmt_monitor/action_groups.rb', line 53

def create_or_update_with_http_info(resource_group_name, action_group_name, action_group, custom_headers:nil)
  create_or_update_async(resource_group_name, action_group_name, action_group, custom_headers:custom_headers).value!
end

#delete(resource_group_name, action_group_name, custom_headers: nil) ⇒ Object

Delete an action group.

will be added to the HTTP request.

Parameters:

  • resource_group_name (String)

    The name of the resource group.

  • action_group_name (String)

    The name of the action group.

  • custom_headers (Hash{String => String}) (defaults to: nil)

    A hash of custom headers that



245
246
247
248
# File 'lib/2018-03-01/generated/azure_mgmt_monitor/action_groups.rb', line 245

def delete(resource_group_name, action_group_name, custom_headers:nil)
  response = delete_async(resource_group_name, action_group_name, custom_headers:custom_headers).value!
  nil
end

#delete_async(resource_group_name, action_group_name, custom_headers: nil) ⇒ Concurrent::Promise

Delete an action group.

to the HTTP request.

Parameters:

  • resource_group_name (String)

    The name of the resource group.

  • action_group_name (String)

    The name of the action group.

  • A (Hash{String => String})

    hash of custom headers that will be added

Returns:

  • (Concurrent::Promise)

    Promise object which holds the HTTP response.



274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
# File 'lib/2018-03-01/generated/azure_mgmt_monitor/action_groups.rb', line 274

def delete_async(resource_group_name, action_group_name, custom_headers:nil)
  fail ArgumentError, 'resource_group_name is nil' if resource_group_name.nil?
  fail ArgumentError, 'action_group_name is nil' if action_group_name.nil?
  fail ArgumentError, '@client.subscription_id is nil' if @client.subscription_id.nil?
  fail ArgumentError, '@client.api_version is nil' if @client.api_version.nil?


  request_headers = {}
  request_headers['Content-Type'] = 'application/json; charset=utf-8'

  # Set Headers
  request_headers['x-ms-client-request-id'] = SecureRandom.uuid
  request_headers['accept-language'] = @client.accept_language unless @client.accept_language.nil?
  path_template = 'subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/microsoft.insights/actionGroups/{actionGroupName}'

  request_url = @base_url || @client.base_url

  options = {
      middlewares: [[MsRest::RetryPolicyMiddleware, times: 3, retry: 0.02], [:cookie_jar]],
      path_params: {'resourceGroupName' => resource_group_name,'actionGroupName' => action_group_name,'subscriptionId' => @client.subscription_id},
      query_params: {'api-version' => @client.api_version},
      headers: request_headers.merge(custom_headers || {}),
      base_url: request_url
  }
  promise = @client.make_request_async(:delete, path_template, options)

  promise = promise.then do |result|
    http_response = result.response
    status_code = http_response.status
    response_content = http_response.body
    unless status_code == 200 || status_code == 204
      error_model = JSON.load(response_content)
      fail MsRest::HttpOperationError.new(result.request, http_response, error_model)
    end

    result.request_id = http_response['x-ms-request-id'] unless http_response['x-ms-request-id'].nil?
    result.correlation_request_id = http_response['x-ms-correlation-request-id'] unless http_response['x-ms-correlation-request-id'].nil?
    result.client_request_id = http_response['x-ms-client-request-id'] unless http_response['x-ms-client-request-id'].nil?

    result
  end

  promise.execute
end

#delete_with_http_info(resource_group_name, action_group_name, custom_headers: nil) ⇒ MsRestAzure::AzureOperationResponse

Delete an action group.

will be added to the HTTP request.

Parameters:

  • resource_group_name (String)

    The name of the resource group.

  • action_group_name (String)

    The name of the action group.

  • custom_headers (Hash{String => String}) (defaults to: nil)

    A hash of custom headers that

Returns:

  • (MsRestAzure::AzureOperationResponse)

    HTTP response information.



260
261
262
# File 'lib/2018-03-01/generated/azure_mgmt_monitor/action_groups.rb', line 260

def delete_with_http_info(resource_group_name, action_group_name, custom_headers:nil)
  delete_async(resource_group_name, action_group_name, custom_headers:custom_headers).value!
end

#enable_receiver(resource_group_name, action_group_name, enable_request, custom_headers: nil) ⇒ Object

Enable a receiver in an action group. This changes the receiver's status from Disabled to Enabled. This operation is only supported for Email or SMS receivers.

will be added to the HTTP request.

Parameters:

  • resource_group_name (String)

    The name of the resource group.

  • action_group_name (String)

    The name of the action group.

  • enable_request (EnableRequest)

    The receiver to re-enable.

  • custom_headers (Hash{String => String}) (defaults to: nil)

    A hash of custom headers that



618
619
620
621
# File 'lib/2018-03-01/generated/azure_mgmt_monitor/action_groups.rb', line 618

def enable_receiver(resource_group_name, action_group_name, enable_request, custom_headers:nil)
  response = enable_receiver_async(resource_group_name, action_group_name, enable_request, custom_headers:custom_headers).value!
  nil
end

#enable_receiver_async(resource_group_name, action_group_name, enable_request, custom_headers: nil) ⇒ Concurrent::Promise

Enable a receiver in an action group. This changes the receiver's status from Disabled to Enabled. This operation is only supported for Email or SMS receivers.

to the HTTP request.

Parameters:

  • resource_group_name (String)

    The name of the resource group.

  • action_group_name (String)

    The name of the action group.

  • enable_request (EnableRequest)

    The receiver to re-enable.

  • A (Hash{String => String})

    hash of custom headers that will be added

Returns:

  • (Concurrent::Promise)

    Promise object which holds the HTTP response.



653
654
655
656
657
658
659
660
661
662
663
664
665
666
667
668
669
670
671
672
673
674
675
676
677
678
679
680
681
682
683
684
685
686
687
688
689
690
691
692
693
694
695
696
697
698
699
700
701
702
703
704
# File 'lib/2018-03-01/generated/azure_mgmt_monitor/action_groups.rb', line 653

def enable_receiver_async(resource_group_name, action_group_name, enable_request, custom_headers:nil)
  fail ArgumentError, 'resource_group_name is nil' if resource_group_name.nil?
  fail ArgumentError, 'action_group_name is nil' if action_group_name.nil?
  fail ArgumentError, 'enable_request is nil' if enable_request.nil?
  fail ArgumentError, '@client.subscription_id is nil' if @client.subscription_id.nil?
  fail ArgumentError, '@client.api_version is nil' if @client.api_version.nil?


  request_headers = {}
  request_headers['Content-Type'] = 'application/json; charset=utf-8'

  # Set Headers
  request_headers['x-ms-client-request-id'] = SecureRandom.uuid
  request_headers['accept-language'] = @client.accept_language unless @client.accept_language.nil?

  # Serialize Request
  request_mapper = Azure::Monitor::Mgmt::V2018_03_01::Models::EnableRequest.mapper()
  request_content = @client.serialize(request_mapper,  enable_request)
  request_content = request_content != nil ? JSON.generate(request_content, quirks_mode: true) : nil

  path_template = 'subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/microsoft.insights/actionGroups/{actionGroupName}/subscribe'

  request_url = @base_url || @client.base_url

  options = {
      middlewares: [[MsRest::RetryPolicyMiddleware, times: 3, retry: 0.02], [:cookie_jar]],
      path_params: {'resourceGroupName' => resource_group_name,'actionGroupName' => action_group_name,'subscriptionId' => @client.subscription_id},
      query_params: {'api-version' => @client.api_version},
      body: request_content,
      headers: request_headers.merge(custom_headers || {}),
      base_url: request_url
  }
  promise = @client.make_request_async(:post, path_template, options)

  promise = promise.then do |result|
    http_response = result.response
    status_code = http_response.status
    response_content = http_response.body
    unless status_code == 200 || status_code == 409
      error_model = JSON.load(response_content)
      fail MsRest::HttpOperationError.new(result.request, http_response, error_model)
    end

    result.request_id = http_response['x-ms-request-id'] unless http_response['x-ms-request-id'].nil?
    result.correlation_request_id = http_response['x-ms-correlation-request-id'] unless http_response['x-ms-correlation-request-id'].nil?
    result.client_request_id = http_response['x-ms-client-request-id'] unless http_response['x-ms-client-request-id'].nil?

    result
  end

  promise.execute
end

#enable_receiver_with_http_info(resource_group_name, action_group_name, enable_request, custom_headers: nil) ⇒ MsRestAzure::AzureOperationResponse

Enable a receiver in an action group. This changes the receiver's status from Disabled to Enabled. This operation is only supported for Email or SMS receivers.

will be added to the HTTP request.

Parameters:

  • resource_group_name (String)

    The name of the resource group.

  • action_group_name (String)

    The name of the action group.

  • enable_request (EnableRequest)

    The receiver to re-enable.

  • custom_headers (Hash{String => String}) (defaults to: nil)

    A hash of custom headers that

Returns:

  • (MsRestAzure::AzureOperationResponse)

    HTTP response information.



636
637
638
# File 'lib/2018-03-01/generated/azure_mgmt_monitor/action_groups.rb', line 636

def enable_receiver_with_http_info(resource_group_name, action_group_name, enable_request, custom_headers:nil)
  enable_receiver_async(resource_group_name, action_group_name, enable_request, custom_headers:custom_headers).value!
end

#get(resource_group_name, action_group_name, custom_headers: nil) ⇒ ActionGroupResource

Get an action group.

will be added to the HTTP request.

Parameters:

  • resource_group_name (String)

    The name of the resource group.

  • action_group_name (String)

    The name of the action group.

  • custom_headers (Hash{String => String}) (defaults to: nil)

    A hash of custom headers that

Returns:

  • (ActionGroupResource)

    operation results.



152
153
154
155
# File 'lib/2018-03-01/generated/azure_mgmt_monitor/action_groups.rb', line 152

def get(resource_group_name, action_group_name, custom_headers:nil)
  response = get_async(resource_group_name, action_group_name, custom_headers:custom_headers).value!
  response.body unless response.nil?
end

#get_async(resource_group_name, action_group_name, custom_headers: nil) ⇒ Concurrent::Promise

Get an action group.

to the HTTP request.

Parameters:

  • resource_group_name (String)

    The name of the resource group.

  • action_group_name (String)

    The name of the action group.

  • A (Hash{String => String})

    hash of custom headers that will be added

Returns:

  • (Concurrent::Promise)

    Promise object which holds the HTTP response.



181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
# File 'lib/2018-03-01/generated/azure_mgmt_monitor/action_groups.rb', line 181

def get_async(resource_group_name, action_group_name, custom_headers:nil)
  fail ArgumentError, 'resource_group_name is nil' if resource_group_name.nil?
  fail ArgumentError, 'action_group_name is nil' if action_group_name.nil?
  fail ArgumentError, '@client.subscription_id is nil' if @client.subscription_id.nil?
  fail ArgumentError, '@client.api_version is nil' if @client.api_version.nil?


  request_headers = {}
  request_headers['Content-Type'] = 'application/json; charset=utf-8'

  # Set Headers
  request_headers['x-ms-client-request-id'] = SecureRandom.uuid
  request_headers['accept-language'] = @client.accept_language unless @client.accept_language.nil?
  path_template = 'subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/microsoft.insights/actionGroups/{actionGroupName}'

  request_url = @base_url || @client.base_url

  options = {
      middlewares: [[MsRest::RetryPolicyMiddleware, times: 3, retry: 0.02], [:cookie_jar]],
      path_params: {'resourceGroupName' => resource_group_name,'actionGroupName' => action_group_name,'subscriptionId' => @client.subscription_id},
      query_params: {'api-version' => @client.api_version},
      headers: request_headers.merge(custom_headers || {}),
      base_url: request_url
  }
  promise = @client.make_request_async(:get, path_template, options)

  promise = promise.then do |result|
    http_response = result.response
    status_code = http_response.status
    response_content = http_response.body
    unless status_code == 200
      error_model = JSON.load(response_content)
      fail MsRest::HttpOperationError.new(result.request, http_response, error_model)
    end

    result.request_id = http_response['x-ms-request-id'] unless http_response['x-ms-request-id'].nil?
    result.correlation_request_id = http_response['x-ms-correlation-request-id'] unless http_response['x-ms-correlation-request-id'].nil?
    result.client_request_id = http_response['x-ms-client-request-id'] unless http_response['x-ms-client-request-id'].nil?
    # Deserialize Response
    if status_code == 200
      begin
        parsed_response = response_content.to_s.empty? ? nil : JSON.load(response_content)
        result_mapper = Azure::Monitor::Mgmt::V2018_03_01::Models::ActionGroupResource.mapper()
        result.body = @client.deserialize(result_mapper, parsed_response)
      rescue Exception => e
        fail MsRest::DeserializationError.new('Error occurred in deserializing the response', e.message, e.backtrace, result)
      end
    end

    result
  end

  promise.execute
end

#get_with_http_info(resource_group_name, action_group_name, custom_headers: nil) ⇒ MsRestAzure::AzureOperationResponse

Get an action group.

will be added to the HTTP request.

Parameters:

  • resource_group_name (String)

    The name of the resource group.

  • action_group_name (String)

    The name of the action group.

  • custom_headers (Hash{String => String}) (defaults to: nil)

    A hash of custom headers that

Returns:

  • (MsRestAzure::AzureOperationResponse)

    HTTP response information.



167
168
169
# File 'lib/2018-03-01/generated/azure_mgmt_monitor/action_groups.rb', line 167

def get_with_http_info(resource_group_name, action_group_name, custom_headers:nil)
  get_async(resource_group_name, action_group_name, custom_headers:custom_headers).value!
end

#list_by_resource_group(resource_group_name, custom_headers: nil) ⇒ ActionGroupList

Get a list of all action groups in a resource group.

will be added to the HTTP request.

Parameters:

  • resource_group_name (String)

    The name of the resource group.

  • custom_headers (Hash{String => String}) (defaults to: nil)

    A hash of custom headers that

Returns:

  • (ActionGroupList)

    operation results.



525
526
527
528
# File 'lib/2018-03-01/generated/azure_mgmt_monitor/action_groups.rb', line 525

def list_by_resource_group(resource_group_name, custom_headers:nil)
  response = list_by_resource_group_async(resource_group_name, custom_headers:custom_headers).value!
  response.body unless response.nil?
end

#list_by_resource_group_async(resource_group_name, custom_headers: nil) ⇒ Concurrent::Promise

Get a list of all action groups in a resource group.

to the HTTP request.

Parameters:

  • resource_group_name (String)

    The name of the resource group.

  • A (Hash{String => String})

    hash of custom headers that will be added

Returns:

  • (Concurrent::Promise)

    Promise object which holds the HTTP response.



552
553
554
555
556
557
558
559
560
561
562
563
564
565
566
567
568
569
570
571
572
573
574
575
576
577
578
579
580
581
582
583
584
585
586
587
588
589
590
591
592
593
594
595
596
597
598
599
600
601
602
603
604
# File 'lib/2018-03-01/generated/azure_mgmt_monitor/action_groups.rb', line 552

def list_by_resource_group_async(resource_group_name, custom_headers:nil)
  fail ArgumentError, 'resource_group_name is nil' if resource_group_name.nil?
  fail ArgumentError, '@client.subscription_id is nil' if @client.subscription_id.nil?
  fail ArgumentError, '@client.api_version is nil' if @client.api_version.nil?


  request_headers = {}
  request_headers['Content-Type'] = 'application/json; charset=utf-8'

  # Set Headers
  request_headers['x-ms-client-request-id'] = SecureRandom.uuid
  request_headers['accept-language'] = @client.accept_language unless @client.accept_language.nil?
  path_template = 'subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/microsoft.insights/actionGroups'

  request_url = @base_url || @client.base_url

  options = {
      middlewares: [[MsRest::RetryPolicyMiddleware, times: 3, retry: 0.02], [:cookie_jar]],
      path_params: {'resourceGroupName' => resource_group_name,'subscriptionId' => @client.subscription_id},
      query_params: {'api-version' => @client.api_version},
      headers: request_headers.merge(custom_headers || {}),
      base_url: request_url
  }
  promise = @client.make_request_async(:get, path_template, options)

  promise = promise.then do |result|
    http_response = result.response
    status_code = http_response.status
    response_content = http_response.body
    unless status_code == 200
      error_model = JSON.load(response_content)
      fail MsRest::HttpOperationError.new(result.request, http_response, error_model)
    end

    result.request_id = http_response['x-ms-request-id'] unless http_response['x-ms-request-id'].nil?
    result.correlation_request_id = http_response['x-ms-correlation-request-id'] unless http_response['x-ms-correlation-request-id'].nil?
    result.client_request_id = http_response['x-ms-client-request-id'] unless http_response['x-ms-client-request-id'].nil?
    # Deserialize Response
    if status_code == 200
      begin
        parsed_response = response_content.to_s.empty? ? nil : JSON.load(response_content)
        result_mapper = Azure::Monitor::Mgmt::V2018_03_01::Models::ActionGroupList.mapper()
        result.body = @client.deserialize(result_mapper, parsed_response)
      rescue Exception => e
        fail MsRest::DeserializationError.new('Error occurred in deserializing the response', e.message, e.backtrace, result)
      end
    end

    result
  end

  promise.execute
end

#list_by_resource_group_with_http_info(resource_group_name, custom_headers: nil) ⇒ MsRestAzure::AzureOperationResponse

Get a list of all action groups in a resource group.

will be added to the HTTP request.

Parameters:

  • resource_group_name (String)

    The name of the resource group.

  • custom_headers (Hash{String => String}) (defaults to: nil)

    A hash of custom headers that

Returns:

  • (MsRestAzure::AzureOperationResponse)

    HTTP response information.



539
540
541
# File 'lib/2018-03-01/generated/azure_mgmt_monitor/action_groups.rb', line 539

def list_by_resource_group_with_http_info(resource_group_name, custom_headers:nil)
  list_by_resource_group_async(resource_group_name, custom_headers:custom_headers).value!
end

#list_by_subscription_id(custom_headers: nil) ⇒ ActionGroupList

Get a list of all action groups in a subscription.

will be added to the HTTP request.

Parameters:

  • custom_headers (Hash{String => String}) (defaults to: nil)

    A hash of custom headers that

Returns:

  • (ActionGroupList)

    operation results.



438
439
440
441
# File 'lib/2018-03-01/generated/azure_mgmt_monitor/action_groups.rb', line 438

def list_by_subscription_id(custom_headers:nil)
  response = list_by_subscription_id_async(custom_headers:custom_headers).value!
  response.body unless response.nil?
end

#list_by_subscription_id_async(custom_headers: nil) ⇒ Concurrent::Promise

Get a list of all action groups in a subscription.

to the HTTP request.

Parameters:

  • A (Hash{String => String})

    hash of custom headers that will be added

Returns:

  • (Concurrent::Promise)

    Promise object which holds the HTTP response.



463
464
465
466
467
468
469
470
471
472
473
474
475
476
477
478
479
480
481
482
483
484
485
486
487
488
489
490
491
492
493
494
495
496
497
498
499
500
501
502
503
504
505
506
507
508
509
510
511
512
513
514
# File 'lib/2018-03-01/generated/azure_mgmt_monitor/action_groups.rb', line 463

def list_by_subscription_id_async(custom_headers:nil)
  fail ArgumentError, '@client.subscription_id is nil' if @client.subscription_id.nil?
  fail ArgumentError, '@client.api_version is nil' if @client.api_version.nil?


  request_headers = {}
  request_headers['Content-Type'] = 'application/json; charset=utf-8'

  # Set Headers
  request_headers['x-ms-client-request-id'] = SecureRandom.uuid
  request_headers['accept-language'] = @client.accept_language unless @client.accept_language.nil?
  path_template = 'subscriptions/{subscriptionId}/providers/microsoft.insights/actionGroups'

  request_url = @base_url || @client.base_url

  options = {
      middlewares: [[MsRest::RetryPolicyMiddleware, times: 3, retry: 0.02], [:cookie_jar]],
      path_params: {'subscriptionId' => @client.subscription_id},
      query_params: {'api-version' => @client.api_version},
      headers: request_headers.merge(custom_headers || {}),
      base_url: request_url
  }
  promise = @client.make_request_async(:get, path_template, options)

  promise = promise.then do |result|
    http_response = result.response
    status_code = http_response.status
    response_content = http_response.body
    unless status_code == 200
      error_model = JSON.load(response_content)
      fail MsRest::HttpOperationError.new(result.request, http_response, error_model)
    end

    result.request_id = http_response['x-ms-request-id'] unless http_response['x-ms-request-id'].nil?
    result.correlation_request_id = http_response['x-ms-correlation-request-id'] unless http_response['x-ms-correlation-request-id'].nil?
    result.client_request_id = http_response['x-ms-client-request-id'] unless http_response['x-ms-client-request-id'].nil?
    # Deserialize Response
    if status_code == 200
      begin
        parsed_response = response_content.to_s.empty? ? nil : JSON.load(response_content)
        result_mapper = Azure::Monitor::Mgmt::V2018_03_01::Models::ActionGroupList.mapper()
        result.body = @client.deserialize(result_mapper, parsed_response)
      rescue Exception => e
        fail MsRest::DeserializationError.new('Error occurred in deserializing the response', e.message, e.backtrace, result)
      end
    end

    result
  end

  promise.execute
end

#list_by_subscription_id_with_http_info(custom_headers: nil) ⇒ MsRestAzure::AzureOperationResponse

Get a list of all action groups in a subscription.

will be added to the HTTP request.

Parameters:

  • custom_headers (Hash{String => String}) (defaults to: nil)

    A hash of custom headers that

Returns:

  • (MsRestAzure::AzureOperationResponse)

    HTTP response information.



451
452
453
# File 'lib/2018-03-01/generated/azure_mgmt_monitor/action_groups.rb', line 451

def list_by_subscription_id_with_http_info(custom_headers:nil)
  list_by_subscription_id_async(custom_headers:custom_headers).value!
end

#update(resource_group_name, action_group_name, action_group_patch, custom_headers: nil) ⇒ ActionGroupResource

Updates an existing action group's tags. To update other fields use the CreateOrUpdate method.

operation. will be added to the HTTP request.

Parameters:

  • resource_group_name (String)

    The name of the resource group.

  • action_group_name (String)

    The name of the action group.

  • action_group_patch (ActionGroupPatchBody)

    Parameters supplied to the

  • custom_headers (Hash{String => String}) (defaults to: nil)

    A hash of custom headers that

Returns:

  • (ActionGroupResource)

    operation results.



332
333
334
335
# File 'lib/2018-03-01/generated/azure_mgmt_monitor/action_groups.rb', line 332

def update(resource_group_name, action_group_name, action_group_patch, custom_headers:nil)
  response = update_async(resource_group_name, action_group_name, action_group_patch, custom_headers:custom_headers).value!
  response.body unless response.nil?
end

#update_async(resource_group_name, action_group_name, action_group_patch, custom_headers: nil) ⇒ Concurrent::Promise

Updates an existing action group's tags. To update other fields use the CreateOrUpdate method.

operation. to the HTTP request.

Parameters:

  • resource_group_name (String)

    The name of the resource group.

  • action_group_name (String)

    The name of the action group.

  • action_group_patch (ActionGroupPatchBody)

    Parameters supplied to the

  • A (Hash{String => String})

    hash of custom headers that will be added

Returns:

  • (Concurrent::Promise)

    Promise object which holds the HTTP response.



367
368
369
370
371
372
373
374
375
376
377
378
379
380
381
382
383
384
385
386
387
388
389
390
391
392
393
394
395
396
397
398
399
400
401
402
403
404
405
406
407
408
409
410
411
412
413
414
415
416
417
418
419
420
421
422
423
424
425
426
427
428
# File 'lib/2018-03-01/generated/azure_mgmt_monitor/action_groups.rb', line 367

def update_async(resource_group_name, action_group_name, action_group_patch, custom_headers:nil)
  fail ArgumentError, '@client.subscription_id is nil' if @client.subscription_id.nil?
  fail ArgumentError, 'resource_group_name is nil' if resource_group_name.nil?
  fail ArgumentError, 'action_group_name is nil' if action_group_name.nil?
  fail ArgumentError, '@client.api_version is nil' if @client.api_version.nil?
  fail ArgumentError, 'action_group_patch is nil' if action_group_patch.nil?


  request_headers = {}
  request_headers['Content-Type'] = 'application/json; charset=utf-8'

  # Set Headers
  request_headers['x-ms-client-request-id'] = SecureRandom.uuid
  request_headers['accept-language'] = @client.accept_language unless @client.accept_language.nil?

  # Serialize Request
  request_mapper = Azure::Monitor::Mgmt::V2018_03_01::Models::ActionGroupPatchBody.mapper()
  request_content = @client.serialize(request_mapper,  action_group_patch)
  request_content = request_content != nil ? JSON.generate(request_content, quirks_mode: true) : nil

  path_template = 'subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/microsoft.insights/actionGroups/{actionGroupName}'

  request_url = @base_url || @client.base_url

  options = {
      middlewares: [[MsRest::RetryPolicyMiddleware, times: 3, retry: 0.02], [:cookie_jar]],
      path_params: {'subscriptionId' => @client.subscription_id,'resourceGroupName' => resource_group_name,'actionGroupName' => action_group_name},
      query_params: {'api-version' => @client.api_version},
      body: request_content,
      headers: request_headers.merge(custom_headers || {}),
      base_url: request_url
  }
  promise = @client.make_request_async(:patch, path_template, options)

  promise = promise.then do |result|
    http_response = result.response
    status_code = http_response.status
    response_content = http_response.body
    unless status_code == 200
      error_model = JSON.load(response_content)
      fail MsRest::HttpOperationError.new(result.request, http_response, error_model)
    end

    result.request_id = http_response['x-ms-request-id'] unless http_response['x-ms-request-id'].nil?
    result.correlation_request_id = http_response['x-ms-correlation-request-id'] unless http_response['x-ms-correlation-request-id'].nil?
    result.client_request_id = http_response['x-ms-client-request-id'] unless http_response['x-ms-client-request-id'].nil?
    # Deserialize Response
    if status_code == 200
      begin
        parsed_response = response_content.to_s.empty? ? nil : JSON.load(response_content)
        result_mapper = Azure::Monitor::Mgmt::V2018_03_01::Models::ActionGroupResource.mapper()
        result.body = @client.deserialize(result_mapper, parsed_response)
      rescue Exception => e
        fail MsRest::DeserializationError.new('Error occurred in deserializing the response', e.message, e.backtrace, result)
      end
    end

    result
  end

  promise.execute
end

#update_with_http_info(resource_group_name, action_group_name, action_group_patch, custom_headers: nil) ⇒ MsRestAzure::AzureOperationResponse

Updates an existing action group's tags. To update other fields use the CreateOrUpdate method.

operation. will be added to the HTTP request.

Parameters:

  • resource_group_name (String)

    The name of the resource group.

  • action_group_name (String)

    The name of the action group.

  • action_group_patch (ActionGroupPatchBody)

    Parameters supplied to the

  • custom_headers (Hash{String => String}) (defaults to: nil)

    A hash of custom headers that

Returns:

  • (MsRestAzure::AzureOperationResponse)

    HTTP response information.



350
351
352
# File 'lib/2018-03-01/generated/azure_mgmt_monitor/action_groups.rb', line 350

def update_with_http_info(resource_group_name, action_group_name, action_group_patch, custom_headers:nil)
  update_async(resource_group_name, action_group_name, action_group_patch, custom_headers:custom_headers).value!
end