Class: Azure::Monitor::Mgmt::V2018_04_16::ScheduledQueryRules

Inherits:
Object
  • Object
show all
Includes:
MsRestAzure
Defined in:
lib/2018-04-16/generated/azure_mgmt_monitor/scheduled_query_rules.rb

Overview

Monitor Management Client

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(client) ⇒ ScheduledQueryRules

Creates and initializes a new instance of the ScheduledQueryRules class.

Parameters:

  • client

    service class for accessing basic functionality.



17
18
19
# File 'lib/2018-04-16/generated/azure_mgmt_monitor/scheduled_query_rules.rb', line 17

def initialize(client)
  @client = client
end

Instance Attribute Details

#clientMonitorClient (readonly)

Returns reference to the MonitorClient.

Returns:



22
23
24
# File 'lib/2018-04-16/generated/azure_mgmt_monitor/scheduled_query_rules.rb', line 22

def client
  @client
end

Instance Method Details

#create_or_update(resource_group_name, rule_name, parameters, custom_headers: nil) ⇒ LogSearchRuleResource

Creates or updates an log search rule.

create or update. will be added to the HTTP request.

Parameters:

  • resource_group_name (String)

    The name of the resource group.

  • rule_name (String)

    The name of the rule.

  • parameters (LogSearchRuleResource)

    The parameters of the rule to

  • custom_headers (Hash{String => String}) (defaults to: nil)

    A hash of custom headers that

Returns:

  • (LogSearchRuleResource)

    operation results.



36
37
38
39
# File 'lib/2018-04-16/generated/azure_mgmt_monitor/scheduled_query_rules.rb', line 36

def create_or_update(resource_group_name, rule_name, parameters, custom_headers:nil)
  response = create_or_update_async(resource_group_name, rule_name, parameters, custom_headers:custom_headers).value!
  response.body unless response.nil?
end

#create_or_update_async(resource_group_name, rule_name, parameters, custom_headers: nil) ⇒ Concurrent::Promise

Creates or updates an log search rule.

create or update. to the HTTP request.

Parameters:

  • resource_group_name (String)

    The name of the resource group.

  • rule_name (String)

    The name of the rule.

  • parameters (LogSearchRuleResource)

    The parameters of the rule to

  • A (Hash{String => String})

    hash of custom headers that will be added

Returns:

  • (Concurrent::Promise)

    Promise object which holds the HTTP response.



69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
# File 'lib/2018-04-16/generated/azure_mgmt_monitor/scheduled_query_rules.rb', line 69

def create_or_update_async(resource_group_name, rule_name, parameters, custom_headers:nil)
  fail ArgumentError, '@client.subscription_id is nil' if @client.subscription_id.nil?
  fail ArgumentError, 'resource_group_name is nil' if resource_group_name.nil?
  fail ArgumentError, 'rule_name is nil' if rule_name.nil?
  fail ArgumentError, '@client.api_version is nil' if @client.api_version.nil?
  fail ArgumentError, 'parameters is nil' if parameters.nil?


  request_headers = {}
  request_headers['Content-Type'] = 'application/json; charset=utf-8'

  # Set Headers
  request_headers['x-ms-client-request-id'] = SecureRandom.uuid
  request_headers['accept-language'] = @client.accept_language unless @client.accept_language.nil?

  # Serialize Request
  request_mapper = Azure::Monitor::Mgmt::V2018_04_16::Models::LogSearchRuleResource.mapper()
  request_content = @client.serialize(request_mapper,  parameters)
  request_content = request_content != nil ? JSON.generate(request_content, quirks_mode: true) : nil

  path_template = 'subscriptions/{subscriptionId}/resourcegroups/{resourceGroupName}/providers/microsoft.insights/scheduledQueryRules/{ruleName}'

  request_url = @base_url || @client.base_url

  options = {
      middlewares: [[MsRest::RetryPolicyMiddleware, times: 3, retry: 0.02], [:cookie_jar]],
      path_params: {'subscriptionId' => @client.subscription_id,'resourceGroupName' => resource_group_name,'ruleName' => rule_name},
      query_params: {'api-version' => @client.api_version},
      body: request_content,
      headers: request_headers.merge(custom_headers || {}),
      base_url: request_url
  }
  promise = @client.make_request_async(:put, path_template, options)

  promise = promise.then do |result|
    http_response = result.response
    status_code = http_response.status
    response_content = http_response.body
    unless status_code == 200 || status_code == 201
      error_model = JSON.load(response_content)
      fail MsRest::HttpOperationError.new(result.request, http_response, error_model)
    end

    result.request_id = http_response['x-ms-request-id'] unless http_response['x-ms-request-id'].nil?
    result.correlation_request_id = http_response['x-ms-correlation-request-id'] unless http_response['x-ms-correlation-request-id'].nil?
    result.client_request_id = http_response['x-ms-client-request-id'] unless http_response['x-ms-client-request-id'].nil?
    # Deserialize Response
    if status_code == 200
      begin
        parsed_response = response_content.to_s.empty? ? nil : JSON.load(response_content)
        result_mapper = Azure::Monitor::Mgmt::V2018_04_16::Models::LogSearchRuleResource.mapper()
        result.body = @client.deserialize(result_mapper, parsed_response)
      rescue Exception => e
        fail MsRest::DeserializationError.new('Error occurred in deserializing the response', e.message, e.backtrace, result)
      end
    end
    # Deserialize Response
    if status_code == 201
      begin
        parsed_response = response_content.to_s.empty? ? nil : JSON.load(response_content)
        result_mapper = Azure::Monitor::Mgmt::V2018_04_16::Models::LogSearchRuleResource.mapper()
        result.body = @client.deserialize(result_mapper, parsed_response)
      rescue Exception => e
        fail MsRest::DeserializationError.new('Error occurred in deserializing the response', e.message, e.backtrace, result)
      end
    end

    result
  end

  promise.execute
end

#create_or_update_with_http_info(resource_group_name, rule_name, parameters, custom_headers: nil) ⇒ MsRestAzure::AzureOperationResponse

Creates or updates an log search rule.

create or update. will be added to the HTTP request.

Parameters:

  • resource_group_name (String)

    The name of the resource group.

  • rule_name (String)

    The name of the rule.

  • parameters (LogSearchRuleResource)

    The parameters of the rule to

  • custom_headers (Hash{String => String}) (defaults to: nil)

    A hash of custom headers that

Returns:

  • (MsRestAzure::AzureOperationResponse)

    HTTP response information.



53
54
55
# File 'lib/2018-04-16/generated/azure_mgmt_monitor/scheduled_query_rules.rb', line 53

def create_or_update_with_http_info(resource_group_name, rule_name, parameters, custom_headers:nil)
  create_or_update_async(resource_group_name, rule_name, parameters, custom_headers:custom_headers).value!
end

#delete(resource_group_name, rule_name, custom_headers: nil) ⇒ Object

Deletes a Log Search rule

will be added to the HTTP request.

Parameters:

  • resource_group_name (String)

    The name of the resource group.

  • rule_name (String)

    The name of the rule.

  • custom_headers (Hash{String => String}) (defaults to: nil)

    A hash of custom headers that



353
354
355
356
# File 'lib/2018-04-16/generated/azure_mgmt_monitor/scheduled_query_rules.rb', line 353

def delete(resource_group_name, rule_name, custom_headers:nil)
  response = delete_async(resource_group_name, rule_name, custom_headers:custom_headers).value!
  nil
end

#delete_async(resource_group_name, rule_name, custom_headers: nil) ⇒ Concurrent::Promise

Deletes a Log Search rule

to the HTTP request.

Parameters:

  • resource_group_name (String)

    The name of the resource group.

  • rule_name (String)

    The name of the rule.

  • A (Hash{String => String})

    hash of custom headers that will be added

Returns:

  • (Concurrent::Promise)

    Promise object which holds the HTTP response.



382
383
384
385
386
387
388
389
390
391
392
393
394
395
396
397
398
399
400
401
402
403
404
405
406
407
408
409
410
411
412
413
414
415
416
417
418
419
420
421
422
423
424
425
# File 'lib/2018-04-16/generated/azure_mgmt_monitor/scheduled_query_rules.rb', line 382

def delete_async(resource_group_name, rule_name, custom_headers:nil)
  fail ArgumentError, 'resource_group_name is nil' if resource_group_name.nil?
  fail ArgumentError, 'rule_name is nil' if rule_name.nil?
  fail ArgumentError, '@client.api_version is nil' if @client.api_version.nil?
  fail ArgumentError, '@client.subscription_id is nil' if @client.subscription_id.nil?


  request_headers = {}
  request_headers['Content-Type'] = 'application/json; charset=utf-8'

  # Set Headers
  request_headers['x-ms-client-request-id'] = SecureRandom.uuid
  request_headers['accept-language'] = @client.accept_language unless @client.accept_language.nil?
  path_template = 'subscriptions/{subscriptionId}/resourcegroups/{resourceGroupName}/providers/microsoft.insights/scheduledQueryRules/{ruleName}'

  request_url = @base_url || @client.base_url

  options = {
      middlewares: [[MsRest::RetryPolicyMiddleware, times: 3, retry: 0.02], [:cookie_jar]],
      path_params: {'resourceGroupName' => resource_group_name,'ruleName' => rule_name,'subscriptionId' => @client.subscription_id},
      query_params: {'api-version' => @client.api_version},
      headers: request_headers.merge(custom_headers || {}),
      base_url: request_url
  }
  promise = @client.make_request_async(:delete, path_template, options)

  promise = promise.then do |result|
    http_response = result.response
    status_code = http_response.status
    response_content = http_response.body
    unless status_code == 200 || status_code == 204
      error_model = JSON.load(response_content)
      fail MsRest::HttpOperationError.new(result.request, http_response, error_model)
    end

    result.request_id = http_response['x-ms-request-id'] unless http_response['x-ms-request-id'].nil?
    result.correlation_request_id = http_response['x-ms-correlation-request-id'] unless http_response['x-ms-correlation-request-id'].nil?
    result.client_request_id = http_response['x-ms-client-request-id'] unless http_response['x-ms-client-request-id'].nil?

    result
  end

  promise.execute
end

#delete_with_http_info(resource_group_name, rule_name, custom_headers: nil) ⇒ MsRestAzure::AzureOperationResponse

Deletes a Log Search rule

will be added to the HTTP request.

Parameters:

  • resource_group_name (String)

    The name of the resource group.

  • rule_name (String)

    The name of the rule.

  • custom_headers (Hash{String => String}) (defaults to: nil)

    A hash of custom headers that

Returns:

  • (MsRestAzure::AzureOperationResponse)

    HTTP response information.



368
369
370
# File 'lib/2018-04-16/generated/azure_mgmt_monitor/scheduled_query_rules.rb', line 368

def delete_with_http_info(resource_group_name, rule_name, custom_headers:nil)
  delete_async(resource_group_name, rule_name, custom_headers:custom_headers).value!
end

#get(resource_group_name, rule_name, custom_headers: nil) ⇒ LogSearchRuleResource

Gets an Log Search rule

will be added to the HTTP request.

Parameters:

  • resource_group_name (String)

    The name of the resource group.

  • rule_name (String)

    The name of the rule.

  • custom_headers (Hash{String => String}) (defaults to: nil)

    A hash of custom headers that

Returns:

  • (LogSearchRuleResource)

    operation results.



152
153
154
155
# File 'lib/2018-04-16/generated/azure_mgmt_monitor/scheduled_query_rules.rb', line 152

def get(resource_group_name, rule_name, custom_headers:nil)
  response = get_async(resource_group_name, rule_name, custom_headers:custom_headers).value!
  response.body unless response.nil?
end

#get_async(resource_group_name, rule_name, custom_headers: nil) ⇒ Concurrent::Promise

Gets an Log Search rule

to the HTTP request.

Parameters:

  • resource_group_name (String)

    The name of the resource group.

  • rule_name (String)

    The name of the rule.

  • A (Hash{String => String})

    hash of custom headers that will be added

Returns:

  • (Concurrent::Promise)

    Promise object which holds the HTTP response.



181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
# File 'lib/2018-04-16/generated/azure_mgmt_monitor/scheduled_query_rules.rb', line 181

def get_async(resource_group_name, rule_name, custom_headers:nil)
  fail ArgumentError, 'resource_group_name is nil' if resource_group_name.nil?
  fail ArgumentError, 'rule_name is nil' if rule_name.nil?
  fail ArgumentError, '@client.api_version is nil' if @client.api_version.nil?
  fail ArgumentError, '@client.subscription_id is nil' if @client.subscription_id.nil?


  request_headers = {}
  request_headers['Content-Type'] = 'application/json; charset=utf-8'

  # Set Headers
  request_headers['x-ms-client-request-id'] = SecureRandom.uuid
  request_headers['accept-language'] = @client.accept_language unless @client.accept_language.nil?
  path_template = 'subscriptions/{subscriptionId}/resourcegroups/{resourceGroupName}/providers/microsoft.insights/scheduledQueryRules/{ruleName}'

  request_url = @base_url || @client.base_url

  options = {
      middlewares: [[MsRest::RetryPolicyMiddleware, times: 3, retry: 0.02], [:cookie_jar]],
      path_params: {'resourceGroupName' => resource_group_name,'ruleName' => rule_name,'subscriptionId' => @client.subscription_id},
      query_params: {'api-version' => @client.api_version},
      headers: request_headers.merge(custom_headers || {}),
      base_url: request_url
  }
  promise = @client.make_request_async(:get, path_template, options)

  promise = promise.then do |result|
    http_response = result.response
    status_code = http_response.status
    response_content = http_response.body
    unless status_code == 200
      error_model = JSON.load(response_content)
      fail MsRest::HttpOperationError.new(result.request, http_response, error_model)
    end

    result.request_id = http_response['x-ms-request-id'] unless http_response['x-ms-request-id'].nil?
    result.correlation_request_id = http_response['x-ms-correlation-request-id'] unless http_response['x-ms-correlation-request-id'].nil?
    result.client_request_id = http_response['x-ms-client-request-id'] unless http_response['x-ms-client-request-id'].nil?
    # Deserialize Response
    if status_code == 200
      begin
        parsed_response = response_content.to_s.empty? ? nil : JSON.load(response_content)
        result_mapper = Azure::Monitor::Mgmt::V2018_04_16::Models::LogSearchRuleResource.mapper()
        result.body = @client.deserialize(result_mapper, parsed_response)
      rescue Exception => e
        fail MsRest::DeserializationError.new('Error occurred in deserializing the response', e.message, e.backtrace, result)
      end
    end

    result
  end

  promise.execute
end

#get_with_http_info(resource_group_name, rule_name, custom_headers: nil) ⇒ MsRestAzure::AzureOperationResponse

Gets an Log Search rule

will be added to the HTTP request.

Parameters:

  • resource_group_name (String)

    The name of the resource group.

  • rule_name (String)

    The name of the rule.

  • custom_headers (Hash{String => String}) (defaults to: nil)

    A hash of custom headers that

Returns:

  • (MsRestAzure::AzureOperationResponse)

    HTTP response information.



167
168
169
# File 'lib/2018-04-16/generated/azure_mgmt_monitor/scheduled_query_rules.rb', line 167

def get_with_http_info(resource_group_name, rule_name, custom_headers:nil)
  get_async(resource_group_name, rule_name, custom_headers:custom_headers).value!
end

#list_by_resource_group(resource_group_name, filter: nil, custom_headers: nil) ⇒ LogSearchRuleResourceCollection

List the Log Search rules within a resource group.

information please see msdn.microsoft.com/en-us/library/azure/dn931934.aspx will be added to the HTTP request.

Parameters:

  • resource_group_name (String)

    The name of the resource group.

  • filter (String) (defaults to: nil)

    The filter to apply on the operation. For more

  • custom_headers (Hash{String => String}) (defaults to: nil)

    A hash of custom headers that

Returns:

  • (LogSearchRuleResourceCollection)

    operation results.



534
535
536
537
# File 'lib/2018-04-16/generated/azure_mgmt_monitor/scheduled_query_rules.rb', line 534

def list_by_resource_group(resource_group_name, filter:nil, custom_headers:nil)
  response = list_by_resource_group_async(resource_group_name, filter:filter, custom_headers:custom_headers).value!
  response.body unless response.nil?
end

#list_by_resource_group_async(resource_group_name, filter: nil, custom_headers: nil) ⇒ Concurrent::Promise

List the Log Search rules within a resource group.

information please see msdn.microsoft.com/en-us/library/azure/dn931934.aspx to the HTTP request.

Parameters:

  • resource_group_name (String)

    The name of the resource group.

  • filter (String) (defaults to: nil)

    The filter to apply on the operation. For more

  • A (Hash{String => String})

    hash of custom headers that will be added

Returns:

  • (Concurrent::Promise)

    Promise object which holds the HTTP response.



567
568
569
570
571
572
573
574
575
576
577
578
579
580
581
582
583
584
585
586
587
588
589
590
591
592
593
594
595
596
597
598
599
600
601
602
603
604
605
606
607
608
609
610
611
612
613
614
615
616
617
618
619
# File 'lib/2018-04-16/generated/azure_mgmt_monitor/scheduled_query_rules.rb', line 567

def list_by_resource_group_async(resource_group_name, filter:nil, custom_headers:nil)
  fail ArgumentError, 'resource_group_name is nil' if resource_group_name.nil?
  fail ArgumentError, '@client.api_version is nil' if @client.api_version.nil?
  fail ArgumentError, '@client.subscription_id is nil' if @client.subscription_id.nil?


  request_headers = {}
  request_headers['Content-Type'] = 'application/json; charset=utf-8'

  # Set Headers
  request_headers['x-ms-client-request-id'] = SecureRandom.uuid
  request_headers['accept-language'] = @client.accept_language unless @client.accept_language.nil?
  path_template = 'subscriptions/{subscriptionId}/resourcegroups/{resourceGroupName}/providers/microsoft.insights/scheduledQueryRules'

  request_url = @base_url || @client.base_url

  options = {
      middlewares: [[MsRest::RetryPolicyMiddleware, times: 3, retry: 0.02], [:cookie_jar]],
      path_params: {'resourceGroupName' => resource_group_name,'subscriptionId' => @client.subscription_id},
      query_params: {'api-version' => @client.api_version,'$filter' => filter},
      headers: request_headers.merge(custom_headers || {}),
      base_url: request_url
  }
  promise = @client.make_request_async(:get, path_template, options)

  promise = promise.then do |result|
    http_response = result.response
    status_code = http_response.status
    response_content = http_response.body
    unless status_code == 200
      error_model = JSON.load(response_content)
      fail MsRest::HttpOperationError.new(result.request, http_response, error_model)
    end

    result.request_id = http_response['x-ms-request-id'] unless http_response['x-ms-request-id'].nil?
    result.correlation_request_id = http_response['x-ms-correlation-request-id'] unless http_response['x-ms-correlation-request-id'].nil?
    result.client_request_id = http_response['x-ms-client-request-id'] unless http_response['x-ms-client-request-id'].nil?
    # Deserialize Response
    if status_code == 200
      begin
        parsed_response = response_content.to_s.empty? ? nil : JSON.load(response_content)
        result_mapper = Azure::Monitor::Mgmt::V2018_04_16::Models::LogSearchRuleResourceCollection.mapper()
        result.body = @client.deserialize(result_mapper, parsed_response)
      rescue Exception => e
        fail MsRest::DeserializationError.new('Error occurred in deserializing the response', e.message, e.backtrace, result)
      end
    end

    result
  end

  promise.execute
end

#list_by_resource_group_with_http_info(resource_group_name, filter: nil, custom_headers: nil) ⇒ MsRestAzure::AzureOperationResponse

List the Log Search rules within a resource group.

information please see msdn.microsoft.com/en-us/library/azure/dn931934.aspx will be added to the HTTP request.

Parameters:

  • resource_group_name (String)

    The name of the resource group.

  • filter (String) (defaults to: nil)

    The filter to apply on the operation. For more

  • custom_headers (Hash{String => String}) (defaults to: nil)

    A hash of custom headers that

Returns:

  • (MsRestAzure::AzureOperationResponse)

    HTTP response information.



551
552
553
# File 'lib/2018-04-16/generated/azure_mgmt_monitor/scheduled_query_rules.rb', line 551

def list_by_resource_group_with_http_info(resource_group_name, filter:nil, custom_headers:nil)
  list_by_resource_group_async(resource_group_name, filter:filter, custom_headers:custom_headers).value!
end

#list_by_subscription(filter: nil, custom_headers: nil) ⇒ LogSearchRuleResourceCollection

List the Log Search rules within a subscription group.

information please see msdn.microsoft.com/en-us/library/azure/dn931934.aspx will be added to the HTTP request.

Parameters:

  • filter (String) (defaults to: nil)

    The filter to apply on the operation. For more

  • custom_headers (Hash{String => String}) (defaults to: nil)

    A hash of custom headers that

Returns:

  • (LogSearchRuleResourceCollection)

    operation results.



438
439
440
441
# File 'lib/2018-04-16/generated/azure_mgmt_monitor/scheduled_query_rules.rb', line 438

def list_by_subscription(filter:nil, custom_headers:nil)
  response = list_by_subscription_async(filter:filter, custom_headers:custom_headers).value!
  response.body unless response.nil?
end

#list_by_subscription_async(filter: nil, custom_headers: nil) ⇒ Concurrent::Promise

List the Log Search rules within a subscription group.

information please see msdn.microsoft.com/en-us/library/azure/dn931934.aspx to the HTTP request.

Parameters:

  • filter (String) (defaults to: nil)

    The filter to apply on the operation. For more

  • A (Hash{String => String})

    hash of custom headers that will be added

Returns:

  • (Concurrent::Promise)

    Promise object which holds the HTTP response.



469
470
471
472
473
474
475
476
477
478
479
480
481
482
483
484
485
486
487
488
489
490
491
492
493
494
495
496
497
498
499
500
501
502
503
504
505
506
507
508
509
510
511
512
513
514
515
516
517
518
519
520
# File 'lib/2018-04-16/generated/azure_mgmt_monitor/scheduled_query_rules.rb', line 469

def list_by_subscription_async(filter:nil, custom_headers:nil)
  fail ArgumentError, '@client.api_version is nil' if @client.api_version.nil?
  fail ArgumentError, '@client.subscription_id is nil' if @client.subscription_id.nil?


  request_headers = {}
  request_headers['Content-Type'] = 'application/json; charset=utf-8'

  # Set Headers
  request_headers['x-ms-client-request-id'] = SecureRandom.uuid
  request_headers['accept-language'] = @client.accept_language unless @client.accept_language.nil?
  path_template = 'subscriptions/{subscriptionId}/providers/microsoft.insights/scheduledQueryRules'

  request_url = @base_url || @client.base_url

  options = {
      middlewares: [[MsRest::RetryPolicyMiddleware, times: 3, retry: 0.02], [:cookie_jar]],
      path_params: {'subscriptionId' => @client.subscription_id},
      query_params: {'api-version' => @client.api_version,'$filter' => filter},
      headers: request_headers.merge(custom_headers || {}),
      base_url: request_url
  }
  promise = @client.make_request_async(:get, path_template, options)

  promise = promise.then do |result|
    http_response = result.response
    status_code = http_response.status
    response_content = http_response.body
    unless status_code == 200
      error_model = JSON.load(response_content)
      fail MsRest::HttpOperationError.new(result.request, http_response, error_model)
    end

    result.request_id = http_response['x-ms-request-id'] unless http_response['x-ms-request-id'].nil?
    result.correlation_request_id = http_response['x-ms-correlation-request-id'] unless http_response['x-ms-correlation-request-id'].nil?
    result.client_request_id = http_response['x-ms-client-request-id'] unless http_response['x-ms-client-request-id'].nil?
    # Deserialize Response
    if status_code == 200
      begin
        parsed_response = response_content.to_s.empty? ? nil : JSON.load(response_content)
        result_mapper = Azure::Monitor::Mgmt::V2018_04_16::Models::LogSearchRuleResourceCollection.mapper()
        result.body = @client.deserialize(result_mapper, parsed_response)
      rescue Exception => e
        fail MsRest::DeserializationError.new('Error occurred in deserializing the response', e.message, e.backtrace, result)
      end
    end

    result
  end

  promise.execute
end

#list_by_subscription_with_http_info(filter: nil, custom_headers: nil) ⇒ MsRestAzure::AzureOperationResponse

List the Log Search rules within a subscription group.

information please see msdn.microsoft.com/en-us/library/azure/dn931934.aspx will be added to the HTTP request.

Parameters:

  • filter (String) (defaults to: nil)

    The filter to apply on the operation. For more

  • custom_headers (Hash{String => String}) (defaults to: nil)

    A hash of custom headers that

Returns:

  • (MsRestAzure::AzureOperationResponse)

    HTTP response information.



454
455
456
# File 'lib/2018-04-16/generated/azure_mgmt_monitor/scheduled_query_rules.rb', line 454

def list_by_subscription_with_http_info(filter:nil, custom_headers:nil)
  list_by_subscription_async(filter:filter, custom_headers:custom_headers).value!
end

#update(resource_group_name, rule_name, parameters, custom_headers: nil) ⇒ LogSearchRuleResource

Update log search Rule.

update. will be added to the HTTP request.

Parameters:

  • resource_group_name (String)

    The name of the resource group.

  • rule_name (String)

    The name of the rule.

  • parameters (LogSearchRuleResourcePatch)

    The parameters of the rule to

  • custom_headers (Hash{String => String}) (defaults to: nil)

    A hash of custom headers that

Returns:

  • (LogSearchRuleResource)

    operation results.



248
249
250
251
# File 'lib/2018-04-16/generated/azure_mgmt_monitor/scheduled_query_rules.rb', line 248

def update(resource_group_name, rule_name, parameters, custom_headers:nil)
  response = update_async(resource_group_name, rule_name, parameters, custom_headers:custom_headers).value!
  response.body unless response.nil?
end

#update_async(resource_group_name, rule_name, parameters, custom_headers: nil) ⇒ Concurrent::Promise

Update log search Rule.

update. to the HTTP request.

Parameters:

  • resource_group_name (String)

    The name of the resource group.

  • rule_name (String)

    The name of the rule.

  • parameters (LogSearchRuleResourcePatch)

    The parameters of the rule to

  • A (Hash{String => String})

    hash of custom headers that will be added

Returns:

  • (Concurrent::Promise)

    Promise object which holds the HTTP response.



281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
# File 'lib/2018-04-16/generated/azure_mgmt_monitor/scheduled_query_rules.rb', line 281

def update_async(resource_group_name, rule_name, parameters, custom_headers:nil)
  fail ArgumentError, '@client.subscription_id is nil' if @client.subscription_id.nil?
  fail ArgumentError, 'resource_group_name is nil' if resource_group_name.nil?
  fail ArgumentError, 'rule_name is nil' if rule_name.nil?
  fail ArgumentError, '@client.api_version is nil' if @client.api_version.nil?
  fail ArgumentError, 'parameters is nil' if parameters.nil?


  request_headers = {}
  request_headers['Content-Type'] = 'application/json; charset=utf-8'

  # Set Headers
  request_headers['x-ms-client-request-id'] = SecureRandom.uuid
  request_headers['accept-language'] = @client.accept_language unless @client.accept_language.nil?

  # Serialize Request
  request_mapper = Azure::Monitor::Mgmt::V2018_04_16::Models::LogSearchRuleResourcePatch.mapper()
  request_content = @client.serialize(request_mapper,  parameters)
  request_content = request_content != nil ? JSON.generate(request_content, quirks_mode: true) : nil

  path_template = 'subscriptions/{subscriptionId}/resourcegroups/{resourceGroupName}/providers/microsoft.insights/scheduledQueryRules/{ruleName}'

  request_url = @base_url || @client.base_url

  options = {
      middlewares: [[MsRest::RetryPolicyMiddleware, times: 3, retry: 0.02], [:cookie_jar]],
      path_params: {'subscriptionId' => @client.subscription_id,'resourceGroupName' => resource_group_name,'ruleName' => rule_name},
      query_params: {'api-version' => @client.api_version},
      body: request_content,
      headers: request_headers.merge(custom_headers || {}),
      base_url: request_url
  }
  promise = @client.make_request_async(:patch, path_template, options)

  promise = promise.then do |result|
    http_response = result.response
    status_code = http_response.status
    response_content = http_response.body
    unless status_code == 200
      error_model = JSON.load(response_content)
      fail MsRest::HttpOperationError.new(result.request, http_response, error_model)
    end

    result.request_id = http_response['x-ms-request-id'] unless http_response['x-ms-request-id'].nil?
    result.correlation_request_id = http_response['x-ms-correlation-request-id'] unless http_response['x-ms-correlation-request-id'].nil?
    result.client_request_id = http_response['x-ms-client-request-id'] unless http_response['x-ms-client-request-id'].nil?
    # Deserialize Response
    if status_code == 200
      begin
        parsed_response = response_content.to_s.empty? ? nil : JSON.load(response_content)
        result_mapper = Azure::Monitor::Mgmt::V2018_04_16::Models::LogSearchRuleResource.mapper()
        result.body = @client.deserialize(result_mapper, parsed_response)
      rescue Exception => e
        fail MsRest::DeserializationError.new('Error occurred in deserializing the response', e.message, e.backtrace, result)
      end
    end

    result
  end

  promise.execute
end

#update_with_http_info(resource_group_name, rule_name, parameters, custom_headers: nil) ⇒ MsRestAzure::AzureOperationResponse

Update log search Rule.

update. will be added to the HTTP request.

Parameters:

  • resource_group_name (String)

    The name of the resource group.

  • rule_name (String)

    The name of the rule.

  • parameters (LogSearchRuleResourcePatch)

    The parameters of the rule to

  • custom_headers (Hash{String => String}) (defaults to: nil)

    A hash of custom headers that

Returns:

  • (MsRestAzure::AzureOperationResponse)

    HTTP response information.



265
266
267
# File 'lib/2018-04-16/generated/azure_mgmt_monitor/scheduled_query_rules.rb', line 265

def update_with_http_info(resource_group_name, rule_name, parameters, custom_headers:nil)
  update_async(resource_group_name, rule_name, parameters, custom_headers:custom_headers).value!
end