Class: Azure::Monitor::Mgmt::V2015_05_01::ApplicationInsightsManagementClient
- Inherits:
-
MsRestAzure::AzureServiceClient
- Object
- MsRestAzure::AzureServiceClient
- Azure::Monitor::Mgmt::V2015_05_01::ApplicationInsightsManagementClient
- Includes:
- MsRestAzure, MsRestAzure::Serialization
- Defined in:
- lib/2015-05-01/generated/azure_mgmt_monitor/application_insights_management_client.rb
Overview
A service client - single point of access to the REST API.
Instance Attribute Summary collapse
-
#accept_language ⇒ String
The preferred language for the response.
-
#analytics_items ⇒ AnalyticsItems
readonly
Analytics_items.
-
#annotations ⇒ Annotations
readonly
Annotations.
-
#api_version ⇒ String
readonly
The API version to use for this operation.
-
#apikeys ⇒ APIKeys
readonly
Apikeys.
-
#base_url ⇒ String
The base URI of the service.
-
#component_available_features ⇒ ComponentAvailableFeatures
readonly
Component_available_features.
-
#component_current_billing_features ⇒ ComponentCurrentBillingFeatures
readonly
component_current_billing_features.
-
#component_feature_capabilities ⇒ ComponentFeatureCapabilities
readonly
Component_feature_capabilities.
-
#component_quota_status ⇒ ComponentQuotaStatus
readonly
Component_quota_status.
-
#components ⇒ Components
readonly
Components.
-
#credentials ⇒ Object
readonly
Credentials needed for the client to connect to Azure.
-
#export_configurations ⇒ ExportConfigurations
readonly
Export_configurations.
-
#favorites ⇒ Favorites
readonly
Favorites.
-
#generate_client_request_id ⇒ Boolean
generated.
-
#long_running_operation_retry_timeout ⇒ Integer
Operations.
-
#operations ⇒ Operations
readonly
Operations.
-
#proactive_detection_configurations ⇒ ProactiveDetectionConfigurations
readonly
proactive_detection_configurations.
-
#subscription_id ⇒ String
The ID of the target subscription.
-
#web_test_locations ⇒ WebTestLocations
readonly
Web_test_locations.
-
#web_tests ⇒ WebTests
readonly
Web_tests.
-
#work_item_configurations ⇒ WorkItemConfigurations
readonly
Work_item_configurations.
-
#workbooks ⇒ Workbooks
readonly
Workbooks.
Instance Method Summary collapse
-
#initialize(credentials = nil, base_url = nil, options = nil) ⇒ ApplicationInsightsManagementClient
constructor
Creates initializes a new instance of the ApplicationInsightsManagementClient class.
-
#make_request(method, path, options = {}) ⇒ Hash{String=>String}
Makes a request and returns the body of the response.
-
#make_request_async(method, path, options = {}) ⇒ Concurrent::Promise
Makes a request asynchronously.
-
#make_request_with_http_info(method, path, options = {}) ⇒ MsRestAzure::AzureOperationResponse
Makes a request and returns the operation response.
Constructor Details
#initialize(credentials = nil, base_url = nil, options = nil) ⇒ ApplicationInsightsManagementClient
Creates initializes a new instance of the ApplicationInsightsManagementClient class.
94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 |
# File 'lib/2015-05-01/generated/azure_mgmt_monitor/application_insights_management_client.rb', line 94 def initialize(credentials = nil, base_url = nil, = nil) super(credentials, ) @base_url = base_url || 'https://management.azure.com' fail ArgumentError, 'invalid type of credentials input parameter' unless credentials.is_a?(MsRest::ServiceClientCredentials) unless credentials.nil? @credentials = credentials @operations = Operations.new(self) @annotations = Annotations.new(self) @apikeys = APIKeys.new(self) @export_configurations = ExportConfigurations.new(self) @component_current_billing_features = ComponentCurrentBillingFeatures.new(self) @component_quota_status = ComponentQuotaStatus.new(self) @component_feature_capabilities = ComponentFeatureCapabilities.new(self) @component_available_features = ComponentAvailableFeatures.new(self) @proactive_detection_configurations = ProactiveDetectionConfigurations.new(self) @components = Components.new(self) @work_item_configurations = WorkItemConfigurations.new(self) @favorites = Favorites.new(self) @web_test_locations = WebTestLocations.new(self) @web_tests = WebTests.new(self) @analytics_items = AnalyticsItems.new(self) @workbooks = Workbooks.new(self) @api_version = '2015-05-01' @accept_language = 'en-US' @long_running_operation_retry_timeout = 30 @generate_client_request_id = true add_telemetry end |
Instance Attribute Details
#accept_language ⇒ String
Returns The preferred language for the response.
27 28 29 |
# File 'lib/2015-05-01/generated/azure_mgmt_monitor/application_insights_management_client.rb', line 27 def accept_language @accept_language end |
#analytics_items ⇒ AnalyticsItems (readonly)
Returns analytics_items.
83 84 85 |
# File 'lib/2015-05-01/generated/azure_mgmt_monitor/application_insights_management_client.rb', line 83 def analytics_items @analytics_items end |
#annotations ⇒ Annotations (readonly)
Returns annotations.
42 43 44 |
# File 'lib/2015-05-01/generated/azure_mgmt_monitor/application_insights_management_client.rb', line 42 def annotations @annotations end |
#api_version ⇒ String (readonly)
Returns The API version to use for this operation.
21 22 23 |
# File 'lib/2015-05-01/generated/azure_mgmt_monitor/application_insights_management_client.rb', line 21 def api_version @api_version end |
#apikeys ⇒ APIKeys (readonly)
Returns apikeys.
45 46 47 |
# File 'lib/2015-05-01/generated/azure_mgmt_monitor/application_insights_management_client.rb', line 45 def apikeys @apikeys end |
#base_url ⇒ String
Returns the base URI of the service.
15 16 17 |
# File 'lib/2015-05-01/generated/azure_mgmt_monitor/application_insights_management_client.rb', line 15 def base_url @base_url end |
#component_available_features ⇒ ComponentAvailableFeatures (readonly)
Returns component_available_features.
61 62 63 |
# File 'lib/2015-05-01/generated/azure_mgmt_monitor/application_insights_management_client.rb', line 61 def component_available_features @component_available_features end |
#component_current_billing_features ⇒ ComponentCurrentBillingFeatures (readonly)
component_current_billing_features
52 53 54 |
# File 'lib/2015-05-01/generated/azure_mgmt_monitor/application_insights_management_client.rb', line 52 def component_current_billing_features @component_current_billing_features end |
#component_feature_capabilities ⇒ ComponentFeatureCapabilities (readonly)
Returns component_feature_capabilities.
58 59 60 |
# File 'lib/2015-05-01/generated/azure_mgmt_monitor/application_insights_management_client.rb', line 58 def component_feature_capabilities @component_feature_capabilities end |
#component_quota_status ⇒ ComponentQuotaStatus (readonly)
Returns component_quota_status.
55 56 57 |
# File 'lib/2015-05-01/generated/azure_mgmt_monitor/application_insights_management_client.rb', line 55 def component_quota_status @component_quota_status end |
#components ⇒ Components (readonly)
Returns components.
68 69 70 |
# File 'lib/2015-05-01/generated/azure_mgmt_monitor/application_insights_management_client.rb', line 68 def components @components end |
#credentials ⇒ Object (readonly)
Returns Credentials needed for the client to connect to Azure.
18 19 20 |
# File 'lib/2015-05-01/generated/azure_mgmt_monitor/application_insights_management_client.rb', line 18 def credentials @credentials end |
#export_configurations ⇒ ExportConfigurations (readonly)
Returns export_configurations.
48 49 50 |
# File 'lib/2015-05-01/generated/azure_mgmt_monitor/application_insights_management_client.rb', line 48 def export_configurations @export_configurations end |
#favorites ⇒ Favorites (readonly)
Returns favorites.
74 75 76 |
# File 'lib/2015-05-01/generated/azure_mgmt_monitor/application_insights_management_client.rb', line 74 def favorites @favorites end |
#generate_client_request_id ⇒ Boolean
generated. When set to true a unique x-ms-client-request-id value is generated and included in each request. Default is true.
36 37 38 |
# File 'lib/2015-05-01/generated/azure_mgmt_monitor/application_insights_management_client.rb', line 36 def generate_client_request_id @generate_client_request_id end |
#long_running_operation_retry_timeout ⇒ Integer
Operations. Default value is 30.
31 32 33 |
# File 'lib/2015-05-01/generated/azure_mgmt_monitor/application_insights_management_client.rb', line 31 def long_running_operation_retry_timeout @long_running_operation_retry_timeout end |
#operations ⇒ Operations (readonly)
Returns operations.
39 40 41 |
# File 'lib/2015-05-01/generated/azure_mgmt_monitor/application_insights_management_client.rb', line 39 def operations @operations end |
#proactive_detection_configurations ⇒ ProactiveDetectionConfigurations (readonly)
proactive_detection_configurations
65 66 67 |
# File 'lib/2015-05-01/generated/azure_mgmt_monitor/application_insights_management_client.rb', line 65 def proactive_detection_configurations @proactive_detection_configurations end |
#subscription_id ⇒ String
Returns The ID of the target subscription.
24 25 26 |
# File 'lib/2015-05-01/generated/azure_mgmt_monitor/application_insights_management_client.rb', line 24 def subscription_id @subscription_id end |
#web_test_locations ⇒ WebTestLocations (readonly)
Returns web_test_locations.
77 78 79 |
# File 'lib/2015-05-01/generated/azure_mgmt_monitor/application_insights_management_client.rb', line 77 def web_test_locations @web_test_locations end |
#web_tests ⇒ WebTests (readonly)
Returns web_tests.
80 81 82 |
# File 'lib/2015-05-01/generated/azure_mgmt_monitor/application_insights_management_client.rb', line 80 def web_tests @web_tests end |
#work_item_configurations ⇒ WorkItemConfigurations (readonly)
Returns work_item_configurations.
71 72 73 |
# File 'lib/2015-05-01/generated/azure_mgmt_monitor/application_insights_management_client.rb', line 71 def work_item_configurations @work_item_configurations end |
#workbooks ⇒ Workbooks (readonly)
Returns workbooks.
86 87 88 |
# File 'lib/2015-05-01/generated/azure_mgmt_monitor/application_insights_management_client.rb', line 86 def workbooks @workbooks end |
Instance Method Details
#make_request(method, path, options = {}) ⇒ Hash{String=>String}
Makes a request and returns the body of the response. Example:
request_content = "{'location':'westus','tags':{'tag1':'val1','tag2':'val2'}}"
path = "/path"
= {
body: request_content,
query_params: {'api-version' => '2016-02-01'}
}
result = @client.make_request(:put, path, )
140 141 142 143 |
# File 'lib/2015-05-01/generated/azure_mgmt_monitor/application_insights_management_client.rb', line 140 def make_request(method, path, = {}) result = make_request_with_http_info(method, path, ) result.body unless result.nil? end |
#make_request_async(method, path, options = {}) ⇒ Concurrent::Promise
Makes a request asynchronously.
165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 |
# File 'lib/2015-05-01/generated/azure_mgmt_monitor/application_insights_management_client.rb', line 165 def make_request_async(method, path, = {}) fail ArgumentError, 'method is nil' if method.nil? fail ArgumentError, 'path is nil' if path.nil? request_url = [:base_url] || @base_url if(![:headers].nil? && ![:headers]['Content-Type'].nil?) @request_headers['Content-Type'] = [:headers]['Content-Type'] end request_headers = @request_headers request_headers.merge!({'accept-language' => @accept_language}) unless @accept_language.nil? .merge!({headers: request_headers.merge([:headers] || {})}) .merge!({credentials: @credentials}) unless @credentials.nil? super(request_url, method, path, ) end |
#make_request_with_http_info(method, path, options = {}) ⇒ MsRestAzure::AzureOperationResponse
Makes a request and returns the operation response.
152 153 154 155 156 |
# File 'lib/2015-05-01/generated/azure_mgmt_monitor/application_insights_management_client.rb', line 152 def make_request_with_http_info(method, path, = {}) result = make_request_async(method, path, ).value! result.body = result.response.body.to_s.empty? ? nil : JSON.load(result.response.body) result end |