Class: Azure::Monitor::Mgmt::V2015_05_01::ComponentCurrentBillingFeatures
- Inherits:
-
Object
- Object
- Azure::Monitor::Mgmt::V2015_05_01::ComponentCurrentBillingFeatures
- Includes:
- MsRestAzure
- Defined in:
- lib/2015-05-01/generated/azure_mgmt_monitor/component_current_billing_features.rb
Overview
Composite Swagger for Application Insights Management Client
Instance Attribute Summary collapse
-
#client ⇒ ApplicationInsightsManagementClient
readonly
Reference to the ApplicationInsightsManagementClient.
Instance Method Summary collapse
-
#get(resource_group_name, resource_name, custom_headers: nil) ⇒ ApplicationInsightsComponentBillingFeatures
Returns current billing features for an Application Insights component.
-
#get_async(resource_group_name, resource_name, custom_headers: nil) ⇒ Concurrent::Promise
Returns current billing features for an Application Insights component.
-
#get_with_http_info(resource_group_name, resource_name, custom_headers: nil) ⇒ MsRestAzure::AzureOperationResponse
Returns current billing features for an Application Insights component.
-
#initialize(client) ⇒ ComponentCurrentBillingFeatures
constructor
Creates and initializes a new instance of the ComponentCurrentBillingFeatures class.
-
#update(resource_group_name, resource_name, billing_features_properties, custom_headers: nil) ⇒ ApplicationInsightsComponentBillingFeatures
Update current billing features for an Application Insights component.
-
#update_async(resource_group_name, resource_name, billing_features_properties, custom_headers: nil) ⇒ Concurrent::Promise
Update current billing features for an Application Insights component.
-
#update_with_http_info(resource_group_name, resource_name, billing_features_properties, custom_headers: nil) ⇒ MsRestAzure::AzureOperationResponse
Update current billing features for an Application Insights component.
Constructor Details
#initialize(client) ⇒ ComponentCurrentBillingFeatures
Creates and initializes a new instance of the ComponentCurrentBillingFeatures class.
17 18 19 |
# File 'lib/2015-05-01/generated/azure_mgmt_monitor/component_current_billing_features.rb', line 17 def initialize(client) @client = client end |
Instance Attribute Details
#client ⇒ ApplicationInsightsManagementClient (readonly)
Returns reference to the ApplicationInsightsManagementClient.
22 23 24 |
# File 'lib/2015-05-01/generated/azure_mgmt_monitor/component_current_billing_features.rb', line 22 def client @client end |
Instance Method Details
#get(resource_group_name, resource_name, custom_headers: nil) ⇒ ApplicationInsightsComponentBillingFeatures
Returns current billing features for an Application Insights component.
is case insensitive. resource. will be added to the HTTP request.
36 37 38 39 |
# File 'lib/2015-05-01/generated/azure_mgmt_monitor/component_current_billing_features.rb', line 36 def get(resource_group_name, resource_name, custom_headers:nil) response = get_async(resource_group_name, resource_name, custom_headers:custom_headers).value! response.body unless response.nil? end |
#get_async(resource_group_name, resource_name, custom_headers: nil) ⇒ Concurrent::Promise
Returns current billing features for an Application Insights component.
is case insensitive. resource. to the HTTP request.
69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 |
# File 'lib/2015-05-01/generated/azure_mgmt_monitor/component_current_billing_features.rb', line 69 def get_async(resource_group_name, resource_name, custom_headers:nil) fail ArgumentError, 'resource_group_name is nil' if resource_group_name.nil? fail ArgumentError, "'resource_group_name' should satisfy the constraint - 'MaxLength': '90'" if !resource_group_name.nil? && resource_group_name.length > 90 fail ArgumentError, "'resource_group_name' should satisfy the constraint - 'MinLength': '1'" if !resource_group_name.nil? && resource_group_name.length < 1 fail ArgumentError, "'resource_group_name' should satisfy the constraint - 'Pattern': '^[-\w\._\(\)]+$'" if !resource_group_name.nil? && resource_group_name.match(Regexp.new('^^[-\w\._\(\)]+$$')).nil? fail ArgumentError, '@client.api_version is nil' if @client.api_version.nil? fail ArgumentError, "'@client.api_version' should satisfy the constraint - 'MinLength': '1'" if !@client.api_version.nil? && @client.api_version.length < 1 fail ArgumentError, '@client.subscription_id is nil' if @client.subscription_id.nil? fail ArgumentError, "'@client.subscription_id' should satisfy the constraint - 'MinLength': '1'" if !@client.subscription_id.nil? && @client.subscription_id.length < 1 fail ArgumentError, 'resource_name is nil' if resource_name.nil? request_headers = {} request_headers['Content-Type'] = 'application/json; charset=utf-8' # Set Headers request_headers['x-ms-client-request-id'] = SecureRandom.uuid request_headers['accept-language'] = @client.accept_language unless @client.accept_language.nil? path_template = 'subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.Insights/components/{resourceName}/currentbillingfeatures' request_url = @base_url || @client.base_url = { middlewares: [[MsRest::RetryPolicyMiddleware, times: 3, retry: 0.02], [:cookie_jar]], path_params: {'resourceGroupName' => resource_group_name,'subscriptionId' => @client.subscription_id,'resourceName' => resource_name}, query_params: {'api-version' => @client.api_version}, headers: request_headers.merge(custom_headers || {}), base_url: request_url } promise = @client.make_request_async(:get, path_template, ) promise = promise.then do |result| http_response = result.response status_code = http_response.status response_content = http_response.body unless status_code == 200 error_model = JSON.load(response_content) fail MsRestAzure::AzureOperationError.new(result.request, http_response, error_model) end result.request_id = http_response['x-ms-request-id'] unless http_response['x-ms-request-id'].nil? result.correlation_request_id = http_response['x-ms-correlation-request-id'] unless http_response['x-ms-correlation-request-id'].nil? result.client_request_id = http_response['x-ms-client-request-id'] unless http_response['x-ms-client-request-id'].nil? # Deserialize Response if status_code == 200 begin parsed_response = response_content.to_s.empty? ? nil : JSON.load(response_content) result_mapper = Azure::Monitor::Mgmt::V2015_05_01::Models::ApplicationInsightsComponentBillingFeatures.mapper() result.body = @client.deserialize(result_mapper, parsed_response) rescue Exception => e fail MsRest::DeserializationError.new('Error occurred in deserializing the response', e., e.backtrace, result) end end result end promise.execute end |
#get_with_http_info(resource_group_name, resource_name, custom_headers: nil) ⇒ MsRestAzure::AzureOperationResponse
Returns current billing features for an Application Insights component.
is case insensitive. resource. will be added to the HTTP request.
53 54 55 |
# File 'lib/2015-05-01/generated/azure_mgmt_monitor/component_current_billing_features.rb', line 53 def get_with_http_info(resource_group_name, resource_name, custom_headers:nil) get_async(resource_group_name, resource_name, custom_headers:custom_headers).value! end |
#update(resource_group_name, resource_name, billing_features_properties, custom_headers: nil) ⇒ ApplicationInsightsComponentBillingFeatures
Update current billing features for an Application Insights component.
is case insensitive. resource.
- ApplicationInsightsComponentBillingFeatures
-
Properties that need to be
specified to update billing features for an Application Insights component. will be added to the HTTP request.
144 145 146 147 |
# File 'lib/2015-05-01/generated/azure_mgmt_monitor/component_current_billing_features.rb', line 144 def update(resource_group_name, resource_name, billing_features_properties, custom_headers:nil) response = update_async(resource_group_name, resource_name, billing_features_properties, custom_headers:custom_headers).value! response.body unless response.nil? end |
#update_async(resource_group_name, resource_name, billing_features_properties, custom_headers: nil) ⇒ Concurrent::Promise
Update current billing features for an Application Insights component.
is case insensitive. resource.
- ApplicationInsightsComponentBillingFeatures
-
Properties that need to be
specified to update billing features for an Application Insights component. to the HTTP request.
183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 |
# File 'lib/2015-05-01/generated/azure_mgmt_monitor/component_current_billing_features.rb', line 183 def update_async(resource_group_name, resource_name, billing_features_properties, custom_headers:nil) fail ArgumentError, 'resource_group_name is nil' if resource_group_name.nil? fail ArgumentError, "'resource_group_name' should satisfy the constraint - 'MaxLength': '90'" if !resource_group_name.nil? && resource_group_name.length > 90 fail ArgumentError, "'resource_group_name' should satisfy the constraint - 'MinLength': '1'" if !resource_group_name.nil? && resource_group_name.length < 1 fail ArgumentError, "'resource_group_name' should satisfy the constraint - 'Pattern': '^[-\w\._\(\)]+$'" if !resource_group_name.nil? && resource_group_name.match(Regexp.new('^^[-\w\._\(\)]+$$')).nil? fail ArgumentError, '@client.api_version is nil' if @client.api_version.nil? fail ArgumentError, "'@client.api_version' should satisfy the constraint - 'MinLength': '1'" if !@client.api_version.nil? && @client.api_version.length < 1 fail ArgumentError, '@client.subscription_id is nil' if @client.subscription_id.nil? fail ArgumentError, "'@client.subscription_id' should satisfy the constraint - 'MinLength': '1'" if !@client.subscription_id.nil? && @client.subscription_id.length < 1 fail ArgumentError, 'resource_name is nil' if resource_name.nil? fail ArgumentError, 'billing_features_properties is nil' if billing_features_properties.nil? request_headers = {} request_headers['Content-Type'] = 'application/json; charset=utf-8' # Set Headers request_headers['x-ms-client-request-id'] = SecureRandom.uuid request_headers['accept-language'] = @client.accept_language unless @client.accept_language.nil? # Serialize Request request_mapper = Azure::Monitor::Mgmt::V2015_05_01::Models::ApplicationInsightsComponentBillingFeatures.mapper() request_content = @client.serialize(request_mapper, billing_features_properties) request_content = request_content != nil ? JSON.generate(request_content, quirks_mode: true) : nil path_template = 'subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.Insights/components/{resourceName}/currentbillingfeatures' request_url = @base_url || @client.base_url = { middlewares: [[MsRest::RetryPolicyMiddleware, times: 3, retry: 0.02], [:cookie_jar]], path_params: {'resourceGroupName' => resource_group_name,'subscriptionId' => @client.subscription_id,'resourceName' => resource_name}, query_params: {'api-version' => @client.api_version}, body: request_content, headers: request_headers.merge(custom_headers || {}), base_url: request_url } promise = @client.make_request_async(:put, path_template, ) promise = promise.then do |result| http_response = result.response status_code = http_response.status response_content = http_response.body unless status_code == 200 error_model = JSON.load(response_content) fail MsRestAzure::AzureOperationError.new(result.request, http_response, error_model) end result.request_id = http_response['x-ms-request-id'] unless http_response['x-ms-request-id'].nil? result.correlation_request_id = http_response['x-ms-correlation-request-id'] unless http_response['x-ms-correlation-request-id'].nil? result.client_request_id = http_response['x-ms-client-request-id'] unless http_response['x-ms-client-request-id'].nil? # Deserialize Response if status_code == 200 begin parsed_response = response_content.to_s.empty? ? nil : JSON.load(response_content) result_mapper = Azure::Monitor::Mgmt::V2015_05_01::Models::ApplicationInsightsComponentBillingFeatures.mapper() result.body = @client.deserialize(result_mapper, parsed_response) rescue Exception => e fail MsRest::DeserializationError.new('Error occurred in deserializing the response', e., e.backtrace, result) end end result end promise.execute end |
#update_with_http_info(resource_group_name, resource_name, billing_features_properties, custom_headers: nil) ⇒ MsRestAzure::AzureOperationResponse
Update current billing features for an Application Insights component.
is case insensitive. resource.
- ApplicationInsightsComponentBillingFeatures
-
Properties that need to be
specified to update billing features for an Application Insights component. will be added to the HTTP request.
164 165 166 |
# File 'lib/2015-05-01/generated/azure_mgmt_monitor/component_current_billing_features.rb', line 164 def update_with_http_info(resource_group_name, resource_name, billing_features_properties, custom_headers:nil) update_async(resource_group_name, resource_name, billing_features_properties, custom_headers:custom_headers).value! end |