Class: Azure::Monitor::Mgmt::V2015_05_01::WebTests
- Inherits:
-
Object
- Object
- Azure::Monitor::Mgmt::V2015_05_01::WebTests
- Includes:
- MsRestAzure
- Defined in:
- lib/2015-05-01/generated/azure_mgmt_monitor/web_tests.rb
Overview
Composite Swagger for Application Insights Management Client
Instance Attribute Summary collapse
-
#client ⇒ ApplicationInsightsManagementClient
readonly
Reference to the ApplicationInsightsManagementClient.
Instance Method Summary collapse
-
#create_or_update(resource_group_name, web_test_name, web_test_definition, custom_headers: nil) ⇒ WebTest
Creates or updates an Application Insights web test definition.
-
#create_or_update_async(resource_group_name, web_test_name, web_test_definition, custom_headers: nil) ⇒ Concurrent::Promise
Creates or updates an Application Insights web test definition.
-
#create_or_update_with_http_info(resource_group_name, web_test_name, web_test_definition, custom_headers: nil) ⇒ MsRestAzure::AzureOperationResponse
Creates or updates an Application Insights web test definition.
-
#delete(resource_group_name, web_test_name, custom_headers: nil) ⇒ Object
Deletes an Application Insights web test.
-
#delete_async(resource_group_name, web_test_name, custom_headers: nil) ⇒ Concurrent::Promise
Deletes an Application Insights web test.
-
#delete_with_http_info(resource_group_name, web_test_name, custom_headers: nil) ⇒ MsRestAzure::AzureOperationResponse
Deletes an Application Insights web test.
-
#get(resource_group_name, web_test_name, custom_headers: nil) ⇒ WebTest
Get a specific Application Insights web test definition.
-
#get_async(resource_group_name, web_test_name, custom_headers: nil) ⇒ Concurrent::Promise
Get a specific Application Insights web test definition.
-
#get_with_http_info(resource_group_name, web_test_name, custom_headers: nil) ⇒ MsRestAzure::AzureOperationResponse
Get a specific Application Insights web test definition.
-
#initialize(client) ⇒ WebTests
constructor
Creates and initializes a new instance of the WebTests class.
-
#list(custom_headers: nil) ⇒ Array<WebTest>
Get all Application Insights web test alerts definitions within a subscription.
-
#list_as_lazy(custom_headers: nil) ⇒ WebTestListResult
Get all Application Insights web test alerts definitions within a subscription.
-
#list_async(custom_headers: nil) ⇒ Concurrent::Promise
Get all Application Insights web test alerts definitions within a subscription.
-
#list_by_component(component_name, resource_group_name, custom_headers: nil) ⇒ Array<WebTest>
Get all Application Insights web tests defined for the specified component.
-
#list_by_component_as_lazy(component_name, resource_group_name, custom_headers: nil) ⇒ WebTestListResult
Get all Application Insights web tests defined for the specified component.
-
#list_by_component_async(component_name, resource_group_name, custom_headers: nil) ⇒ Concurrent::Promise
Get all Application Insights web tests defined for the specified component.
-
#list_by_component_next(next_page_link, custom_headers: nil) ⇒ WebTestListResult
Get all Application Insights web tests defined for the specified component.
-
#list_by_component_next_async(next_page_link, custom_headers: nil) ⇒ Concurrent::Promise
Get all Application Insights web tests defined for the specified component.
-
#list_by_component_next_with_http_info(next_page_link, custom_headers: nil) ⇒ MsRestAzure::AzureOperationResponse
Get all Application Insights web tests defined for the specified component.
-
#list_by_component_with_http_info(component_name, resource_group_name, custom_headers: nil) ⇒ MsRestAzure::AzureOperationResponse
Get all Application Insights web tests defined for the specified component.
-
#list_by_resource_group(resource_group_name, custom_headers: nil) ⇒ Array<WebTest>
Get all Application Insights web tests defined within a specified resource group.
-
#list_by_resource_group_as_lazy(resource_group_name, custom_headers: nil) ⇒ WebTestListResult
Get all Application Insights web tests defined within a specified resource group.
-
#list_by_resource_group_async(resource_group_name, custom_headers: nil) ⇒ Concurrent::Promise
Get all Application Insights web tests defined within a specified resource group.
-
#list_by_resource_group_next(next_page_link, custom_headers: nil) ⇒ WebTestListResult
Get all Application Insights web tests defined within a specified resource group.
-
#list_by_resource_group_next_async(next_page_link, custom_headers: nil) ⇒ Concurrent::Promise
Get all Application Insights web tests defined within a specified resource group.
-
#list_by_resource_group_next_with_http_info(next_page_link, custom_headers: nil) ⇒ MsRestAzure::AzureOperationResponse
Get all Application Insights web tests defined within a specified resource group.
-
#list_by_resource_group_with_http_info(resource_group_name, custom_headers: nil) ⇒ MsRestAzure::AzureOperationResponse
Get all Application Insights web tests defined within a specified resource group.
-
#list_next(next_page_link, custom_headers: nil) ⇒ WebTestListResult
Get all Application Insights web test alerts definitions within a subscription.
-
#list_next_async(next_page_link, custom_headers: nil) ⇒ Concurrent::Promise
Get all Application Insights web test alerts definitions within a subscription.
-
#list_next_with_http_info(next_page_link, custom_headers: nil) ⇒ MsRestAzure::AzureOperationResponse
Get all Application Insights web test alerts definitions within a subscription.
-
#list_with_http_info(custom_headers: nil) ⇒ MsRestAzure::AzureOperationResponse
Get all Application Insights web test alerts definitions within a subscription.
-
#update_tags(resource_group_name, web_test_name, web_test_tags, custom_headers: nil) ⇒ WebTest
Creates or updates an Application Insights web test definition.
-
#update_tags_async(resource_group_name, web_test_name, web_test_tags, custom_headers: nil) ⇒ Concurrent::Promise
Creates or updates an Application Insights web test definition.
-
#update_tags_with_http_info(resource_group_name, web_test_name, web_test_tags, custom_headers: nil) ⇒ MsRestAzure::AzureOperationResponse
Creates or updates an Application Insights web test definition.
Constructor Details
#initialize(client) ⇒ WebTests
Creates and initializes a new instance of the WebTests class.
17 18 19 |
# File 'lib/2015-05-01/generated/azure_mgmt_monitor/web_tests.rb', line 17 def initialize(client) @client = client end |
Instance Attribute Details
#client ⇒ ApplicationInsightsManagementClient (readonly)
Returns reference to the ApplicationInsightsManagementClient.
22 23 24 |
# File 'lib/2015-05-01/generated/azure_mgmt_monitor/web_tests.rb', line 22 def client @client end |
Instance Method Details
#create_or_update(resource_group_name, web_test_name, web_test_definition, custom_headers: nil) ⇒ WebTest
Creates or updates an Application Insights web test definition.
is case insensitive. resource. create or update an Application Insights web test definition. will be added to the HTTP request.
244 245 246 247 |
# File 'lib/2015-05-01/generated/azure_mgmt_monitor/web_tests.rb', line 244 def create_or_update(resource_group_name, web_test_name, web_test_definition, custom_headers:nil) response = create_or_update_async(resource_group_name, web_test_name, web_test_definition, custom_headers:custom_headers).value! response.body unless response.nil? end |
#create_or_update_async(resource_group_name, web_test_name, web_test_definition, custom_headers: nil) ⇒ Concurrent::Promise
Creates or updates an Application Insights web test definition.
is case insensitive. resource. create or update an Application Insights web test definition. to the HTTP request.
281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 |
# File 'lib/2015-05-01/generated/azure_mgmt_monitor/web_tests.rb', line 281 def create_or_update_async(resource_group_name, web_test_name, web_test_definition, custom_headers:nil) fail ArgumentError, 'resource_group_name is nil' if resource_group_name.nil? fail ArgumentError, "'resource_group_name' should satisfy the constraint - 'MaxLength': '90'" if !resource_group_name.nil? && resource_group_name.length > 90 fail ArgumentError, "'resource_group_name' should satisfy the constraint - 'MinLength': '1'" if !resource_group_name.nil? && resource_group_name.length < 1 fail ArgumentError, "'resource_group_name' should satisfy the constraint - 'Pattern': '^[-\w\._\(\)]+$'" if !resource_group_name.nil? && resource_group_name.match(Regexp.new('^^[-\w\._\(\)]+$$')).nil? fail ArgumentError, '@client.api_version is nil' if @client.api_version.nil? fail ArgumentError, "'@client.api_version' should satisfy the constraint - 'MinLength': '1'" if !@client.api_version.nil? && @client.api_version.length < 1 fail ArgumentError, '@client.subscription_id is nil' if @client.subscription_id.nil? fail ArgumentError, "'@client.subscription_id' should satisfy the constraint - 'MinLength': '1'" if !@client.subscription_id.nil? && @client.subscription_id.length < 1 fail ArgumentError, 'web_test_name is nil' if web_test_name.nil? fail ArgumentError, 'web_test_definition is nil' if web_test_definition.nil? request_headers = {} request_headers['Content-Type'] = 'application/json; charset=utf-8' # Set Headers request_headers['x-ms-client-request-id'] = SecureRandom.uuid request_headers['accept-language'] = @client.accept_language unless @client.accept_language.nil? # Serialize Request request_mapper = Azure::Monitor::Mgmt::V2015_05_01::Models::WebTest.mapper() request_content = @client.serialize(request_mapper, web_test_definition) request_content = request_content != nil ? JSON.generate(request_content, quirks_mode: true) : nil path_template = 'subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.Insights/webtests/{webTestName}' request_url = @base_url || @client.base_url = { middlewares: [[MsRest::RetryPolicyMiddleware, times: 3, retry: 0.02], [:cookie_jar]], path_params: {'resourceGroupName' => resource_group_name,'subscriptionId' => @client.subscription_id,'webTestName' => web_test_name}, query_params: {'api-version' => @client.api_version}, body: request_content, headers: request_headers.merge(custom_headers || {}), base_url: request_url } promise = @client.make_request_async(:put, path_template, ) promise = promise.then do |result| http_response = result.response status_code = http_response.status response_content = http_response.body unless status_code == 200 error_model = JSON.load(response_content) fail MsRestAzure::AzureOperationError.new(result.request, http_response, error_model) end result.request_id = http_response['x-ms-request-id'] unless http_response['x-ms-request-id'].nil? result.correlation_request_id = http_response['x-ms-correlation-request-id'] unless http_response['x-ms-correlation-request-id'].nil? result.client_request_id = http_response['x-ms-client-request-id'] unless http_response['x-ms-client-request-id'].nil? # Deserialize Response if status_code == 200 begin parsed_response = response_content.to_s.empty? ? nil : JSON.load(response_content) result_mapper = Azure::Monitor::Mgmt::V2015_05_01::Models::WebTest.mapper() result.body = @client.deserialize(result_mapper, parsed_response) rescue Exception => e fail MsRest::DeserializationError.new('Error occurred in deserializing the response', e., e.backtrace, result) end end result end promise.execute end |
#create_or_update_with_http_info(resource_group_name, web_test_name, web_test_definition, custom_headers: nil) ⇒ MsRestAzure::AzureOperationResponse
Creates or updates an Application Insights web test definition.
is case insensitive. resource. create or update an Application Insights web test definition. will be added to the HTTP request.
263 264 265 |
# File 'lib/2015-05-01/generated/azure_mgmt_monitor/web_tests.rb', line 263 def create_or_update_with_http_info(resource_group_name, web_test_name, web_test_definition, custom_headers:nil) create_or_update_async(resource_group_name, web_test_name, web_test_definition, custom_headers:custom_headers).value! end |
#delete(resource_group_name, web_test_name, custom_headers: nil) ⇒ Object
Deletes an Application Insights web test.
is case insensitive. resource. will be added to the HTTP request.
479 480 481 482 |
# File 'lib/2015-05-01/generated/azure_mgmt_monitor/web_tests.rb', line 479 def delete(resource_group_name, web_test_name, custom_headers:nil) response = delete_async(resource_group_name, web_test_name, custom_headers:custom_headers).value! nil end |
#delete_async(resource_group_name, web_test_name, custom_headers: nil) ⇒ Concurrent::Promise
Deletes an Application Insights web test.
is case insensitive. resource. to the HTTP request.
512 513 514 515 516 517 518 519 520 521 522 523 524 525 526 527 528 529 530 531 532 533 534 535 536 537 538 539 540 541 542 543 544 545 546 547 548 549 550 551 552 553 554 555 556 557 558 559 560 |
# File 'lib/2015-05-01/generated/azure_mgmt_monitor/web_tests.rb', line 512 def delete_async(resource_group_name, web_test_name, custom_headers:nil) fail ArgumentError, '@client.subscription_id is nil' if @client.subscription_id.nil? fail ArgumentError, "'@client.subscription_id' should satisfy the constraint - 'MinLength': '1'" if !@client.subscription_id.nil? && @client.subscription_id.length < 1 fail ArgumentError, 'resource_group_name is nil' if resource_group_name.nil? fail ArgumentError, "'resource_group_name' should satisfy the constraint - 'MaxLength': '90'" if !resource_group_name.nil? && resource_group_name.length > 90 fail ArgumentError, "'resource_group_name' should satisfy the constraint - 'MinLength': '1'" if !resource_group_name.nil? && resource_group_name.length < 1 fail ArgumentError, "'resource_group_name' should satisfy the constraint - 'Pattern': '^[-\w\._\(\)]+$'" if !resource_group_name.nil? && resource_group_name.match(Regexp.new('^^[-\w\._\(\)]+$$')).nil? fail ArgumentError, 'web_test_name is nil' if web_test_name.nil? fail ArgumentError, '@client.api_version is nil' if @client.api_version.nil? fail ArgumentError, "'@client.api_version' should satisfy the constraint - 'MinLength': '1'" if !@client.api_version.nil? && @client.api_version.length < 1 request_headers = {} request_headers['Content-Type'] = 'application/json; charset=utf-8' # Set Headers request_headers['x-ms-client-request-id'] = SecureRandom.uuid request_headers['accept-language'] = @client.accept_language unless @client.accept_language.nil? path_template = 'subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.Insights/webtests/{webTestName}' request_url = @base_url || @client.base_url = { middlewares: [[MsRest::RetryPolicyMiddleware, times: 3, retry: 0.02], [:cookie_jar]], path_params: {'subscriptionId' => @client.subscription_id,'resourceGroupName' => resource_group_name,'webTestName' => web_test_name}, query_params: {'api-version' => @client.api_version}, headers: request_headers.merge(custom_headers || {}), base_url: request_url } promise = @client.make_request_async(:delete, path_template, ) promise = promise.then do |result| http_response = result.response status_code = http_response.status response_content = http_response.body unless status_code == 204 || status_code == 200 error_model = JSON.load(response_content) fail MsRestAzure::AzureOperationError.new(result.request, http_response, error_model) end result.request_id = http_response['x-ms-request-id'] unless http_response['x-ms-request-id'].nil? result.correlation_request_id = http_response['x-ms-correlation-request-id'] unless http_response['x-ms-correlation-request-id'].nil? result.client_request_id = http_response['x-ms-client-request-id'] unless http_response['x-ms-client-request-id'].nil? result end promise.execute end |
#delete_with_http_info(resource_group_name, web_test_name, custom_headers: nil) ⇒ MsRestAzure::AzureOperationResponse
Deletes an Application Insights web test.
is case insensitive. resource. will be added to the HTTP request.
496 497 498 |
# File 'lib/2015-05-01/generated/azure_mgmt_monitor/web_tests.rb', line 496 def delete_with_http_info(resource_group_name, web_test_name, custom_headers:nil) delete_async(resource_group_name, web_test_name, custom_headers:custom_headers).value! end |
#get(resource_group_name, web_test_name, custom_headers: nil) ⇒ WebTest
Get a specific Application Insights web test definition.
is case insensitive. resource. will be added to the HTTP request.
137 138 139 140 |
# File 'lib/2015-05-01/generated/azure_mgmt_monitor/web_tests.rb', line 137 def get(resource_group_name, web_test_name, custom_headers:nil) response = get_async(resource_group_name, web_test_name, custom_headers:custom_headers).value! response.body unless response.nil? end |
#get_async(resource_group_name, web_test_name, custom_headers: nil) ⇒ Concurrent::Promise
Get a specific Application Insights web test definition.
is case insensitive. resource. to the HTTP request.
170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 |
# File 'lib/2015-05-01/generated/azure_mgmt_monitor/web_tests.rb', line 170 def get_async(resource_group_name, web_test_name, custom_headers:nil) fail ArgumentError, 'resource_group_name is nil' if resource_group_name.nil? fail ArgumentError, "'resource_group_name' should satisfy the constraint - 'MaxLength': '90'" if !resource_group_name.nil? && resource_group_name.length > 90 fail ArgumentError, "'resource_group_name' should satisfy the constraint - 'MinLength': '1'" if !resource_group_name.nil? && resource_group_name.length < 1 fail ArgumentError, "'resource_group_name' should satisfy the constraint - 'Pattern': '^[-\w\._\(\)]+$'" if !resource_group_name.nil? && resource_group_name.match(Regexp.new('^^[-\w\._\(\)]+$$')).nil? fail ArgumentError, '@client.api_version is nil' if @client.api_version.nil? fail ArgumentError, "'@client.api_version' should satisfy the constraint - 'MinLength': '1'" if !@client.api_version.nil? && @client.api_version.length < 1 fail ArgumentError, '@client.subscription_id is nil' if @client.subscription_id.nil? fail ArgumentError, "'@client.subscription_id' should satisfy the constraint - 'MinLength': '1'" if !@client.subscription_id.nil? && @client.subscription_id.length < 1 fail ArgumentError, 'web_test_name is nil' if web_test_name.nil? request_headers = {} request_headers['Content-Type'] = 'application/json; charset=utf-8' # Set Headers request_headers['x-ms-client-request-id'] = SecureRandom.uuid request_headers['accept-language'] = @client.accept_language unless @client.accept_language.nil? path_template = 'subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.Insights/webtests/{webTestName}' request_url = @base_url || @client.base_url = { middlewares: [[MsRest::RetryPolicyMiddleware, times: 3, retry: 0.02], [:cookie_jar]], path_params: {'resourceGroupName' => resource_group_name,'subscriptionId' => @client.subscription_id,'webTestName' => web_test_name}, query_params: {'api-version' => @client.api_version}, headers: request_headers.merge(custom_headers || {}), base_url: request_url } promise = @client.make_request_async(:get, path_template, ) promise = promise.then do |result| http_response = result.response status_code = http_response.status response_content = http_response.body unless status_code == 200 error_model = JSON.load(response_content) fail MsRestAzure::AzureOperationError.new(result.request, http_response, error_model) end result.request_id = http_response['x-ms-request-id'] unless http_response['x-ms-request-id'].nil? result.correlation_request_id = http_response['x-ms-correlation-request-id'] unless http_response['x-ms-correlation-request-id'].nil? result.client_request_id = http_response['x-ms-client-request-id'] unless http_response['x-ms-client-request-id'].nil? # Deserialize Response if status_code == 200 begin parsed_response = response_content.to_s.empty? ? nil : JSON.load(response_content) result_mapper = Azure::Monitor::Mgmt::V2015_05_01::Models::WebTest.mapper() result.body = @client.deserialize(result_mapper, parsed_response) rescue Exception => e fail MsRest::DeserializationError.new('Error occurred in deserializing the response', e., e.backtrace, result) end end result end promise.execute end |
#get_with_http_info(resource_group_name, web_test_name, custom_headers: nil) ⇒ MsRestAzure::AzureOperationResponse
Get a specific Application Insights web test definition.
is case insensitive. resource. will be added to the HTTP request.
154 155 156 |
# File 'lib/2015-05-01/generated/azure_mgmt_monitor/web_tests.rb', line 154 def get_with_http_info(resource_group_name, web_test_name, custom_headers:nil) get_async(resource_group_name, web_test_name, custom_headers:custom_headers).value! end |
#list(custom_headers: nil) ⇒ Array<WebTest>
Get all Application Insights web test alerts definitions within a subscription.
will be added to the HTTP request.
571 572 573 574 |
# File 'lib/2015-05-01/generated/azure_mgmt_monitor/web_tests.rb', line 571 def list(custom_headers:nil) first_page = list_as_lazy(custom_headers:custom_headers) first_page.get_all_items end |
#list_as_lazy(custom_headers: nil) ⇒ WebTestListResult
Get all Application Insights web test alerts definitions within a subscription.
will be added to the HTTP request.
response.
1067 1068 1069 1070 1071 1072 1073 1074 1075 1076 |
# File 'lib/2015-05-01/generated/azure_mgmt_monitor/web_tests.rb', line 1067 def list_as_lazy(custom_headers:nil) response = list_async(custom_headers:custom_headers).value! unless response.nil? page = response.body page.next_method = Proc.new do |next_page_link| list_next_async(next_page_link, custom_headers:custom_headers) end page end end |
#list_async(custom_headers: nil) ⇒ Concurrent::Promise
Get all Application Insights web test alerts definitions within a subscription.
to the HTTP request.
598 599 600 601 602 603 604 605 606 607 608 609 610 611 612 613 614 615 616 617 618 619 620 621 622 623 624 625 626 627 628 629 630 631 632 633 634 635 636 637 638 639 640 641 642 643 644 645 646 647 648 649 650 651 |
# File 'lib/2015-05-01/generated/azure_mgmt_monitor/web_tests.rb', line 598 def list_async(custom_headers:nil) fail ArgumentError, '@client.api_version is nil' if @client.api_version.nil? fail ArgumentError, "'@client.api_version' should satisfy the constraint - 'MinLength': '1'" if !@client.api_version.nil? && @client.api_version.length < 1 fail ArgumentError, '@client.subscription_id is nil' if @client.subscription_id.nil? fail ArgumentError, "'@client.subscription_id' should satisfy the constraint - 'MinLength': '1'" if !@client.subscription_id.nil? && @client.subscription_id.length < 1 request_headers = {} request_headers['Content-Type'] = 'application/json; charset=utf-8' # Set Headers request_headers['x-ms-client-request-id'] = SecureRandom.uuid request_headers['accept-language'] = @client.accept_language unless @client.accept_language.nil? path_template = 'subscriptions/{subscriptionId}/providers/Microsoft.Insights/webtests' request_url = @base_url || @client.base_url = { middlewares: [[MsRest::RetryPolicyMiddleware, times: 3, retry: 0.02], [:cookie_jar]], path_params: {'subscriptionId' => @client.subscription_id}, query_params: {'api-version' => @client.api_version}, headers: request_headers.merge(custom_headers || {}), base_url: request_url } promise = @client.make_request_async(:get, path_template, ) promise = promise.then do |result| http_response = result.response status_code = http_response.status response_content = http_response.body unless status_code == 200 error_model = JSON.load(response_content) fail MsRestAzure::AzureOperationError.new(result.request, http_response, error_model) end result.request_id = http_response['x-ms-request-id'] unless http_response['x-ms-request-id'].nil? result.correlation_request_id = http_response['x-ms-correlation-request-id'] unless http_response['x-ms-correlation-request-id'].nil? result.client_request_id = http_response['x-ms-client-request-id'] unless http_response['x-ms-client-request-id'].nil? # Deserialize Response if status_code == 200 begin parsed_response = response_content.to_s.empty? ? nil : JSON.load(response_content) result_mapper = Azure::Monitor::Mgmt::V2015_05_01::Models::WebTestListResult.mapper() result.body = @client.deserialize(result_mapper, parsed_response) rescue Exception => e fail MsRest::DeserializationError.new('Error occurred in deserializing the response', e., e.backtrace, result) end end result end promise.execute end |
#list_by_component(component_name, resource_group_name, custom_headers: nil) ⇒ Array<WebTest>
Get all Application Insights web tests defined for the specified component.
resource. is case insensitive. will be added to the HTTP request.
665 666 667 668 |
# File 'lib/2015-05-01/generated/azure_mgmt_monitor/web_tests.rb', line 665 def list_by_component(component_name, resource_group_name, custom_headers:nil) first_page = list_by_component_as_lazy(component_name, resource_group_name, custom_headers:custom_headers) first_page.get_all_items end |
#list_by_component_as_lazy(component_name, resource_group_name, custom_headers: nil) ⇒ WebTestListResult
Get all Application Insights web tests defined for the specified component.
resource. is case insensitive. will be added to the HTTP request.
response.
1091 1092 1093 1094 1095 1096 1097 1098 1099 1100 |
# File 'lib/2015-05-01/generated/azure_mgmt_monitor/web_tests.rb', line 1091 def list_by_component_as_lazy(component_name, resource_group_name, custom_headers:nil) response = list_by_component_async(component_name, resource_group_name, custom_headers:custom_headers).value! unless response.nil? page = response.body page.next_method = Proc.new do |next_page_link| list_by_component_next_async(next_page_link, custom_headers:custom_headers) end page end end |
#list_by_component_async(component_name, resource_group_name, custom_headers: nil) ⇒ Concurrent::Promise
Get all Application Insights web tests defined for the specified component.
resource. is case insensitive. to the HTTP request.
698 699 700 701 702 703 704 705 706 707 708 709 710 711 712 713 714 715 716 717 718 719 720 721 722 723 724 725 726 727 728 729 730 731 732 733 734 735 736 737 738 739 740 741 742 743 744 745 746 747 748 749 750 751 752 753 754 755 756 |
# File 'lib/2015-05-01/generated/azure_mgmt_monitor/web_tests.rb', line 698 def list_by_component_async(component_name, resource_group_name, custom_headers:nil) fail ArgumentError, 'component_name is nil' if component_name.nil? fail ArgumentError, 'resource_group_name is nil' if resource_group_name.nil? fail ArgumentError, "'resource_group_name' should satisfy the constraint - 'MaxLength': '90'" if !resource_group_name.nil? && resource_group_name.length > 90 fail ArgumentError, "'resource_group_name' should satisfy the constraint - 'MinLength': '1'" if !resource_group_name.nil? && resource_group_name.length < 1 fail ArgumentError, "'resource_group_name' should satisfy the constraint - 'Pattern': '^[-\w\._\(\)]+$'" if !resource_group_name.nil? && resource_group_name.match(Regexp.new('^^[-\w\._\(\)]+$$')).nil? fail ArgumentError, '@client.api_version is nil' if @client.api_version.nil? fail ArgumentError, "'@client.api_version' should satisfy the constraint - 'MinLength': '1'" if !@client.api_version.nil? && @client.api_version.length < 1 fail ArgumentError, '@client.subscription_id is nil' if @client.subscription_id.nil? fail ArgumentError, "'@client.subscription_id' should satisfy the constraint - 'MinLength': '1'" if !@client.subscription_id.nil? && @client.subscription_id.length < 1 request_headers = {} request_headers['Content-Type'] = 'application/json; charset=utf-8' # Set Headers request_headers['x-ms-client-request-id'] = SecureRandom.uuid request_headers['accept-language'] = @client.accept_language unless @client.accept_language.nil? path_template = 'subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.Insights/components/{componentName}/webtests' request_url = @base_url || @client.base_url = { middlewares: [[MsRest::RetryPolicyMiddleware, times: 3, retry: 0.02], [:cookie_jar]], path_params: {'componentName' => component_name,'resourceGroupName' => resource_group_name,'subscriptionId' => @client.subscription_id}, query_params: {'api-version' => @client.api_version}, headers: request_headers.merge(custom_headers || {}), base_url: request_url } promise = @client.make_request_async(:get, path_template, ) promise = promise.then do |result| http_response = result.response status_code = http_response.status response_content = http_response.body unless status_code == 200 error_model = JSON.load(response_content) fail MsRestAzure::AzureOperationError.new(result.request, http_response, error_model) end result.request_id = http_response['x-ms-request-id'] unless http_response['x-ms-request-id'].nil? result.correlation_request_id = http_response['x-ms-correlation-request-id'] unless http_response['x-ms-correlation-request-id'].nil? result.client_request_id = http_response['x-ms-client-request-id'] unless http_response['x-ms-client-request-id'].nil? # Deserialize Response if status_code == 200 begin parsed_response = response_content.to_s.empty? ? nil : JSON.load(response_content) result_mapper = Azure::Monitor::Mgmt::V2015_05_01::Models::WebTestListResult.mapper() result.body = @client.deserialize(result_mapper, parsed_response) rescue Exception => e fail MsRest::DeserializationError.new('Error occurred in deserializing the response', e., e.backtrace, result) end end result end promise.execute end |
#list_by_component_next(next_page_link, custom_headers: nil) ⇒ WebTestListResult
Get all Application Insights web tests defined for the specified component.
to List operation. will be added to the HTTP request.
954 955 956 957 |
# File 'lib/2015-05-01/generated/azure_mgmt_monitor/web_tests.rb', line 954 def list_by_component_next(next_page_link, custom_headers:nil) response = list_by_component_next_async(next_page_link, custom_headers:custom_headers).value! response.body unless response.nil? end |
#list_by_component_next_async(next_page_link, custom_headers: nil) ⇒ Concurrent::Promise
Get all Application Insights web tests defined for the specified component.
to List operation. to the HTTP request.
983 984 985 986 987 988 989 990 991 992 993 994 995 996 997 998 999 1000 1001 1002 1003 1004 1005 1006 1007 1008 1009 1010 1011 1012 1013 1014 1015 1016 1017 1018 1019 1020 1021 1022 1023 1024 1025 1026 1027 1028 1029 1030 1031 1032 |
# File 'lib/2015-05-01/generated/azure_mgmt_monitor/web_tests.rb', line 983 def list_by_component_next_async(next_page_link, custom_headers:nil) fail ArgumentError, 'next_page_link is nil' if next_page_link.nil? request_headers = {} request_headers['Content-Type'] = 'application/json; charset=utf-8' # Set Headers request_headers['x-ms-client-request-id'] = SecureRandom.uuid request_headers['accept-language'] = @client.accept_language unless @client.accept_language.nil? path_template = '{nextLink}' request_url = @base_url || @client.base_url = { middlewares: [[MsRest::RetryPolicyMiddleware, times: 3, retry: 0.02], [:cookie_jar]], skip_encoding_path_params: {'nextLink' => next_page_link}, headers: request_headers.merge(custom_headers || {}), base_url: request_url } promise = @client.make_request_async(:get, path_template, ) promise = promise.then do |result| http_response = result.response status_code = http_response.status response_content = http_response.body unless status_code == 200 error_model = JSON.load(response_content) fail MsRestAzure::AzureOperationError.new(result.request, http_response, error_model) end result.request_id = http_response['x-ms-request-id'] unless http_response['x-ms-request-id'].nil? result.correlation_request_id = http_response['x-ms-correlation-request-id'] unless http_response['x-ms-correlation-request-id'].nil? result.client_request_id = http_response['x-ms-client-request-id'] unless http_response['x-ms-client-request-id'].nil? # Deserialize Response if status_code == 200 begin parsed_response = response_content.to_s.empty? ? nil : JSON.load(response_content) result_mapper = Azure::Monitor::Mgmt::V2015_05_01::Models::WebTestListResult.mapper() result.body = @client.deserialize(result_mapper, parsed_response) rescue Exception => e fail MsRest::DeserializationError.new('Error occurred in deserializing the response', e., e.backtrace, result) end end result end promise.execute end |
#list_by_component_next_with_http_info(next_page_link, custom_headers: nil) ⇒ MsRestAzure::AzureOperationResponse
Get all Application Insights web tests defined for the specified component.
to List operation. will be added to the HTTP request.
969 970 971 |
# File 'lib/2015-05-01/generated/azure_mgmt_monitor/web_tests.rb', line 969 def list_by_component_next_with_http_info(next_page_link, custom_headers:nil) list_by_component_next_async(next_page_link, custom_headers:custom_headers).value! end |
#list_by_component_with_http_info(component_name, resource_group_name, custom_headers: nil) ⇒ MsRestAzure::AzureOperationResponse
Get all Application Insights web tests defined for the specified component.
resource. is case insensitive. will be added to the HTTP request.
682 683 684 |
# File 'lib/2015-05-01/generated/azure_mgmt_monitor/web_tests.rb', line 682 def list_by_component_with_http_info(component_name, resource_group_name, custom_headers:nil) list_by_component_async(component_name, resource_group_name, custom_headers:custom_headers).value! end |
#list_by_resource_group(resource_group_name, custom_headers: nil) ⇒ Array<WebTest>
Get all Application Insights web tests defined within a specified resource group.
is case insensitive. will be added to the HTTP request.
35 36 37 38 |
# File 'lib/2015-05-01/generated/azure_mgmt_monitor/web_tests.rb', line 35 def list_by_resource_group(resource_group_name, custom_headers:nil) first_page = list_by_resource_group_as_lazy(resource_group_name, custom_headers:custom_headers) first_page.get_all_items end |
#list_by_resource_group_as_lazy(resource_group_name, custom_headers: nil) ⇒ WebTestListResult
Get all Application Insights web tests defined within a specified resource group.
is case insensitive. will be added to the HTTP request.
response.
1046 1047 1048 1049 1050 1051 1052 1053 1054 1055 |
# File 'lib/2015-05-01/generated/azure_mgmt_monitor/web_tests.rb', line 1046 def list_by_resource_group_as_lazy(resource_group_name, custom_headers:nil) response = list_by_resource_group_async(resource_group_name, custom_headers:custom_headers).value! unless response.nil? page = response.body page.next_method = Proc.new do |next_page_link| list_by_resource_group_next_async(next_page_link, custom_headers:custom_headers) end page end end |
#list_by_resource_group_async(resource_group_name, custom_headers: nil) ⇒ Concurrent::Promise
Get all Application Insights web tests defined within a specified resource group.
is case insensitive. to the HTTP request.
66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 |
# File 'lib/2015-05-01/generated/azure_mgmt_monitor/web_tests.rb', line 66 def list_by_resource_group_async(resource_group_name, custom_headers:nil) fail ArgumentError, 'resource_group_name is nil' if resource_group_name.nil? fail ArgumentError, "'resource_group_name' should satisfy the constraint - 'MaxLength': '90'" if !resource_group_name.nil? && resource_group_name.length > 90 fail ArgumentError, "'resource_group_name' should satisfy the constraint - 'MinLength': '1'" if !resource_group_name.nil? && resource_group_name.length < 1 fail ArgumentError, "'resource_group_name' should satisfy the constraint - 'Pattern': '^[-\w\._\(\)]+$'" if !resource_group_name.nil? && resource_group_name.match(Regexp.new('^^[-\w\._\(\)]+$$')).nil? fail ArgumentError, '@client.api_version is nil' if @client.api_version.nil? fail ArgumentError, "'@client.api_version' should satisfy the constraint - 'MinLength': '1'" if !@client.api_version.nil? && @client.api_version.length < 1 fail ArgumentError, '@client.subscription_id is nil' if @client.subscription_id.nil? fail ArgumentError, "'@client.subscription_id' should satisfy the constraint - 'MinLength': '1'" if !@client.subscription_id.nil? && @client.subscription_id.length < 1 request_headers = {} request_headers['Content-Type'] = 'application/json; charset=utf-8' # Set Headers request_headers['x-ms-client-request-id'] = SecureRandom.uuid request_headers['accept-language'] = @client.accept_language unless @client.accept_language.nil? path_template = 'subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.Insights/webtests' request_url = @base_url || @client.base_url = { middlewares: [[MsRest::RetryPolicyMiddleware, times: 3, retry: 0.02], [:cookie_jar]], path_params: {'resourceGroupName' => resource_group_name,'subscriptionId' => @client.subscription_id}, query_params: {'api-version' => @client.api_version}, headers: request_headers.merge(custom_headers || {}), base_url: request_url } promise = @client.make_request_async(:get, path_template, ) promise = promise.then do |result| http_response = result.response status_code = http_response.status response_content = http_response.body unless status_code == 200 error_model = JSON.load(response_content) fail MsRestAzure::AzureOperationError.new(result.request, http_response, error_model) end result.request_id = http_response['x-ms-request-id'] unless http_response['x-ms-request-id'].nil? result.correlation_request_id = http_response['x-ms-correlation-request-id'] unless http_response['x-ms-correlation-request-id'].nil? result.client_request_id = http_response['x-ms-client-request-id'] unless http_response['x-ms-client-request-id'].nil? # Deserialize Response if status_code == 200 begin parsed_response = response_content.to_s.empty? ? nil : JSON.load(response_content) result_mapper = Azure::Monitor::Mgmt::V2015_05_01::Models::WebTestListResult.mapper() result.body = @client.deserialize(result_mapper, parsed_response) rescue Exception => e fail MsRest::DeserializationError.new('Error occurred in deserializing the response', e., e.backtrace, result) end end result end promise.execute end |
#list_by_resource_group_next(next_page_link, custom_headers: nil) ⇒ WebTestListResult
Get all Application Insights web tests defined within a specified resource group.
to List operation. will be added to the HTTP request.
769 770 771 772 |
# File 'lib/2015-05-01/generated/azure_mgmt_monitor/web_tests.rb', line 769 def list_by_resource_group_next(next_page_link, custom_headers:nil) response = list_by_resource_group_next_async(next_page_link, custom_headers:custom_headers).value! response.body unless response.nil? end |
#list_by_resource_group_next_async(next_page_link, custom_headers: nil) ⇒ Concurrent::Promise
Get all Application Insights web tests defined within a specified resource group.
to List operation. to the HTTP request.
800 801 802 803 804 805 806 807 808 809 810 811 812 813 814 815 816 817 818 819 820 821 822 823 824 825 826 827 828 829 830 831 832 833 834 835 836 837 838 839 840 841 842 843 844 845 846 847 848 849 |
# File 'lib/2015-05-01/generated/azure_mgmt_monitor/web_tests.rb', line 800 def list_by_resource_group_next_async(next_page_link, custom_headers:nil) fail ArgumentError, 'next_page_link is nil' if next_page_link.nil? request_headers = {} request_headers['Content-Type'] = 'application/json; charset=utf-8' # Set Headers request_headers['x-ms-client-request-id'] = SecureRandom.uuid request_headers['accept-language'] = @client.accept_language unless @client.accept_language.nil? path_template = '{nextLink}' request_url = @base_url || @client.base_url = { middlewares: [[MsRest::RetryPolicyMiddleware, times: 3, retry: 0.02], [:cookie_jar]], skip_encoding_path_params: {'nextLink' => next_page_link}, headers: request_headers.merge(custom_headers || {}), base_url: request_url } promise = @client.make_request_async(:get, path_template, ) promise = promise.then do |result| http_response = result.response status_code = http_response.status response_content = http_response.body unless status_code == 200 error_model = JSON.load(response_content) fail MsRestAzure::AzureOperationError.new(result.request, http_response, error_model) end result.request_id = http_response['x-ms-request-id'] unless http_response['x-ms-request-id'].nil? result.correlation_request_id = http_response['x-ms-correlation-request-id'] unless http_response['x-ms-correlation-request-id'].nil? result.client_request_id = http_response['x-ms-client-request-id'] unless http_response['x-ms-client-request-id'].nil? # Deserialize Response if status_code == 200 begin parsed_response = response_content.to_s.empty? ? nil : JSON.load(response_content) result_mapper = Azure::Monitor::Mgmt::V2015_05_01::Models::WebTestListResult.mapper() result.body = @client.deserialize(result_mapper, parsed_response) rescue Exception => e fail MsRest::DeserializationError.new('Error occurred in deserializing the response', e., e.backtrace, result) end end result end promise.execute end |
#list_by_resource_group_next_with_http_info(next_page_link, custom_headers: nil) ⇒ MsRestAzure::AzureOperationResponse
Get all Application Insights web tests defined within a specified resource group.
to List operation. will be added to the HTTP request.
785 786 787 |
# File 'lib/2015-05-01/generated/azure_mgmt_monitor/web_tests.rb', line 785 def list_by_resource_group_next_with_http_info(next_page_link, custom_headers:nil) list_by_resource_group_next_async(next_page_link, custom_headers:custom_headers).value! end |
#list_by_resource_group_with_http_info(resource_group_name, custom_headers: nil) ⇒ MsRestAzure::AzureOperationResponse
Get all Application Insights web tests defined within a specified resource group.
is case insensitive. will be added to the HTTP request.
51 52 53 |
# File 'lib/2015-05-01/generated/azure_mgmt_monitor/web_tests.rb', line 51 def list_by_resource_group_with_http_info(resource_group_name, custom_headers:nil) list_by_resource_group_async(resource_group_name, custom_headers:custom_headers).value! end |
#list_next(next_page_link, custom_headers: nil) ⇒ WebTestListResult
Get all Application Insights web test alerts definitions within a subscription.
to List operation. will be added to the HTTP request.
862 863 864 865 |
# File 'lib/2015-05-01/generated/azure_mgmt_monitor/web_tests.rb', line 862 def list_next(next_page_link, custom_headers:nil) response = list_next_async(next_page_link, custom_headers:custom_headers).value! response.body unless response.nil? end |
#list_next_async(next_page_link, custom_headers: nil) ⇒ Concurrent::Promise
Get all Application Insights web test alerts definitions within a subscription.
to List operation. to the HTTP request.
893 894 895 896 897 898 899 900 901 902 903 904 905 906 907 908 909 910 911 912 913 914 915 916 917 918 919 920 921 922 923 924 925 926 927 928 929 930 931 932 933 934 935 936 937 938 939 940 941 942 |
# File 'lib/2015-05-01/generated/azure_mgmt_monitor/web_tests.rb', line 893 def list_next_async(next_page_link, custom_headers:nil) fail ArgumentError, 'next_page_link is nil' if next_page_link.nil? request_headers = {} request_headers['Content-Type'] = 'application/json; charset=utf-8' # Set Headers request_headers['x-ms-client-request-id'] = SecureRandom.uuid request_headers['accept-language'] = @client.accept_language unless @client.accept_language.nil? path_template = '{nextLink}' request_url = @base_url || @client.base_url = { middlewares: [[MsRest::RetryPolicyMiddleware, times: 3, retry: 0.02], [:cookie_jar]], skip_encoding_path_params: {'nextLink' => next_page_link}, headers: request_headers.merge(custom_headers || {}), base_url: request_url } promise = @client.make_request_async(:get, path_template, ) promise = promise.then do |result| http_response = result.response status_code = http_response.status response_content = http_response.body unless status_code == 200 error_model = JSON.load(response_content) fail MsRestAzure::AzureOperationError.new(result.request, http_response, error_model) end result.request_id = http_response['x-ms-request-id'] unless http_response['x-ms-request-id'].nil? result.correlation_request_id = http_response['x-ms-correlation-request-id'] unless http_response['x-ms-correlation-request-id'].nil? result.client_request_id = http_response['x-ms-client-request-id'] unless http_response['x-ms-client-request-id'].nil? # Deserialize Response if status_code == 200 begin parsed_response = response_content.to_s.empty? ? nil : JSON.load(response_content) result_mapper = Azure::Monitor::Mgmt::V2015_05_01::Models::WebTestListResult.mapper() result.body = @client.deserialize(result_mapper, parsed_response) rescue Exception => e fail MsRest::DeserializationError.new('Error occurred in deserializing the response', e., e.backtrace, result) end end result end promise.execute end |
#list_next_with_http_info(next_page_link, custom_headers: nil) ⇒ MsRestAzure::AzureOperationResponse
Get all Application Insights web test alerts definitions within a subscription.
to List operation. will be added to the HTTP request.
878 879 880 |
# File 'lib/2015-05-01/generated/azure_mgmt_monitor/web_tests.rb', line 878 def list_next_with_http_info(next_page_link, custom_headers:nil) list_next_async(next_page_link, custom_headers:custom_headers).value! end |
#list_with_http_info(custom_headers: nil) ⇒ MsRestAzure::AzureOperationResponse
Get all Application Insights web test alerts definitions within a subscription.
will be added to the HTTP request.
585 586 587 |
# File 'lib/2015-05-01/generated/azure_mgmt_monitor/web_tests.rb', line 585 def list_with_http_info(custom_headers:nil) list_async(custom_headers:custom_headers).value! end |
#update_tags(resource_group_name, web_test_name, web_test_tags, custom_headers: nil) ⇒ WebTest
Creates or updates an Application Insights web test definition.
is case insensitive. resource. web test instance. will be added to the HTTP request.
363 364 365 366 |
# File 'lib/2015-05-01/generated/azure_mgmt_monitor/web_tests.rb', line 363 def (resource_group_name, web_test_name, , custom_headers:nil) response = (resource_group_name, web_test_name, , custom_headers:custom_headers).value! response.body unless response.nil? end |
#update_tags_async(resource_group_name, web_test_name, web_test_tags, custom_headers: nil) ⇒ Concurrent::Promise
Creates or updates an Application Insights web test definition.
is case insensitive. resource. web test instance. to the HTTP request.
400 401 402 403 404 405 406 407 408 409 410 411 412 413 414 415 416 417 418 419 420 421 422 423 424 425 426 427 428 429 430 431 432 433 434 435 436 437 438 439 440 441 442 443 444 445 446 447 448 449 450 451 452 453 454 455 456 457 458 459 460 461 462 463 464 465 466 |
# File 'lib/2015-05-01/generated/azure_mgmt_monitor/web_tests.rb', line 400 def (resource_group_name, web_test_name, , custom_headers:nil) fail ArgumentError, 'resource_group_name is nil' if resource_group_name.nil? fail ArgumentError, "'resource_group_name' should satisfy the constraint - 'MaxLength': '90'" if !resource_group_name.nil? && resource_group_name.length > 90 fail ArgumentError, "'resource_group_name' should satisfy the constraint - 'MinLength': '1'" if !resource_group_name.nil? && resource_group_name.length < 1 fail ArgumentError, "'resource_group_name' should satisfy the constraint - 'Pattern': '^[-\w\._\(\)]+$'" if !resource_group_name.nil? && resource_group_name.match(Regexp.new('^^[-\w\._\(\)]+$$')).nil? fail ArgumentError, '@client.api_version is nil' if @client.api_version.nil? fail ArgumentError, "'@client.api_version' should satisfy the constraint - 'MinLength': '1'" if !@client.api_version.nil? && @client.api_version.length < 1 fail ArgumentError, '@client.subscription_id is nil' if @client.subscription_id.nil? fail ArgumentError, "'@client.subscription_id' should satisfy the constraint - 'MinLength': '1'" if !@client.subscription_id.nil? && @client.subscription_id.length < 1 fail ArgumentError, 'web_test_name is nil' if web_test_name.nil? fail ArgumentError, 'web_test_tags is nil' if .nil? request_headers = {} request_headers['Content-Type'] = 'application/json; charset=utf-8' # Set Headers request_headers['x-ms-client-request-id'] = SecureRandom.uuid request_headers['accept-language'] = @client.accept_language unless @client.accept_language.nil? # Serialize Request request_mapper = Azure::Monitor::Mgmt::V2015_05_01::Models::TagsResource.mapper() request_content = @client.serialize(request_mapper, ) request_content = request_content != nil ? JSON.generate(request_content, quirks_mode: true) : nil path_template = 'subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.Insights/webtests/{webTestName}' request_url = @base_url || @client.base_url = { middlewares: [[MsRest::RetryPolicyMiddleware, times: 3, retry: 0.02], [:cookie_jar]], path_params: {'resourceGroupName' => resource_group_name,'subscriptionId' => @client.subscription_id,'webTestName' => web_test_name}, query_params: {'api-version' => @client.api_version}, body: request_content, headers: request_headers.merge(custom_headers || {}), base_url: request_url } promise = @client.make_request_async(:patch, path_template, ) promise = promise.then do |result| http_response = result.response status_code = http_response.status response_content = http_response.body unless status_code == 200 error_model = JSON.load(response_content) fail MsRestAzure::AzureOperationError.new(result.request, http_response, error_model) end result.request_id = http_response['x-ms-request-id'] unless http_response['x-ms-request-id'].nil? result.correlation_request_id = http_response['x-ms-correlation-request-id'] unless http_response['x-ms-correlation-request-id'].nil? result.client_request_id = http_response['x-ms-client-request-id'] unless http_response['x-ms-client-request-id'].nil? # Deserialize Response if status_code == 200 begin parsed_response = response_content.to_s.empty? ? nil : JSON.load(response_content) result_mapper = Azure::Monitor::Mgmt::V2015_05_01::Models::WebTest.mapper() result.body = @client.deserialize(result_mapper, parsed_response) rescue Exception => e fail MsRest::DeserializationError.new('Error occurred in deserializing the response', e., e.backtrace, result) end end result end promise.execute end |
#update_tags_with_http_info(resource_group_name, web_test_name, web_test_tags, custom_headers: nil) ⇒ MsRestAzure::AzureOperationResponse
Creates or updates an Application Insights web test definition.
is case insensitive. resource. web test instance. will be added to the HTTP request.
382 383 384 |
# File 'lib/2015-05-01/generated/azure_mgmt_monitor/web_tests.rb', line 382 def (resource_group_name, web_test_name, , custom_headers:nil) (resource_group_name, web_test_name, , custom_headers:custom_headers).value! end |