Class: Azure::Monitor::Mgmt::V2016_09_01::Metrics
- Inherits:
-
Object
- Object
- Azure::Monitor::Mgmt::V2016_09_01::Metrics
- Includes:
- MsRestAzure
- Defined in:
- lib/2016-09-01/generated/azure_mgmt_monitor/metrics.rb
Overview
Monitor Management Client
Instance Attribute Summary collapse
-
#client ⇒ MonitorClient
readonly
Reference to the MonitorClient.
Instance Method Summary collapse
-
#initialize(client) ⇒ Metrics
constructor
Creates and initializes a new instance of the Metrics class.
-
#list(resource_uri, filter: nil, custom_headers: nil) ⇒ MetricCollection
Lists the metric values for a resource.
-
#list_async(resource_uri, filter: nil, custom_headers: nil) ⇒ Concurrent::Promise
Lists the metric values for a resource.
-
#list_with_http_info(resource_uri, filter: nil, custom_headers: nil) ⇒ MsRestAzure::AzureOperationResponse
Lists the metric values for a resource.
Constructor Details
#initialize(client) ⇒ Metrics
Creates and initializes a new instance of the Metrics class.
17 18 19 |
# File 'lib/2016-09-01/generated/azure_mgmt_monitor/metrics.rb', line 17 def initialize(client) @client = client end |
Instance Attribute Details
#client ⇒ MonitorClient (readonly)
Returns reference to the MonitorClient.
22 23 24 |
# File 'lib/2016-09-01/generated/azure_mgmt_monitor/metrics.rb', line 22 def client @client end |
Instance Method Details
#list(resource_uri, filter: nil, custom_headers: nil) ⇒ MetricCollection
Lists the metric values for a resource.
optional. If present it must contain a list of metric names to retrieve of the form: *(name.value eq 'metricName' [or name.value eq 'metricName' or …])*. Optionally, the filter can contain conditions for the following attributes aggregationType, startTime, endTime, and timeGrain of the form *attributeName operator value*. Where operator is one of ne, eq, gt, lt.
Several conditions can be combined with parentheses and logical operators, e.g: and, or.
Some example filter expressions are:
- $filter=(name.value eq 'RunsSucceeded') and aggregationType eq 'Total' and startTime eq 2016-02-20 and endTime eq 2016-02-21 and timeGrain eq duration'PT1M',
- $filter=(name.value eq 'RunsSucceeded') and (aggregationType eq 'Total' or aggregationType eq 'Average') and startTime eq 2016-02-20 and endTime eq 2016-02-21 and timeGrain eq duration'PT1H',
- $filter=(name.value eq 'ActionsCompleted' or name.value eq 'RunsSucceeded') and (aggregationType eq 'Total' or aggregationType eq 'Average') and startTime eq 2016-02-20 and endTime eq 2016-02-21 and timeGrain eq duration'PT1M'.
*NOTE*: When a metrics query comes in with multiple metrics, but with no aggregation types defined, the service will pick the Primary aggregation type of the first metrics to be used as the default aggregation type for all the metrics. will be added to the HTTP request.
53 54 55 56 |
# File 'lib/2016-09-01/generated/azure_mgmt_monitor/metrics.rb', line 53 def list(resource_uri, filter:nil, custom_headers:nil) response = list_async(resource_uri, filter:filter, custom_headers:custom_headers).value! response.body unless response.nil? end |
#list_async(resource_uri, filter: nil, custom_headers: nil) ⇒ Concurrent::Promise
Lists the metric values for a resource.
optional. If present it must contain a list of metric names to retrieve of the form: *(name.value eq 'metricName' [or name.value eq 'metricName' or …])*. Optionally, the filter can contain conditions for the following attributes aggregationType, startTime, endTime, and timeGrain of the form *attributeName operator value*. Where operator is one of ne, eq, gt, lt.
Several conditions can be combined with parentheses and logical operators, e.g: and, or.
Some example filter expressions are:
- $filter=(name.value eq 'RunsSucceeded') and aggregationType eq 'Total' and startTime eq 2016-02-20 and endTime eq 2016-02-21 and timeGrain eq duration'PT1M',
- $filter=(name.value eq 'RunsSucceeded') and (aggregationType eq 'Total' or aggregationType eq 'Average') and startTime eq 2016-02-20 and endTime eq 2016-02-21 and timeGrain eq duration'PT1H',
- $filter=(name.value eq 'ActionsCompleted' or name.value eq 'RunsSucceeded') and (aggregationType eq 'Total' or aggregationType eq 'Average') and startTime eq 2016-02-20 and endTime eq 2016-02-21 and timeGrain eq duration'PT1M'.
*NOTE*: When a metrics query comes in with multiple metrics, but with no aggregation types defined, the service will pick the Primary aggregation type of the first metrics to be used as the default aggregation type for all the metrics. to the HTTP request.
120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 |
# File 'lib/2016-09-01/generated/azure_mgmt_monitor/metrics.rb', line 120 def list_async(resource_uri, filter:nil, custom_headers:nil) fail ArgumentError, 'resource_uri is nil' if resource_uri.nil? fail ArgumentError, '@client.api_version is nil' if @client.api_version.nil? request_headers = {} request_headers['Content-Type'] = 'application/json; charset=utf-8' # Set Headers request_headers['x-ms-client-request-id'] = SecureRandom.uuid request_headers['accept-language'] = @client.accept_language unless @client.accept_language.nil? path_template = '{resourceUri}/providers/microsoft.insights/metrics' request_url = @base_url || @client.base_url = { middlewares: [[MsRest::RetryPolicyMiddleware, times: 3, retry: 0.02], [:cookie_jar]], skip_encoding_path_params: {'resourceUri' => resource_uri}, query_params: {'$filter' => filter,'api-version' => @client.api_version}, headers: request_headers.merge(custom_headers || {}), base_url: request_url } promise = @client.make_request_async(:get, path_template, ) promise = promise.then do |result| http_response = result.response status_code = http_response.status response_content = http_response.body unless status_code == 200 error_model = JSON.load(response_content) fail MsRest::HttpOperationError.new(result.request, http_response, error_model) end result.request_id = http_response['x-ms-request-id'] unless http_response['x-ms-request-id'].nil? result.correlation_request_id = http_response['x-ms-correlation-request-id'] unless http_response['x-ms-correlation-request-id'].nil? result.client_request_id = http_response['x-ms-client-request-id'] unless http_response['x-ms-client-request-id'].nil? # Deserialize Response if status_code == 200 begin parsed_response = response_content.to_s.empty? ? nil : JSON.load(response_content) result_mapper = Azure::Monitor::Mgmt::V2016_09_01::Models::MetricCollection.mapper() result.body = @client.deserialize(result_mapper, parsed_response) rescue Exception => e fail MsRest::DeserializationError.new('Error occurred in deserializing the response', e., e.backtrace, result) end end result end promise.execute end |
#list_with_http_info(resource_uri, filter: nil, custom_headers: nil) ⇒ MsRestAzure::AzureOperationResponse
Lists the metric values for a resource.
optional. If present it must contain a list of metric names to retrieve of the form: *(name.value eq 'metricName' [or name.value eq 'metricName' or …])*. Optionally, the filter can contain conditions for the following attributes aggregationType, startTime, endTime, and timeGrain of the form *attributeName operator value*. Where operator is one of ne, eq, gt, lt.
Several conditions can be combined with parentheses and logical operators, e.g: and, or.
Some example filter expressions are:
- $filter=(name.value eq 'RunsSucceeded') and aggregationType eq 'Total' and startTime eq 2016-02-20 and endTime eq 2016-02-21 and timeGrain eq duration'PT1M',
- $filter=(name.value eq 'RunsSucceeded') and (aggregationType eq 'Total' or aggregationType eq 'Average') and startTime eq 2016-02-20 and endTime eq 2016-02-21 and timeGrain eq duration'PT1H',
- $filter=(name.value eq 'ActionsCompleted' or name.value eq 'RunsSucceeded') and (aggregationType eq 'Total' or aggregationType eq 'Average') and startTime eq 2016-02-20 and endTime eq 2016-02-21 and timeGrain eq duration'PT1M'.
*NOTE*: When a metrics query comes in with multiple metrics, but with no aggregation types defined, the service will pick the Primary aggregation type of the first metrics to be used as the default aggregation type for all the metrics. will be added to the HTTP request.
87 88 89 |
# File 'lib/2016-09-01/generated/azure_mgmt_monitor/metrics.rb', line 87 def list_with_http_info(resource_uri, filter:nil, custom_headers:nil) list_async(resource_uri, filter:filter, custom_headers:custom_headers).value! end |